Module: Google::Apis::SecuritycenterV1beta2

Defined in:
lib/google/apis/securitycenter_v1beta2.rb,
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/service.rb,
lib/google/apis/securitycenter_v1beta2/gem_version.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Security Command Center API

Security Command Center API provides access to temporal views of assets and findings within an organization.

Defined Under Namespace

Classes: Access, AccessReview, AdaptiveProtection, AffectedResources, AiModel, Allowed, Application, ArtifactGuardPolicies, ArtifactGuardPolicy, Attack, AttackExposure, AwsAccount, AwsMetadata, AwsOrganization, AwsOrganizationalUnit, AzureManagementGroup, AzureMetadata, AzureResourceGroup, AzureSubscription, AzureTenant, BackupDisasterRecovery, BigQueryDestination, Chokepoint, CloudArmor, CloudControl, CloudDlpDataProfile, CloudDlpInspection, CloudLoggingEntry, Compliance, ComplianceDetails, Config, Connection, Contact, ContactDetails, Container, ContainerThreatDetectionSettings, Control, Cve, Cvssv3, Cwe, DataAccessEvent, DataFlowEvent, DataRetentionDeletionEvent, Database, Dataset, Denied, Details, Detection, Disk, DiskPath, DynamicMuteRecord, EnvironmentVariable, EventThreatDetectionSettings, ExfilResource, Exfiltration, ExportFindingsMetadata, ExportFindingsResponse, Expr, File, FileOperation, Finding, Folder, Framework, GcpMetadata, Geolocation, GoogleCloudSecuritycenterV1BigQueryExport, GoogleCloudSecuritycenterV1Binding, GoogleCloudSecuritycenterV1BulkMuteFindingsResponse, GoogleCloudSecuritycenterV1CustomConfig, GoogleCloudSecuritycenterV1CustomOutputSpec, GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule, GoogleCloudSecuritycenterV1ExternalSystem, GoogleCloudSecuritycenterV1MuteConfig, GoogleCloudSecuritycenterV1NotificationMessage, GoogleCloudSecuritycenterV1Property, GoogleCloudSecuritycenterV1Resource, GoogleCloudSecuritycenterV1ResourceApplication, GoogleCloudSecuritycenterV1ResourceApplicationAttributes, GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo, GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality, GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment, GoogleCloudSecuritycenterV1ResourceSelector, GoogleCloudSecuritycenterV1ResourceValueConfig, GoogleCloudSecuritycenterV1RunAssetDiscoveryResponse, GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule, GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping, GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse, GoogleCloudSecuritycenterV1p1beta1Finding, GoogleCloudSecuritycenterV1p1beta1Folder, GoogleCloudSecuritycenterV1p1beta1NotificationMessage, GoogleCloudSecuritycenterV1p1beta1Resource, GoogleCloudSecuritycenterV1p1beta1RunAssetDiscoveryResponse, GoogleCloudSecuritycenterV1p1beta1SecurityMarks, GoogleCloudSecuritycenterV2Access, GoogleCloudSecuritycenterV2AccessReview, GoogleCloudSecuritycenterV2AdaptiveProtection, GoogleCloudSecuritycenterV2AffectedResources, GoogleCloudSecuritycenterV2AiModel, GoogleCloudSecuritycenterV2Allowed, GoogleCloudSecuritycenterV2Application, GoogleCloudSecuritycenterV2ArtifactGuardPolicies, GoogleCloudSecuritycenterV2ArtifactGuardPolicy, GoogleCloudSecuritycenterV2Attack, GoogleCloudSecuritycenterV2AttackExposure, GoogleCloudSecuritycenterV2AwsAccount, GoogleCloudSecuritycenterV2AwsMetadata, GoogleCloudSecuritycenterV2AwsOrganization, GoogleCloudSecuritycenterV2AwsOrganizationalUnit, GoogleCloudSecuritycenterV2AzureManagementGroup, GoogleCloudSecuritycenterV2AzureMetadata, GoogleCloudSecuritycenterV2AzureResourceGroup, GoogleCloudSecuritycenterV2AzureSubscription, GoogleCloudSecuritycenterV2AzureTenant, GoogleCloudSecuritycenterV2BackupDisasterRecovery, GoogleCloudSecuritycenterV2BigQueryExport, GoogleCloudSecuritycenterV2Binding, GoogleCloudSecuritycenterV2BulkMuteFindingsResponse, GoogleCloudSecuritycenterV2Chokepoint, GoogleCloudSecuritycenterV2CloudArmor, GoogleCloudSecuritycenterV2CloudControl, GoogleCloudSecuritycenterV2CloudDlpDataProfile, GoogleCloudSecuritycenterV2CloudDlpInspection, GoogleCloudSecuritycenterV2CloudLoggingEntry, GoogleCloudSecuritycenterV2Compliance, GoogleCloudSecuritycenterV2ComplianceDetails, GoogleCloudSecuritycenterV2Connection, GoogleCloudSecuritycenterV2Contact, GoogleCloudSecuritycenterV2ContactDetails, GoogleCloudSecuritycenterV2Container, GoogleCloudSecuritycenterV2Control, GoogleCloudSecuritycenterV2Cve, GoogleCloudSecuritycenterV2Cvssv3, GoogleCloudSecuritycenterV2Cwe, GoogleCloudSecuritycenterV2DataAccessEvent, GoogleCloudSecuritycenterV2DataFlowEvent, GoogleCloudSecuritycenterV2DataRetentionDeletionEvent, GoogleCloudSecuritycenterV2Database, GoogleCloudSecuritycenterV2Dataset, GoogleCloudSecuritycenterV2Denied, GoogleCloudSecuritycenterV2Detection, GoogleCloudSecuritycenterV2Disk, GoogleCloudSecuritycenterV2DiskPath, GoogleCloudSecuritycenterV2DynamicMuteRecord, GoogleCloudSecuritycenterV2EnvironmentVariable, GoogleCloudSecuritycenterV2ExfilResource, GoogleCloudSecuritycenterV2Exfiltration, GoogleCloudSecuritycenterV2ExternalSystem, GoogleCloudSecuritycenterV2File, GoogleCloudSecuritycenterV2FileOperation, GoogleCloudSecuritycenterV2Finding, GoogleCloudSecuritycenterV2Folder, GoogleCloudSecuritycenterV2Framework, GoogleCloudSecuritycenterV2Geolocation, GoogleCloudSecuritycenterV2GroupMembership, GoogleCloudSecuritycenterV2IamBinding, GoogleCloudSecuritycenterV2Indicator, GoogleCloudSecuritycenterV2InfoType, GoogleCloudSecuritycenterV2IpRule, GoogleCloudSecuritycenterV2IpRules, GoogleCloudSecuritycenterV2Issue, GoogleCloudSecuritycenterV2IssueDomain, GoogleCloudSecuritycenterV2IssueFinding, GoogleCloudSecuritycenterV2IssueFindingCve, GoogleCloudSecuritycenterV2IssueFindingSecurityBulletin, GoogleCloudSecuritycenterV2IssueMute, GoogleCloudSecuritycenterV2IssueResource, GoogleCloudSecuritycenterV2IssueResourceApplication, GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes, GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo, GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality, GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment, GoogleCloudSecuritycenterV2IssueResourceAwsMetadata, GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount, GoogleCloudSecuritycenterV2IssueResourceAzureMetadata, GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription, GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata, GoogleCloudSecuritycenterV2IssueSecurityContext, GoogleCloudSecuritycenterV2IssueSecurityContextAggregatedCount, GoogleCloudSecuritycenterV2IssueSecurityContextContext, GoogleCloudSecuritycenterV2Job, GoogleCloudSecuritycenterV2KernelRootkit, GoogleCloudSecuritycenterV2Kubernetes, GoogleCloudSecuritycenterV2Label, GoogleCloudSecuritycenterV2LoadBalancer, GoogleCloudSecuritycenterV2LogEntry, GoogleCloudSecuritycenterV2MemoryHashSignature, GoogleCloudSecuritycenterV2MitreAttack, GoogleCloudSecuritycenterV2MuteConfig, GoogleCloudSecuritycenterV2MuteInfo, GoogleCloudSecuritycenterV2Network, GoogleCloudSecuritycenterV2Node, GoogleCloudSecuritycenterV2NodePool, GoogleCloudSecuritycenterV2Notebook, GoogleCloudSecuritycenterV2NotificationMessage, GoogleCloudSecuritycenterV2Object, GoogleCloudSecuritycenterV2OrgPolicy, GoogleCloudSecuritycenterV2Package, GoogleCloudSecuritycenterV2Pipeline, GoogleCloudSecuritycenterV2Pod, GoogleCloudSecuritycenterV2PolicyDriftDetails, GoogleCloudSecuritycenterV2PortRange, GoogleCloudSecuritycenterV2Process, GoogleCloudSecuritycenterV2ProcessSignature, GoogleCloudSecuritycenterV2Reference, GoogleCloudSecuritycenterV2Requests, GoogleCloudSecuritycenterV2Resource, GoogleCloudSecuritycenterV2ResourceApplication, GoogleCloudSecuritycenterV2ResourceApplicationAttributes, GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo, GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality, GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment, GoogleCloudSecuritycenterV2ResourcePath, GoogleCloudSecuritycenterV2ResourcePathNode, GoogleCloudSecuritycenterV2ResourceValueConfig, GoogleCloudSecuritycenterV2Role, GoogleCloudSecuritycenterV2Secret, GoogleCloudSecuritycenterV2SecretEnvironmentVariable, GoogleCloudSecuritycenterV2SecretFilePath, GoogleCloudSecuritycenterV2SecretStatus, GoogleCloudSecuritycenterV2SecurityBulletin, GoogleCloudSecuritycenterV2SecurityMarks, GoogleCloudSecuritycenterV2SecurityPolicy, GoogleCloudSecuritycenterV2SecurityPosture, GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping, GoogleCloudSecuritycenterV2SensitivityScore, GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo, GoogleCloudSecuritycenterV2StaticMute, GoogleCloudSecuritycenterV2Subject, GoogleCloudSecuritycenterV2TicketInfo, GoogleCloudSecuritycenterV2ToxicCombination, GoogleCloudSecuritycenterV2VertexAi, GoogleCloudSecuritycenterV2Vulnerability, GoogleCloudSecuritycenterV2YaraRuleSignature, GroupMembership, IamBinding, Indicator, InfoType, IpRule, IpRules, Job, KernelRootkit, Kubernetes, Label, LoadBalancer, LogEntry, MemoryHashSignature, MitreAttack, MuteInfo, Network, Node, NodePool, Notebook, Object, OrgPolicy, Package, Pipeline, Pod, PolicyDriftDetails, PortRange, Process, ProcessSignature, RapidVulnerabilityDetectionSettings, Reference, Requests, ResourcePath, ResourcePathNode, Role, Secret, SecretEnvironmentVariable, SecretFilePath, SecretStatus, SecurityBulletin, SecurityCenterSettings, SecurityCommandCenterService, SecurityHealthAnalyticsSettings, SecurityMarks, SecurityPolicy, SecurityPosture, SensitivityScore, ServiceAccountDelegationInfo, StaticMute, Subject, Subscription, TicketInfo, ToxicCombination, VertexAi, VirtualMachineThreatDetectionSettings, Vulnerability, VulnerabilityCountBySeverity, VulnerabilitySnapshot, WebSecurityScannerSettings, YaraRuleSignature

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-securitycenter_v1beta2 gem

"0.94.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260105"
VERSION =

Version of the Security Command Center API this client connects to. This is NOT the gem version.

'V1beta2'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'