Class: Google::Apis::SecuritycenterV1beta2::AgentDataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about a data access attempt made by an agent principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentDataAccessEvent

Returns a new instance of AgentDataAccessEvent.



326
327
328
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 309

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


314
315
316
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 314

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


319
320
321
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 319

def operation
  @operation
end

#principal_subjectString

The agent principal that accessed the data. Corresponds to the JSON property principalSubject

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 324

def principal_subject
  @principal_subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



331
332
333
334
335
336
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 331

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
end