Class: Google::Apis::SecuritycenterV1beta2::Application
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Application
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an application associated with a finding.
Instance Attribute Summary collapse
-
#base_uri ⇒ String
The base URI that identifies the network location of the application in which the vulnerability was detected.
-
#full_uri ⇒ String
The full URI with payload that can be used to reproduce the vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Application
constructor
A new instance of Application.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Application
Returns a new instance of Application.
329 330 331 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_uri ⇒ String
The base URI that identifies the network location of the application in which
the vulnerability was detected. For example, http://example.com.
Corresponds to the JSON property baseUri
321 322 323 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 321 def base_uri @base_uri end |
#full_uri ⇒ String
The full URI with payload that can be used to reproduce the vulnerability. For
example, http://example.com?p=aMmYgI6H.
Corresponds to the JSON property fullUri
327 328 329 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 327 def full_uri @full_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
334 335 336 337 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 334 def update!(**args) @base_uri = args[:base_uri] if args.key?(:base_uri) @full_uri = args[:full_uri] if args.key?(:full_uri) end |