Class: Google::Apis::SecuritycenterV1beta2::ArtifactGuardPolicy
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::ArtifactGuardPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an artifact guard policy.
Instance Attribute Summary collapse
-
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND max_vuln_count=2".
-
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/ global/policies/prod-policy".
-
#type ⇒ String
The type of the policy evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ArtifactGuardPolicy
constructor
A new instance of ArtifactGuardPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ArtifactGuardPolicy
Returns a new instance of ArtifactGuardPolicy.
386 387 388 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND
max_vuln_count=2".
Corresponds to the JSON property failureReason
373 374 375 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 373 def failure_reason @failure_reason end |
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/
global/policies/prod-policy".
Corresponds to the JSON property policyId
379 380 381 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 379 def policy_id @policy_id end |
#type ⇒ String
The type of the policy evaluation.
Corresponds to the JSON property type
384 385 386 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 384 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
391 392 393 394 395 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 391 def update!(**args) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @policy_id = args[:policy_id] if args.key?(:policy_id) @type = args[:type] if args.key?(:type) end |