Class: Google::Apis::SecuritycenterV1beta2::AwsOrganization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AwsOrganization

Returns a new instance of AwsOrganization.



579
580
581
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier (ID) for the organization. The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits. Corresponds to the JSON property id

Returns:

  • (String)


577
578
579
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 577

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



584
585
586
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 584

def update!(**args)
  @id = args[:id] if args.key?(:id)
end