Class: Google::Apis::SecuritycenterV1beta2::AzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AzureMetadata

Returns a new instance of AzureMetadata.



740
741
742
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_groupsArray<Google::Apis::SecuritycenterV1beta2::AzureManagementGroup>

A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level. Corresponds to the JSON property managementGroups



723
724
725
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 723

def management_groups
  @management_groups
end

#resource_groupGoogle::Apis::SecuritycenterV1beta2::AzureResourceGroup

Represents an Azure resource group. Corresponds to the JSON property resourceGroup



728
729
730
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 728

def resource_group
  @resource_group
end

#subscriptionGoogle::Apis::SecuritycenterV1beta2::AzureSubscription

Represents an Azure subscription. Corresponds to the JSON property subscription



733
734
735
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 733

def subscription
  @subscription
end

#tenantGoogle::Apis::SecuritycenterV1beta2::AzureTenant

Represents a Microsoft Entra tenant. Corresponds to the JSON property tenant



738
739
740
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 738

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



745
746
747
748
749
750
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 745

def update!(**args)
  @management_groups = args[:management_groups] if args.key?(:management_groups)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @subscription = args[:subscription] if args.key?(:subscription)
  @tenant = args[:tenant] if args.key?(:tenant)
end