Class: Google::Apis::SecuritycenterV1beta2::CloudArmor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Fields related to Google Cloud Armor findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudArmor

Returns a new instance of CloudArmor.



943
944
945
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptive_protectionGoogle::Apis::SecuritycenterV1beta2::AdaptiveProtection

Information about Google Cloud Armor Adaptive Protection. Corresponds to the JSON property adaptiveProtection



912
913
914
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 912

def adaptive_protection
  @adaptive_protection
end

#attackGoogle::Apis::SecuritycenterV1beta2::Attack

Information about DDoS attack volume and classification. Corresponds to the JSON property attack



917
918
919
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 917

def attack
  @attack
end

#durationString

Duration of attack from the start until the current moment (updated every 5 minutes). Corresponds to the JSON property duration

Returns:

  • (String)


923
924
925
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 923

def duration
  @duration
end

#requestsGoogle::Apis::SecuritycenterV1beta2::Requests

Information about the requests relevant to the finding. Corresponds to the JSON property requests



928
929
930
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 928

def requests
  @requests
end

#security_policyGoogle::Apis::SecuritycenterV1beta2::SecurityPolicy

Information about the Google Cloud Armor security policy relevant to the finding. Corresponds to the JSON property securityPolicy



934
935
936
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 934

def security_policy
  @security_policy
end

#threat_vectorString

Distinguish between volumetric & protocol DDoS attack and application layer attacks. For example, "L3_4" for Layer 3 and Layer 4 DDoS attacks, or "L_7" for Layer 7 DDoS attacks. Corresponds to the JSON property threatVector

Returns:

  • (String)


941
942
943
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 941

def threat_vector
  @threat_vector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



948
949
950
951
952
953
954
955
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 948

def update!(**args)
  @adaptive_protection = args[:adaptive_protection] if args.key?(:adaptive_protection)
  @attack = args[:attack] if args.key?(:attack)
  @duration = args[:duration] if args.key?(:duration)
  @requests = args[:requests] if args.key?(:requests)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @threat_vector = args[:threat_vector] if args.key?(:threat_vector)
end