Class: Google::Apis::SecuritycenterV1beta2::CloudLoggingEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Metadata taken from a Cloud Logging LogEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudLoggingEntry

Returns a new instance of CloudLoggingEntry.



1100
1101
1102
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#insert_idString

A unique identifier for the log entry. Corresponds to the JSON property insertId

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1079

def insert_id
  @insert_id
end

#log_idString

The type of the log (part of log_name. log_name is the resource name of the log to which this log entry belongs). For example: cloudresourcemanager. googleapis.com/activity. Note that this field is not URL-encoded, unlike the LOG_ID field in LogEntry. Corresponds to the JSON property logId

Returns:

  • (String)


1087
1088
1089
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1087

def log_id
  @log_id
end

#resource_containerString

The organization, folder, or project of the monitored resource that produced this log entry. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1093
1094
1095
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1093

def resource_container
  @resource_container
end

#timestampString

The time the event described by the log entry occurred. Corresponds to the JSON property timestamp

Returns:

  • (String)


1098
1099
1100
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1098

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1105
1106
1107
1108
1109
1110
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1105

def update!(**args)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @log_id = args[:log_id] if args.key?(:log_id)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end