Class: Google::Apis::SecuritycenterV1beta2::Compliance
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Compliance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Contains compliance information about a security standard indicating unmet recommendations.
Instance Attribute Summary collapse
-
#ids ⇒ Array<String>
Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property
ids. -
#standard ⇒ String
Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP.
-
#version ⇒ String
Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Compliance
constructor
A new instance of Compliance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Compliance
Returns a new instance of Compliance.
1201 1202 1203 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ids ⇒ Array<String>
Policies within the standard or benchmark, for example, A.12.4.1
Corresponds to the JSON property ids
1189 1190 1191 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1189 def ids @ids end |
#standard ⇒ String
Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP.
Corresponds to the JSON property standard
1194 1195 1196 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1194 def standard @standard end |
#version ⇒ String
Version of the standard or benchmark, for example, 1.1
Corresponds to the JSON property version
1199 1200 1201 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1199 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1206 1207 1208 1209 1210 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1206 def update!(**args) @ids = args[:ids] if args.key?(:ids) @standard = args[:standard] if args.key?(:standard) @version = args[:version] if args.key?(:version) end |