Class: Google::Apis::SecuritycenterV1beta2::Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Container

Returns a new instance of Container.



1385
1386
1387
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1361

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


1367
1368
1369
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1367

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1beta2::Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



1372
1373
1374
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1372

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


1377
1378
1379
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1377

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


1383
1384
1385
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1383

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1390
1391
1392
1393
1394
1395
1396
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1390

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end