Class: Google::Apis::SecuritycenterV1beta2::Cve

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

CVE stands for Common Vulnerabilities and Exposures. Information from the CVE record that describes this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cve

Returns a new instance of Cve.



1536
1537
1538
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvssv3Google::Apis::SecuritycenterV1beta2::Cvssv3

Common Vulnerability Scoring System version 3. Corresponds to the JSON property cvssv3



1485
1486
1487
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1485

def cvssv3
  @cvssv3
end

#exploit_release_dateString

Date the first publicly available exploit or PoC was released. Corresponds to the JSON property exploitReleaseDate

Returns:

  • (String)


1490
1491
1492
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1490

def exploit_release_date
  @exploit_release_date
end

#exploitation_activityString

The exploitation activity of the vulnerability in the wild. Corresponds to the JSON property exploitationActivity

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1495

def exploitation_activity
  @exploitation_activity
end

#first_exploitation_dateString

Date of the earliest known exploitation. Corresponds to the JSON property firstExploitationDate

Returns:

  • (String)


1500
1501
1502
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1500

def first_exploitation_date
  @first_exploitation_date
end

#idString

The unique identifier for the vulnerability. e.g. CVE-2021-34527 Corresponds to the JSON property id

Returns:

  • (String)


1505
1506
1507
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1505

def id
  @id
end

#impactString

The potential impact of the vulnerability if it was to be exploited. Corresponds to the JSON property impact

Returns:

  • (String)


1510
1511
1512
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1510

def impact
  @impact
end

#observed_in_the_wildBoolean Also known as: observed_in_the_wild?

Whether or not the vulnerability has been observed in the wild. Corresponds to the JSON property observedInTheWild

Returns:

  • (Boolean)


1515
1516
1517
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1515

def observed_in_the_wild
  @observed_in_the_wild
end

#referencesArray<Google::Apis::SecuritycenterV1beta2::Reference>

Additional information about the CVE. e.g. https://cve.mitre.org/cgi-bin/ cvename.cgi?name=CVE-2021-34527 Corresponds to the JSON property references



1522
1523
1524
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1522

def references
  @references
end

#upstream_fix_availableBoolean Also known as: upstream_fix_available?

Whether upstream fix is available for the CVE. Corresponds to the JSON property upstreamFixAvailable

Returns:

  • (Boolean)


1527
1528
1529
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1527

def upstream_fix_available
  @upstream_fix_available
end

#zero_dayBoolean Also known as: zero_day?

Whether or not the vulnerability was zero day when the finding was published. Corresponds to the JSON property zeroDay

Returns:

  • (Boolean)


1533
1534
1535
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1533

def zero_day
  @zero_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1541

def update!(**args)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @exploit_release_date = args[:exploit_release_date] if args.key?(:exploit_release_date)
  @exploitation_activity = args[:exploitation_activity] if args.key?(:exploitation_activity)
  @first_exploitation_date = args[:first_exploitation_date] if args.key?(:first_exploitation_date)
  @id = args[:id] if args.key?(:id)
  @impact = args[:impact] if args.key?(:impact)
  @observed_in_the_wild = args[:observed_in_the_wild] if args.key?(:observed_in_the_wild)
  @references = args[:references] if args.key?(:references)
  @upstream_fix_available = args[:upstream_fix_available] if args.key?(:upstream_fix_available)
  @zero_day = args[:zero_day] if args.key?(:zero_day)
end