Class: Google::Apis::SecuritycenterV1beta2::DataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about a data access attempt made by a principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataAccessEvent

Returns a new instance of DataAccessEvent.



1617
1618
1619
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


1599
1600
1601
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1599

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


1604
1605
1606
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1604

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


1609
1610
1611
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1609

def operation
  @operation
end

#principal_emailString

The email address of the principal that accessed the data. The principal could be a user account, service account, Google group, or other. Corresponds to the JSON property principalEmail

Returns:

  • (String)


1615
1616
1617
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1615

def principal_email
  @principal_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1622
1623
1624
1625
1626
1627
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1622

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_email = args[:principal_email] if args.key?(:principal_email)
end