Class: Google::Apis::SecuritycenterV1beta2::DataRetentionDeletionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataRetentionDeletionEvent

Returns a new instance of DataRetentionDeletionEvent.



1828
1829
1830
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_object_countFixnum

Number of objects that violated the policy for this resource. If the number is less than 1,000, then the value of this field is the exact number. If the number of objects that violated the policy is greater than or equal to 1,000, then the value of this field is 1000. Corresponds to the JSON property dataObjectCount

Returns:

  • (Fixnum)


1800
1801
1802
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1800

def data_object_count
  @data_object_count
end

#event_detection_timeString

Timestamp indicating when the event was detected. Corresponds to the JSON property eventDetectionTime

Returns:

  • (String)


1805
1806
1807
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1805

def event_detection_time
  @event_detection_time
end

#event_typeString

Type of the DRD event. Corresponds to the JSON property eventType

Returns:

  • (String)


1810
1811
1812
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1810

def event_type
  @event_type
end

#max_retention_allowedString

Maximum duration of retention allowed from the DRD control. This comes from the DRD control where users set a max TTL for their data. For example, suppose that a user sets the max TTL for a Cloud Storage bucket to 90 days. However, an object in that bucket is 100 days old. In this case, a DataRetentionDeletionEvent will be generated for that Cloud Storage bucket, and the max_retention_allowed is 90 days. Corresponds to the JSON property maxRetentionAllowed

Returns:

  • (String)


1820
1821
1822
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1820

def max_retention_allowed
  @max_retention_allowed
end

#min_retention_allowedString

Min duration of retention allowed from the DSPM retention control. This field is only populated when event type is set to EVENT_TYPE_MIN_TTL_FROM_CREATION. Corresponds to the JSON property minRetentionAllowed

Returns:

  • (String)


1826
1827
1828
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1826

def min_retention_allowed
  @min_retention_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1833
1834
1835
1836
1837
1838
1839
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1833

def update!(**args)
  @data_object_count = args[:data_object_count] if args.key?(:data_object_count)
  @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed)
  @min_retention_allowed = args[:min_retention_allowed] if args.key?(:min_retention_allowed)
end