Class: Google::Apis::SecuritycenterV1beta2::Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Database

Returns a new instance of Database.



1890
1891
1892
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The human-readable name of the database that the user connected to. Corresponds to the JSON property displayName

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1855

def display_name
  @display_name
end

#granteesArray<String>

The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change. Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


1861
1862
1863
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1861

def grantees
  @grantees
end

#nameString

Some database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In these cases only the display name will be provided. The full resource name of the database that the user connected to, if it is supported by Cloud Asset Inventory. Corresponds to the JSON property name

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1871

def name
  @name
end

#queryString

The SQL statement that is associated with the database access. Corresponds to the JSON property query

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1876

def query
  @query
end

#user_nameString

The username used to connect to the database. The username might not be an IAM principal and does not have a set format. Corresponds to the JSON property userName

Returns:

  • (String)


1882
1883
1884
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1882

def user_name
  @user_name
end

#versionString

The version of the database, for example, POSTGRES_14. See the complete list. Corresponds to the JSON property version

Returns:

  • (String)


1888
1889
1890
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1888

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1895

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @grantees = args[:grantees] if args.key?(:grantees)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
  @user_name = args[:user_name] if args.key?(:user_name)
  @version = args[:version] if args.key?(:version)
end