Class: Google::Apis::SecuritycenterV1beta2::Detection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Memory hash detection contributing to the binary family match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Detection

Returns a new instance of Detection.



2002
2003
2004
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binaryString

The name of the binary associated with the memory hash signature detection. Corresponds to the JSON property binary

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1995

def binary
  @binary
end

#percent_pages_matchedFloat

The percentage of memory page hashes in the signature that were matched. Corresponds to the JSON property percentPagesMatched

Returns:

  • (Float)


2000
2001
2002
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2000

def percent_pages_matched
  @percent_pages_matched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2007
2008
2009
2010
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2007

def update!(**args)
  @binary = args[:binary] if args.key?(:binary)
  @percent_pages_matched = args[:percent_pages_matched] if args.key?(:percent_pages_matched)
end