Class: Google::Apis::SecuritycenterV1beta2::DynamicMuteRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The record of a dynamic mute rule that matches the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicMuteRecord

Returns a new instance of DynamicMuteRecord.



2126
2127
2128
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#match_timeString

When the dynamic mute rule first matched the finding. Corresponds to the JSON property matchTime

Returns:

  • (String)


2117
2118
2119
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2117

def match_time
  @match_time
end

#mute_configString

The relative resource name of the mute rule, represented by a mute config, that created this record, for example organizations/123/muteConfigs/ mymuteconfig or organizations/123/locations/global/muteConfigs/mymuteconfig. Corresponds to the JSON property muteConfig

Returns:

  • (String)


2124
2125
2126
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2124

def mute_config
  @mute_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2131
2132
2133
2134
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2131

def update!(**args)
  @match_time = args[:match_time] if args.key?(:match_time)
  @mute_config = args[:mute_config] if args.key?(:mute_config)
end