Class: Google::Apis::SecuritycenterV1beta2::EventThreatDetectionSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::EventThreatDetectionSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource capturing the settings for the Event Threat Detection service.
Instance Attribute Summary collapse
-
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's different modules.
-
#name ⇒ String
Identifier.
-
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventThreatDetectionSettings
constructor
A new instance of EventThreatDetectionSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventThreatDetectionSettings
Returns a new instance of EventThreatDetectionSettings.
2097 2098 2099 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's
different modules. The absence of a module in the map implies its
configuration is inherited from its parent's configuration.
Corresponds to the JSON property modules
2077 2078 2079 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2077 def modules @modules end |
#name ⇒ String
Identifier. The resource name of the EventThreatDetectionSettings. Formats: *
organizations/organization/eventThreatDetectionSettings * folders/folder/
eventThreatDetectionSettings * projects/project/eventThreatDetectionSettings
Corresponds to the JSON property name
2084 2085 2086 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2084 def name @name end |
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
A DISABLED state will override all module enablement_states to DISABLED.
Corresponds to the JSON property serviceEnablementState
2090 2091 2092 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2090 def service_enablement_state @service_enablement_state end |
#update_time ⇒ String
Output only. The time the settings were last updated.
Corresponds to the JSON property updateTime
2095 2096 2097 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2095 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2102 2103 2104 2105 2106 2107 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2102 def update!(**args) @modules = args[:modules] if args.key?(:modules) @name = args[:name] if args.key?(:name) @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state) @update_time = args[:update_time] if args.key?(:update_time) end |