Class: Google::Apis::SecuritycenterV1beta2::ExfilResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource where data was exfiltrated from or exfiltrated to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExfilResource

Returns a new instance of ExfilResource.



2223
2224
2225
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#componentsArray<String>

Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames. For example, multiple tables might have been exfiltrated from the same Cloud SQL instance, or multiple files might have been exfiltrated from the same Cloud Storage bucket. Corresponds to the JSON property components

Returns:

  • (Array<String>)


2215
2216
2217
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2215

def components
  @components
end

#nameString

The resource's full resource name. Corresponds to the JSON property name

Returns:

  • (String)


2221
2222
2223
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2221

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2228
2229
2230
2231
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2228

def update!(**args)
  @components = args[:components] if args.key?(:components)
  @name = args[:name] if args.key?(:name)
end