Class: Google::Apis::SecuritycenterV1beta2::ExternalExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about the externally exposed resource associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalExposure

Returns a new instance of ExternalExposure.



2488
2489
2490
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucketString

The full resource name of the load balancer backend bucket, for example, "// compute.googleapis.com/projects/project-id/global/backendBuckets/name" Corresponds to the JSON property backendBucket

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2371

def backend_bucket
  @backend_bucket
end

#backend_serviceString

The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/project-id/global/backendServices/name". Corresponds to the JSON property backendService

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2377

def backend_service
  @backend_service
end

#exposed_applicationString

The name and version of the exposed web application, for example, "Jenkins 2. 184". Corresponds to the JSON property exposedApplication

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2383

def exposed_application
  @exposed_application
end

#exposed_endpointString

The resource which is running the exposed service, for example, "//compute. googleapis.com/projects/project-id/zones/zone/instances/instance.” Corresponds to the JSON property exposedEndpoint

Returns:

  • (String)


2389
2390
2391
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2389

def exposed_endpoint
  @exposed_endpoint
end

#exposed_serviceString

The name and version of the service, for example, "Jupyter Notebook 6.14.0". Corresponds to the JSON property exposedService

Returns:

  • (String)


2394
2395
2396
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2394

def exposed_service
  @exposed_service
end

#forwarding_ruleString

The full resource name of the forwarding rule, for example, "//compute. googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule- name". Corresponds to the JSON property forwardingRule

Returns:

  • (String)


2401
2402
2403
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2401

def forwarding_rule
  @forwarding_rule
end

#hostname_uriString

Hostname of the exposed application, for example, "https://test-app.a.run.app/" Corresponds to the JSON property hostnameUri

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2406

def hostname_uri
  @hostname_uri
end

#http_responseArray<Google::Apis::SecuritycenterV1beta2::HttpResponse>

The http response returned by the web application. Corresponds to the JSON property httpResponse



2411
2412
2413
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2411

def http_response
  @http_response
end

#instance_groupString

The full resource name of the instance group, for example, "//compute. googleapis.com/projects/project-id/global/instanceGroups/name". Corresponds to the JSON property instanceGroup

Returns:

  • (String)


2417
2418
2419
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2417

def instance_group
  @instance_group
end

#internal_backend_serviceString

The full resource name of load balancer backend service in the internal project having resource exposed via PSC, for example, "//compute.googleapis. com/projects/project-id/global/backendServices/name". Corresponds to the JSON property internalBackendService

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2424

def internal_backend_service
  @internal_backend_service
end

#load_balancer_firewall_policyString

The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/policy- name". Corresponds to the JSON property loadBalancerFirewallPolicy

Returns:

  • (String)


2431
2432
2433
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2431

def load_balancer_firewall_policy
  @load_balancer_firewall_policy
end

#network_endpoint_groupString

The full resource name of the network endpoint group, for example, "//compute. googleapis.com/projects/project-id/global/networkEndpointGroups/name". Corresponds to the JSON property networkEndpointGroup

Returns:

  • (String)


2437
2438
2439
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2437

def network_endpoint_group
  @network_endpoint_group
end

#network_ingress_firewall_policyString

The full resource name of the network ingress firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/name". Corresponds to the JSON property networkIngressFirewallPolicy

Returns:

  • (String)


2443
2444
2445
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2443

def network_ingress_firewall_policy
  @network_ingress_firewall_policy
end

#private_ip_addressString

Private IP address of the exposed endpoint. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


2448
2449
2450
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2448

def private_ip_address
  @private_ip_address
end

#private_portString

Port number associated with private IP address. Corresponds to the JSON property privatePort

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2453

def private_port
  @private_port
end

#psc_network_attachmentString

The full resource name of the PSC (Private Service Connect) network attachment that network interface controller is attached to, for example, "//compute. googleapis.com/projects/project-id/regions/region/networkAttachments/name " Corresponds to the JSON property pscNetworkAttachment

Returns:

  • (String)


2461
2462
2463
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2461

def psc_network_attachment
  @psc_network_attachment
end

#psc_service_attachmentString

The full resource name of the PSC (Private Service Connect) service attachment that the load balancer network endpoint group targets, for example, "//compute. googleapis.com/projects/project-id/regions/region/serviceAttachments/name " Corresponds to the JSON property pscServiceAttachment

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2469

def psc_service_attachment
  @psc_service_attachment
end

#public_ip_addressString

Public IP address of the exposed endpoint. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2474

def public_ip_address
  @public_ip_address
end

#public_portString

Public port number of the exposed endpoint. Corresponds to the JSON property publicPort

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2479

def public_port
  @public_port
end

#service_firewall_policyString

The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/project-id/global/ firewallPolicies/policy-name". Corresponds to the JSON property serviceFirewallPolicy

Returns:

  • (String)


2486
2487
2488
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2486

def service_firewall_policy
  @service_firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2493

def update!(**args)
  @backend_bucket = args[:backend_bucket] if args.key?(:backend_bucket)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @exposed_application = args[:exposed_application] if args.key?(:exposed_application)
  @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint)
  @exposed_service = args[:exposed_service] if args.key?(:exposed_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @hostname_uri = args[:hostname_uri] if args.key?(:hostname_uri)
  @http_response = args[:http_response] if args.key?(:http_response)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @internal_backend_service = args[:internal_backend_service] if args.key?(:internal_backend_service)
  @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy)
  @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group)
  @network_ingress_firewall_policy = args[:network_ingress_firewall_policy] if args.key?(:network_ingress_firewall_policy)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @private_port = args[:private_port] if args.key?(:private_port)
  @psc_network_attachment = args[:psc_network_attachment] if args.key?(:psc_network_attachment)
  @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @public_port = args[:public_port] if args.key?(:public_port)
  @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy)
end