Class: Google::Apis::SecuritycenterV1beta2::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



2570
2571
2572
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


2525
2526
2527
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2525

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1beta2::DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



2530
2531
2532
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2530

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


2535
2536
2537
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2535

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


2541
2542
2543
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2541

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1beta2::FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



2546
2547
2548
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2546

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


2551
2552
2553
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2551

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


2557
2558
2559
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2557

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


2563
2564
2565
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2563

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2568
2569
2570
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2568

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2575

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end