Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource

Returns a new instance of GoogleCloudSecuritycenterV1Resource.



3917
3918
3919
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta2::AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



3804
3805
3806
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3804

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta2::AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



3809
3810
3811
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3809

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta2::AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



3814
3815
3816
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3814

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



3819
3820
3821
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3819

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta2::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



3825
3826
3827
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3825

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta2::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



3831
3832
3833
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3831

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the resource resides in. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


3836
3837
3838
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3836

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


3841
3842
3843
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3841

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1beta2::Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



3848
3849
3850
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3848

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


3853
3854
3855
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3853

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


3859
3860
3861
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3859

def name
  @name
end

#organizationString

Indicates which organization or tenant in the cloud provider the finding applies to. Corresponds to the JSON property organization

Returns:

  • (String)


3865
3866
3867
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3865

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


3870
3871
3872
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3870

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


3875
3876
3877
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3875

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


3880
3881
3882
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3880

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


3885
3886
3887
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3885

def project_display_name
  @project_display_name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta2::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



3891
3892
3893
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3891

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


3904
3905
3906
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3904

def resource_path_string
  @resource_path_string
end

#serviceString

The parent service or product from which the resource is provided, for example, GKE or SNS. Corresponds to the JSON property service

Returns:

  • (String)


3910
3911
3912
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3910

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


3915
3916
3917
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3915

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3922
3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3922

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end