Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceValueConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceValueConfig

Returns a new instance of GoogleCloudSecuritycenterV1ResourceValueConfig.



3986
3987
3988
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_providerString

Cloud provider this configuration applies to Corresponds to the JSON property cloudProvider

Returns:

  • (String)


3921
3922
3923
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3921

def cloud_provider
  @cloud_provider
end

#create_timeString

Output only. Timestamp this resource value configuration was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3926
3927
3928
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3926

def create_time
  @create_time
end

#descriptionString

Description of the resource value configuration. Corresponds to the JSON property description

Returns:

  • (String)


3931
3932
3933
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3931

def description
  @description
end

#nameString

Name for the resource value configuration Corresponds to the JSON property name

Returns:

  • (String)


3936
3937
3938
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3936

def name
  @name
end

#resource_labels_selectorHash<String,String>

List of resource labels to search for, evaluated with AND. For example, " resource_labels_selector":"key": "value", "env": "prod"`will match resources with labels "key": "value"AND"env": "prod" https://cloud.google. com/resource-manager/docs/creating-managing-labels Corresponds to the JSON propertyresourceLabelsSelector`

Returns:

  • (Hash<String,String>)


3944
3945
3946
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3944

def resource_labels_selector
  @resource_labels_selector
end

#resource_typeString

Apply resource_value only to resources that match resource_type. resource_type will be checked with AND of other resources. For example, "storage. googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only to "storage.googleapis.com/Bucket" resources. Corresponds to the JSON property resourceType

Returns:

  • (String)


3952
3953
3954
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3952

def resource_type
  @resource_type
end

#resource_valueString

Required. Resource value level this expression represents Corresponds to the JSON property resourceValue

Returns:

  • (String)


3957
3958
3959
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3957

def resource_value
  @resource_value
end

#scopeString

Project or folder to scope this configuration to. For example, "project/456" would apply this configuration only to resources in "project/456" scope will be checked with AND of other resources. Corresponds to the JSON property scope

Returns:

  • (String)


3964
3965
3966
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3964

def scope
  @scope
end

#sensitive_data_protection_mappingGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping

Resource value mapping for Sensitive Data Protection findings. If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration. Corresponds to the JSON property sensitiveDataProtectionMapping



3971
3972
3973
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3971

def sensitive_data_protection_mapping
  @sensitive_data_protection_mapping
end

#tag_valuesArray<String>

Required. Tag values combined with AND to check against. For Google Cloud resources, they are tag value IDs in the form of "tagValues/123". Example: [ " tagValues/123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/ resource-manager/docs/tags/tags-creating-and-managing Corresponds to the JSON property tagValues

Returns:

  • (Array<String>)


3979
3980
3981
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3979

def tag_values
  @tag_values
end

#update_timeString

Output only. Timestamp this resource value configuration was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3984
3985
3986
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3984

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3991

def update!(**args)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @scope = args[:scope] if args.key?(:scope)
  @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping)
  @tag_values = args[:tag_values] if args.key?(:tag_values)
  @update_time = args[:update_time] if args.key?(:update_time)
end