Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource value mapping for Sensitive Data Protection findings. If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping

Returns a new instance of GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping.



4306
4307
4308
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#high_sensitivity_mappingString

Resource value mapping for high-sensitivity Sensitive Data Protection findings Corresponds to the JSON property highSensitivityMapping

Returns:

  • (String)


4298
4299
4300
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4298

def high_sensitivity_mapping
  @high_sensitivity_mapping
end

#medium_sensitivity_mappingString

Resource value mapping for medium-sensitivity Sensitive Data Protection findings Corresponds to the JSON property mediumSensitivityMapping

Returns:

  • (String)


4304
4305
4306
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4304

def medium_sensitivity_mapping
  @medium_sensitivity_mapping
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4311
4312
4313
4314
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4311

def update!(**args)
  @high_sensitivity_mapping = args[:high_sensitivity_mapping] if args.key?(:high_sensitivity_mapping)
  @medium_sensitivity_mapping = args[:medium_sensitivity_mapping] if args.key?(:medium_sensitivity_mapping)
end