Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1NotificationMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Security Command Center's Notification

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1NotificationMessage

Returns a new instance of GoogleCloudSecuritycenterV1p1beta1NotificationMessage.



4141
4142
4143
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#findingGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1Finding

Security Command Center finding. A finding is a record of assessment data ( security, risk, health or privacy) ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, an XSS vulnerability in an App Engine application is a finding. Corresponds to the JSON property finding



4129
4130
4131
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4129

def finding
  @finding
end

#notification_config_nameString

Name of the notification config that generated current notification. Corresponds to the JSON property notificationConfigName

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4134

def notification_config_name
  @notification_config_name
end

#resourceGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1Resource

Information related to the Google Cloud resource. Corresponds to the JSON property resource



4139
4140
4141
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4139

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4146
4147
4148
4149
4150
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4146

def update!(**args)
  @finding = args[:finding] if args.key?(:finding)
  @notification_config_name = args[:notification_config_name] if args.key?(:notification_config_name)
  @resource = args[:resource] if args.key?(:resource)
end