Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Access
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Access
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an access event.
Instance Attribute Summary collapse
-
#caller_ip ⇒ String
Caller's IP address, such as "1.1.1.1".
-
#caller_ip_geo ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Geolocation
Represents a geographical location for a given access.
-
#method_name ⇒ String
The method that the service account called, e.g.
-
#principal_email ⇒ String
Associated email, such as "foo@google.com".
-
#principal_subject ⇒ String
A string that represents the principal_subject that is associated with the identity.
-
#service_account_delegation_info ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo>
The identity delegation history of an authenticated service account that made the request.
-
#service_account_key_name ⇒ String
The name of the service account key that was used to create or exchange credentials when authenticating the service account that made the request.
-
#service_name ⇒ String
This is the API service that the service account made a call to, e.g.
-
#user_agent ⇒ String
The caller's user agent string associated with the finding.
-
#user_agent_family ⇒ String
Type of user agent associated with the finding.
-
#user_name ⇒ String
A string that represents a username.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Access
constructor
A new instance of GoogleCloudSecuritycenterV2Access.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Access
Returns a new instance of GoogleCloudSecuritycenterV2Access.
4667 4668 4669 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#caller_ip ⇒ String
Caller's IP address, such as "1.1.1.1".
Corresponds to the JSON property callerIp
4590 4591 4592 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4590 def caller_ip @caller_ip end |
#caller_ip_geo ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Geolocation
Represents a geographical location for a given access.
Corresponds to the JSON property callerIpGeo
4595 4596 4597 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4595 def caller_ip_geo @caller_ip_geo end |
#method_name ⇒ String
The method that the service account called, e.g. "SetIamPolicy".
Corresponds to the JSON property methodName
4600 4601 4602 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4600 def method_name @method_name end |
#principal_email ⇒ String
Associated email, such as "foo@google.com". The email address of the
authenticated user or a service account acting on behalf of a third party
principal making the request. For third party identity callers, the
principal_subject field is populated instead of this field. For privacy
reasons, the principal email address is sometimes redacted. For more
information, see Caller identities in audit logs.
Corresponds to the JSON property principalEmail
4611 4612 4613 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4611 def principal_email @principal_email end |
#principal_subject ⇒ String
A string that represents the principal_subject that is associated with the
identity. Unlike principal_email, principal_subject supports principals
that aren't associated with email addresses, such as third party principals.
For most identities, the format is principal://iam.googleapis.com/identity
pool name/subject/subject`. Some GKE identities, such as GKE_WORKLOAD,
FREEFORM, and GKE_HUB_WORKLOAD, still use the legacy formatserviceAccount:
identity pool name[subject].
Corresponds to the JSON propertyprincipalSubject`
4622 4623 4624 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4622 def principal_subject @principal_subject end |
#service_account_delegation_info ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo>
The identity delegation history of an authenticated service account that made
the request. The serviceAccountDelegationInfo[] object contains information
about the real authorities that try to access Google Cloud resources by
delegating on a service account. When multiple authorities are present, they
are guaranteed to be sorted based on the original ordering of the identity
delegation events.
Corresponds to the JSON property serviceAccountDelegationInfo
4632 4633 4634 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4632 def service_account_delegation_info @service_account_delegation_info end |
#service_account_key_name ⇒ String
The name of the service account key that was used to create or exchange
credentials when authenticating the service account that made the request.
This is a scheme-less URI full resource name. For example: "//iam.googleapis.
com/projects/PROJECT_ID/serviceAccounts/ACCOUNT/keys/key".
Corresponds to the JSON property serviceAccountKeyName
4640 4641 4642 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4640 def service_account_key_name @service_account_key_name end |
#service_name ⇒ String
This is the API service that the service account made a call to, e.g. "iam.
googleapis.com"
Corresponds to the JSON property serviceName
4646 4647 4648 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4646 def service_name @service_name end |
#user_agent ⇒ String
The caller's user agent string associated with the finding.
Corresponds to the JSON property userAgent
4651 4652 4653 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4651 def user_agent @user_agent end |
#user_agent_family ⇒ String
Type of user agent associated with the finding. For example, an operating
system shell or an embedded or standalone application.
Corresponds to the JSON property userAgentFamily
4657 4658 4659 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4657 def user_agent_family @user_agent_family end |
#user_name ⇒ String
A string that represents a username. The username provided depends on the type
of the finding and is likely not an IAM principal. For example, this can be a
system username if the finding is related to a virtual machine, or it can be
an application login username.
Corresponds to the JSON property userName
4665 4666 4667 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4665 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4672 4673 4674 4675 4676 4677 4678 4679 4680 4681 4682 4683 4684 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4672 def update!(**args) @caller_ip = args[:caller_ip] if args.key?(:caller_ip) @caller_ip_geo = args[:caller_ip_geo] if args.key?(:caller_ip_geo) @method_name = args[:method_name] if args.key?(:method_name) @principal_email = args[:principal_email] if args.key?(:principal_email) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @service_account_delegation_info = args[:service_account_delegation_info] if args.key?(:service_account_delegation_info) @service_account_key_name = args[:service_account_key_name] if args.key?(:service_account_key_name) @service_name = args[:service_name] if args.key?(:service_name) @user_agent = args[:user_agent] if args.key?(:user_agent) @user_agent_family = args[:user_agent_family] if args.key?(:user_agent_family) @user_name = args[:user_name] if args.key?(:user_name) end |