Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



4790
4791
4792
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


4756
4757
4758
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4756

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


4761
4762
4763
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4761

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


4767
4768
4769
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4767

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


4772
4773
4774
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4772

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


4777
4778
4779
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4777

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


4783
4784
4785
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4783

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


4788
4789
4790
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4788

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4795
4796
4797
4798
4799
4800
4801
4802
4803
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4795

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end