Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdaptiveProtection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AdaptiveProtection

Returns a new instance of GoogleCloudSecuritycenterV2AdaptiveProtection.



4821
4822
4823
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

A score of 0 means that there is low confidence that the detected event is an actual attack. A score of 1 means that there is high confidence that the detected event is an attack. See the Adaptive Protection documentation for further explanation. Corresponds to the JSON property confidence

Returns:

  • (Float)


4819
4820
4821
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4819

def confidence
  @confidence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4826
4827
4828
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4826

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
end