Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Application

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an application associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Application

Returns a new instance of GoogleCloudSecuritycenterV2Application.



4993
4994
4995
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_uriString

The base URI that identifies the network location of the application in which the vulnerability was detected. For example, http://example.com. Corresponds to the JSON property baseUri

Returns:

  • (String)


4985
4986
4987
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4985

def base_uri
  @base_uri
end

#full_uriString

The full URI with payload that could be used to reproduce the vulnerability. For example, http://example.com?p=aMmYgI6H. Corresponds to the JSON property fullUri

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4991

def full_uri
  @full_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4998
4999
5000
5001
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4998

def update!(**args)
  @base_uri = args[:base_uri] if args.key?(:base_uri)
  @full_uri = args[:full_uri] if args.key?(:full_uri)
end