Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicies
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicies
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents the result of evaluating artifact guard policies.
Instance Attribute Summary collapse
-
#failing_policies ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicy>
A list of failing policies.
-
#resource_id ⇒ String
The ID of the resource that has policies configured for it.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicies
constructor
A new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicies
Returns a new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicies.
4606 4607 4608 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failing_policies ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicy>
A list of failing policies.
Corresponds to the JSON property failingPolicies
4599 4600 4601 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4599 def failing_policies @failing_policies end |
#resource_id ⇒ String
The ID of the resource that has policies configured for it.
Corresponds to the JSON property resourceId
4604 4605 4606 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4604 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4611 4612 4613 4614 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4611 def update!(**args) @failing_policies = args[:failing_policies] if args.key?(:failing_policies) @resource_id = args[:resource_id] if args.key?(:resource_id) end |