Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicy
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an artifact guard policy.
Instance Attribute Summary collapse
-
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND max_vuln_count=2".
-
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/ global/policies/prod-policy".
-
#type ⇒ String
The type of the policy evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicy
constructor
A new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicy
Returns a new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicy.
4893 4894 4895 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND
max_vuln_count=2".
Corresponds to the JSON property failureReason
4880 4881 4882 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4880 def failure_reason @failure_reason end |
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/
global/policies/prod-policy".
Corresponds to the JSON property policyId
4886 4887 4888 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4886 def policy_id @policy_id end |
#type ⇒ String
The type of the policy evaluation.
Corresponds to the JSON property type
4891 4892 4893 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4891 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4898 4899 4900 4901 4902 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4898 def update!(**args) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @policy_id = args[:policy_id] if args.key?(:policy_id) @type = args[:type] if args.key?(:type) end |