Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
An attack exposure contains the results of an attack path simulation run.
Instance Attribute Summary collapse
-
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the details regarding this attack exposure score.
-
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this finding.
-
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
-
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this finding is to remediate.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure
constructor
A new instance of GoogleCloudSecuritycenterV2AttackExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure
Returns a new instance of GoogleCloudSecuritycenterV2AttackExposure.
5213 5214 5215 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the
details regarding this attack exposure score. Example: organizations/123/
simulations/456/attackExposureResults/789
Corresponds to the JSON property attackExposureResult
5175 5176 5177 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5175 def attack_exposure_result @attack_exposure_result end |
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedHighValueResourcesCount
5181 5182 5183 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5181 def exposed_high_value_resources_count @exposed_high_value_resources_count end |
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedLowValueResourcesCount
5187 5188 5189 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5187 def exposed_low_value_resources_count @exposed_low_value_resources_count end |
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedMediumValueResourcesCount
5193 5194 5195 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5193 def exposed_medium_value_resources_count @exposed_medium_value_resources_count end |
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
Corresponds to the JSON property latestCalculationTime
5198 5199 5200 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5198 def latest_calculation_time @latest_calculation_time end |
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this
finding is to remediate. The higher the score, the more important it is to
remediate.
Corresponds to the JSON property score
5205 5206 5207 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5205 def score @score end |
#state ⇒ String
Output only. What state this AttackExposure is in. This captures whether or
not an attack exposure has been calculated or not.
Corresponds to the JSON property state
5211 5212 5213 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5211 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5218 5219 5220 5221 5222 5223 5224 5225 5226 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5218 def update!(**args) @attack_exposure_result = args[:attack_exposure_result] if args.key?(:attack_exposure_result) @exposed_high_value_resources_count = args[:exposed_high_value_resources_count] if args.key?(:exposed_high_value_resources_count) @exposed_low_value_resources_count = args[:exposed_low_value_resources_count] if args.key?(:exposed_low_value_resources_count) @exposed_medium_value_resources_count = args[:exposed_medium_value_resources_count] if args.key?(:exposed_medium_value_resources_count) @latest_calculation_time = args[:latest_calculation_time] if args.key?(:latest_calculation_time) @score = args[:score] if args.key?(:score) @state = args[:state] if args.key?(:state) end |