Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AwsMetadata

Returns a new instance of GoogleCloudSecuritycenterV2AwsMetadata.



5218
5219
5220
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsAccount

An AWS account that is a member of an organization. Corresponds to the JSON property account



5203
5204
5205
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5203

def 
  @account
end

#organizationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsOrganization

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies. Corresponds to the JSON property organization



5210
5211
5212
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5210

def organization
  @organization
end

#organizational_unitsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsOrganizationalUnit>

A list of AWS organizational units associated with the resource, ordered from lowest level (closest to the account) to highest level. Corresponds to the JSON property organizationalUnits



5216
5217
5218
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5216

def organizational_units
  @organizational_units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5223
5224
5225
5226
5227
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5223

def update!(**args)
  @account = args[:account] if args.key?(:account)
  @organization = args[:organization] if args.key?(:organization)
  @organizational_units = args[:organizational_units] if args.key?(:organizational_units)
end