Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata

Returns a new instance of GoogleCloudSecuritycenterV2AzureMetadata.



5395
5396
5397
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_groupsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureManagementGroup>

A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level. Corresponds to the JSON property managementGroups



5378
5379
5380
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5378

def management_groups
  @management_groups
end

#resource_groupGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureResourceGroup

Represents an Azure resource group. Corresponds to the JSON property resourceGroup



5383
5384
5385
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5383

def resource_group
  @resource_group
end

#subscriptionGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureSubscription

Represents an Azure subscription. Corresponds to the JSON property subscription



5388
5389
5390
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5388

def subscription
  @subscription
end

#tenantGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureTenant

Represents a Microsoft Entra tenant. Corresponds to the JSON property tenant



5393
5394
5395
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5393

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5400
5401
5402
5403
5404
5405
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5400

def update!(**args)
  @management_groups = args[:management_groups] if args.key?(:management_groups)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @subscription = args[:subscription] if args.key?(:subscription)
  @tenant = args[:tenant] if args.key?(:tenant)
end