Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a Kubernetes RoleBinding or ClusterRoleBinding.
Instance Attribute Summary collapse
-
#name ⇒ String
Name for the binding.
-
#ns ⇒ String
Namespace for the binding.
-
#role ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
-
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
constructor
A new instance of GoogleCloudSecuritycenterV2Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
Returns a new instance of GoogleCloudSecuritycenterV2Binding.
5228 5229 5230 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name for the binding.
Corresponds to the JSON property name
5210 5211 5212 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5210 def name @name end |
#ns ⇒ String
Namespace for the binding.
Corresponds to the JSON property ns
5215 5216 5217 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5215 def ns @ns end |
#role ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
Corresponds to the JSON property role
5220 5221 5222 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5220 def role @role end |
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role. Not always
available for PATCH requests.
Corresponds to the JSON property subjects
5226 5227 5228 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5226 def subjects @subjects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5233 5234 5235 5236 5237 5238 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5233 def update!(**args) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @role = args[:role] if args.key?(:role) @subjects = args[:subjects] if args.key?(:subjects) end |