Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Chokepoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Chokepoint

Returns a new instance of GoogleCloudSecuritycenterV2Chokepoint.



5268
5269
5270
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of resource names of findings associated with this chokepoint. For example, organizations/123/sources/456/findings/789. This list will have at most 100 findings. Corresponds to the JSON property relatedFindings

Returns:

  • (Array<String>)


5266
5267
5268
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5266

def related_findings
  @related_findings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5273
5274
5275
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5273

def update!(**args)
  @related_findings = args[:related_findings] if args.key?(:related_findings)
end