Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The data profile associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile

Returns a new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.



5647
5648
5649
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profileString

Name of the data profile, for example, projects/123/locations/europe/ tableProfiles/8383929. Corresponds to the JSON property dataProfile

Returns:

  • (String)


5634
5635
5636
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5634

def data_profile
  @data_profile
end

#info_typesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2InfoType>

Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type. Corresponds to the JSON property infoTypes



5640
5641
5642
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5640

def info_types
  @info_types
end

#parent_typeString

The resource hierarchy level at which the data profile was generated. Corresponds to the JSON property parentType

Returns:

  • (String)


5645
5646
5647
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5645

def parent_type
  @parent_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5652
5653
5654
5655
5656
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5652

def update!(**args)
  @data_profile = args[:data_profile] if args.key?(:data_profile)
  @info_types = args[:info_types] if args.key?(:info_types)
  @parent_type = args[:parent_type] if args.key?(:parent_type)
end