Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Connection

Returns a new instance of GoogleCloudSecuritycenterV2Connection.



6054
6055
6056
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


6032
6033
6034
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6032

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


6037
6038
6039
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6037

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


6042
6043
6044
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6042

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


6047
6048
6049
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6047

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


6052
6053
6054
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6052

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6059
6060
6061
6062
6063
6064
6065
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6059

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end