Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Container

Returns a new instance of GoogleCloudSecuritycenterV2Container.



6078
6079
6080
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6054
6055
6056
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6054

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


6060
6061
6062
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6060

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



6065
6066
6067
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6065

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


6070
6071
6072
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6070

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


6076
6077
6078
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6076

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6083
6084
6085
6086
6087
6088
6089
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6083

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end