Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Cvssv3
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Cvssv3
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Common Vulnerability Scoring System version 3.
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
This metric describes the conditions beyond the attacker's control that must exist in order to exploit the vulnerability.
-
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments.
-
#availability_impact ⇒ String
This metric measures the impact to the availability of the impacted component resulting from a successfully exploited vulnerability.
-
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
This metric measures the impact to the confidentiality of the information resources managed by a software component due to a successfully exploited vulnerability.
-
#integrity_impact ⇒ String
This metric measures the impact to integrity of a successfully exploited vulnerability.
-
#privileges_required ⇒ String
This metric describes the level of privileges an attacker must possess before successfully exploiting the vulnerability.
-
#scope ⇒ String
The Scope metric captures whether a vulnerability in one vulnerable component impacts resources in components beyond its security scope.
-
#user_interaction ⇒ String
This metric captures the requirement for a human user, other than the attacker, to participate in the successful compromise of the vulnerable component.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Cvssv3
constructor
A new instance of GoogleCloudSecuritycenterV2Cvssv3.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Cvssv3
Returns a new instance of GoogleCloudSecuritycenterV2Cvssv3.
6314 6315 6316 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
This metric describes the conditions beyond the attacker's control that must
exist in order to exploit the vulnerability.
Corresponds to the JSON property attackComplexity
6263 6264 6265 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6263 def attack_complexity @attack_complexity end |
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that
are constant over time and across user environments. This metric reflects the
context by which vulnerability exploitation is possible.
Corresponds to the JSON property attackVector
6270 6271 6272 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6270 def attack_vector @attack_vector end |
#availability_impact ⇒ String
This metric measures the impact to the availability of the impacted component
resulting from a successfully exploited vulnerability.
Corresponds to the JSON property availabilityImpact
6276 6277 6278 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6276 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
6281 6282 6283 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6281 def base_score @base_score end |
#confidentiality_impact ⇒ String
This metric measures the impact to the confidentiality of the information
resources managed by a software component due to a successfully exploited
vulnerability.
Corresponds to the JSON property confidentialityImpact
6288 6289 6290 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6288 def confidentiality_impact @confidentiality_impact end |
#integrity_impact ⇒ String
This metric measures the impact to integrity of a successfully exploited
vulnerability.
Corresponds to the JSON property integrityImpact
6294 6295 6296 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6294 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
This metric describes the level of privileges an attacker must possess before
successfully exploiting the vulnerability.
Corresponds to the JSON property privilegesRequired
6300 6301 6302 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6300 def privileges_required @privileges_required end |
#scope ⇒ String
The Scope metric captures whether a vulnerability in one vulnerable component
impacts resources in components beyond its security scope.
Corresponds to the JSON property scope
6306 6307 6308 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6306 def scope @scope end |
#user_interaction ⇒ String
This metric captures the requirement for a human user, other than the attacker,
to participate in the successful compromise of the vulnerable component.
Corresponds to the JSON property userInteraction
6312 6313 6314 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6312 def user_interaction @user_interaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6319 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) end |