Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about a data access attempt made by a principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataAccessEvent

Returns a new instance of GoogleCloudSecuritycenterV2DataAccessEvent.



6326
6327
6328
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


6308
6309
6310
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6308

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


6313
6314
6315
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6313

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


6318
6319
6320
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6318

def operation
  @operation
end

#principal_emailString

The email address of the principal that accessed the data. The principal could be a user account, service account, Google group, or other. Corresponds to the JSON property principalEmail

Returns:

  • (String)


6324
6325
6326
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6324

def principal_email
  @principal_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6331
6332
6333
6334
6335
6336
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6331

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_email = args[:principal_email] if args.key?(:principal_email)
end