Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataFlowEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataFlowEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Details about a data flow event, in which either the data is moved to or is accessed from a non-compliant geo-location, as defined in the applicable data security policy.
Instance Attribute Summary collapse
-
#event_id ⇒ String
Unique identifier for data flow event.
-
#event_time ⇒ String
Timestamp of data flow event.
-
#operation ⇒ String
The operation performed by the principal for the data flow event.
-
#principal_email ⇒ String
The email address of the principal that initiated the data flow event.
-
#violated_location ⇒ String
Non-compliant location of the principal or the data destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataFlowEvent
constructor
A new instance of GoogleCloudSecuritycenterV2DataFlowEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataFlowEvent
Returns a new instance of GoogleCloudSecuritycenterV2DataFlowEvent.
6430 6431 6432 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
Unique identifier for data flow event.
Corresponds to the JSON property eventId
6407 6408 6409 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6407 def event_id @event_id end |
#event_time ⇒ String
Timestamp of data flow event.
Corresponds to the JSON property eventTime
6412 6413 6414 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6412 def event_time @event_time end |
#operation ⇒ String
The operation performed by the principal for the data flow event.
Corresponds to the JSON property operation
6417 6418 6419 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6417 def operation @operation end |
#principal_email ⇒ String
The email address of the principal that initiated the data flow event. The
principal could be a user account, service account, Google group, or other.
Corresponds to the JSON property principalEmail
6423 6424 6425 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6423 def principal_email @principal_email end |
#violated_location ⇒ String
Non-compliant location of the principal or the data destination.
Corresponds to the JSON property violatedLocation
6428 6429 6430 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6428 def violated_location @violated_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6435 6436 6437 6438 6439 6440 6441 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6435 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @operation = args[:operation] if args.key?(:operation) @principal_email = args[:principal_email] if args.key?(:principal_email) @violated_location = args[:violated_location] if args.key?(:violated_location) end |