Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Detection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Memory hash detection contributing to the binary family match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Detection

Returns a new instance of GoogleCloudSecuritycenterV2Detection.



6410
6411
6412
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binaryString

The name of the binary associated with the memory hash signature detection. Corresponds to the JSON property binary

Returns:

  • (String)


6403
6404
6405
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6403

def binary
  @binary
end

#percent_pages_matchedFloat

The percentage of memory page hashes in the signature that were matched. Corresponds to the JSON property percentPagesMatched

Returns:

  • (Float)


6408
6409
6410
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6408

def percent_pages_matched
  @percent_pages_matched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6415
6416
6417
6418
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6415

def update!(**args)
  @binary = args[:binary] if args.key?(:binary)
  @percent_pages_matched = args[:percent_pages_matched] if args.key?(:percent_pages_matched)
end