Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ExternalExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about the externally exposed resource associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalExposure

Returns a new instance of GoogleCloudSecuritycenterV2ExternalExposure.



6985
6986
6987
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucketString

The full resource name of the load balancer backend bucket, for example, "// compute.googleapis.com/projects/project-id/global/backendBuckets/name" Corresponds to the JSON property backendBucket

Returns:

  • (String)


6868
6869
6870
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6868

def backend_bucket
  @backend_bucket
end

#backend_serviceString

The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/project-id/global/backendServices/name". Corresponds to the JSON property backendService

Returns:

  • (String)


6874
6875
6876
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6874

def backend_service
  @backend_service
end

#exposed_applicationString

The name and version of the exposed web application, for example, "Jenkins 2. 184". Corresponds to the JSON property exposedApplication

Returns:

  • (String)


6880
6881
6882
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6880

def exposed_application
  @exposed_application
end

#exposed_endpointString

The resource which is running the exposed service, for example, "//compute. googleapis.com/projects/project-id/zones/zone/instances/instance.” Corresponds to the JSON property exposedEndpoint

Returns:

  • (String)


6886
6887
6888
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6886

def exposed_endpoint
  @exposed_endpoint
end

#exposed_serviceString

The name and version of the service, for example, "Jupyter Notebook 6.14.0". Corresponds to the JSON property exposedService

Returns:

  • (String)


6891
6892
6893
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6891

def exposed_service
  @exposed_service
end

#forwarding_ruleString

The full resource name of the forwarding rule, for example, "//compute. googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule- name". Corresponds to the JSON property forwardingRule

Returns:

  • (String)


6898
6899
6900
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6898

def forwarding_rule
  @forwarding_rule
end

#hostname_uriString

Hostname of the exposed application, for example, "https://test-app.a.run.app/" Corresponds to the JSON property hostnameUri

Returns:

  • (String)


6903
6904
6905
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6903

def hostname_uri
  @hostname_uri
end

#http_responseArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2HttpResponse>

The http response returned by the web application. Corresponds to the JSON property httpResponse



6908
6909
6910
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6908

def http_response
  @http_response
end

#instance_groupString

The full resource name of the instance group, for example, "//compute. googleapis.com/projects/project-id/global/instanceGroups/name". Corresponds to the JSON property instanceGroup

Returns:

  • (String)


6914
6915
6916
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6914

def instance_group
  @instance_group
end

#internal_backend_serviceString

The full resource name of load balancer backend service in the internal project having resource exposed via PSC, for example, "//compute.googleapis. com/projects/project-id/global/backendServices/name". Corresponds to the JSON property internalBackendService

Returns:

  • (String)


6921
6922
6923
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6921

def internal_backend_service
  @internal_backend_service
end

#load_balancer_firewall_policyString

The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/policy- name". Corresponds to the JSON property loadBalancerFirewallPolicy

Returns:

  • (String)


6928
6929
6930
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6928

def load_balancer_firewall_policy
  @load_balancer_firewall_policy
end

#network_endpoint_groupString

The full resource name of the network endpoint group, for example, "//compute. googleapis.com/projects/project-id/global/networkEndpointGroups/name". Corresponds to the JSON property networkEndpointGroup

Returns:

  • (String)


6934
6935
6936
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6934

def network_endpoint_group
  @network_endpoint_group
end

#network_ingress_firewall_policyString

The full resource name of the network ingress firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/name". Corresponds to the JSON property networkIngressFirewallPolicy

Returns:

  • (String)


6940
6941
6942
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6940

def network_ingress_firewall_policy
  @network_ingress_firewall_policy
end

#private_ip_addressString

Private IP address of the exposed endpoint. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


6945
6946
6947
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6945

def private_ip_address
  @private_ip_address
end

#private_portString

Port number associated with private IP address. Corresponds to the JSON property privatePort

Returns:

  • (String)


6950
6951
6952
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6950

def private_port
  @private_port
end

#psc_network_attachmentString

The full resource name of the PSC (Private Service Connect) network attachment that network interface controller is attached to, for example, "//compute. googleapis.com/projects/project-id/regions/region/networkAttachments/name " Corresponds to the JSON property pscNetworkAttachment

Returns:

  • (String)


6958
6959
6960
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6958

def psc_network_attachment
  @psc_network_attachment
end

#psc_service_attachmentString

The full resource name of the PSC (Private Service Connect) service attachment that the load balancer network endpoint group targets, for example, "//compute. googleapis.com/projects/project-id/regions/region/serviceAttachments/name " Corresponds to the JSON property pscServiceAttachment

Returns:

  • (String)


6966
6967
6968
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6966

def psc_service_attachment
  @psc_service_attachment
end

#public_ip_addressString

Public IP address of the exposed endpoint. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


6971
6972
6973
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6971

def public_ip_address
  @public_ip_address
end

#public_portString

Public port number of the exposed endpoint. Corresponds to the JSON property publicPort

Returns:

  • (String)


6976
6977
6978
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6976

def public_port
  @public_port
end

#service_firewall_policyString

The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/project-id/global/ firewallPolicies/policy-name". Corresponds to the JSON property serviceFirewallPolicy

Returns:

  • (String)


6983
6984
6985
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6983

def service_firewall_policy
  @service_firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6990

def update!(**args)
  @backend_bucket = args[:backend_bucket] if args.key?(:backend_bucket)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @exposed_application = args[:exposed_application] if args.key?(:exposed_application)
  @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint)
  @exposed_service = args[:exposed_service] if args.key?(:exposed_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @hostname_uri = args[:hostname_uri] if args.key?(:hostname_uri)
  @http_response = args[:http_response] if args.key?(:http_response)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @internal_backend_service = args[:internal_backend_service] if args.key?(:internal_backend_service)
  @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy)
  @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group)
  @network_ingress_firewall_policy = args[:network_ingress_firewall_policy] if args.key?(:network_ingress_firewall_policy)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @private_port = args[:private_port] if args.key?(:private_port)
  @psc_network_attachment = args[:psc_network_attachment] if args.key?(:psc_network_attachment)
  @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @public_port = args[:public_port] if args.key?(:public_port)
  @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy)
end