Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
File information about the related binary/library used by an executable, or the script used by a script interpreter
Instance Attribute Summary collapse
-
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
-
#disk_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DiskPath
Path of the file in terms of underlying disk/partition identifiers.
-
#file_load_state ⇒ String
The load state of the file.
-
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed.
-
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2FileOperation>
Operation(s) performed on a file.
-
#partially_hashed ⇒ Boolean
(also: #partially_hashed?)
True when the hash covers only a prefix of the file.
-
#path ⇒ String
Absolute path of the file as a JSON encoded string.
-
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
-
#size ⇒ Fixnum
Size of the file in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2File
constructor
A new instance of GoogleCloudSecuritycenterV2File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2File
Returns a new instance of GoogleCloudSecuritycenterV2File.
6824 6825 6826 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
Corresponds to the JSON property contents
6779 6780 6781 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6779 def contents @contents end |
#disk_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DiskPath
Path of the file in terms of underlying disk/partition identifiers.
Corresponds to the JSON property diskPath
6784 6785 6786 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6784 def disk_path @disk_path end |
#file_load_state ⇒ String
The load state of the file.
Corresponds to the JSON property fileLoadState
6789 6790 6791 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6789 def file_load_state @file_load_state end |
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed. If hashed_size == size,
any hashes reported represent the entire file.
Corresponds to the JSON property hashedSize
6795 6796 6797 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6795 def hashed_size @hashed_size end |
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2FileOperation>
Operation(s) performed on a file.
Corresponds to the JSON property operations
6800 6801 6802 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6800 def operations @operations end |
#partially_hashed ⇒ Boolean Also known as: partially_hashed?
True when the hash covers only a prefix of the file.
Corresponds to the JSON property partiallyHashed
6805 6806 6807 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6805 def partially_hashed @partially_hashed end |
#path ⇒ String
Absolute path of the file as a JSON encoded string.
Corresponds to the JSON property path
6811 6812 6813 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6811 def path @path end |
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
If hashed_size == size, sha256 represents the SHA256 hash of the entire file.
Corresponds to the JSON property sha256
6817 6818 6819 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6817 def sha256 @sha256 end |
#size ⇒ Fixnum
Size of the file in bytes.
Corresponds to the JSON property size
6822 6823 6824 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6822 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6829 def update!(**args) @contents = args[:contents] if args.key?(:contents) @disk_path = args[:disk_path] if args.key?(:disk_path) @file_load_state = args[:file_load_state] if args.key?(:file_load_state) @hashed_size = args[:hashed_size] if args.key?(:hashed_size) @operations = args[:operations] if args.key?(:operations) @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed) @path = args[:path] if args.key?(:path) @sha256 = args[:sha256] if args.key?(:sha256) @size = args[:size] if args.key?(:size) end |