Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Framework

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Compliance framework associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework

Returns a new instance of GoogleCloudSecuritycenterV2Framework.



7658
7659
7660
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryArray<String>

Category of the framework associated with the finding. E.g. Security Benchmark, or Assured Workloads Corresponds to the JSON property category

Returns:

  • (Array<String>)


7632
7633
7634
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7632

def category
  @category
end

#controlsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Control>

The controls associated with the framework. Corresponds to the JSON property controls



7637
7638
7639
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7637

def controls
  @controls
end

#display_nameString

Display name of the framework. For a standard framework, this will look like e. g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined string like MyFramework Corresponds to the JSON property displayName

Returns:

  • (String)


7644
7645
7646
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7644

def display_name
  @display_name
end

#nameString

Name of the framework associated with the finding Corresponds to the JSON property name

Returns:

  • (String)


7649
7650
7651
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7649

def name
  @name
end

#typeString

Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property type

Returns:

  • (String)


7656
7657
7658
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7656

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7663
7664
7665
7666
7667
7668
7669
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7663

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @controls = args[:controls] if args.key?(:controls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end