Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The http response returned by the web application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2HttpResponse

Returns a new instance of GoogleCloudSecuritycenterV2HttpResponse.



7850
7851
7852
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

The http path for which response code was returned by web application, for example, "https://test-app.a.run.app/test". Corresponds to the JSON property path

Returns:

  • (String)


7843
7844
7845
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7843

def path
  @path
end

#status_codeString

The http response code returned by the web application, for example, 200. Corresponds to the JSON property statusCode

Returns:

  • (String)


7848
7849
7850
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7848

def status_code
  @status_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7855
7856
7857
7858
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7855

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @status_code = args[:status_code] if args.key?(:status_code)
end