Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IamBinding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IamBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a particular IAM binding, which captures a member's role addition, removal, or state.
Instance Attribute Summary collapse
-
#action ⇒ String
The action that was performed on a Binding.
-
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example, "foo@google.com".
-
#role ⇒ String
Role that is assigned to "members".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
constructor
A new instance of GoogleCloudSecuritycenterV2IamBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
Returns a new instance of GoogleCloudSecuritycenterV2IamBinding.
7739 7740 7741 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action that was performed on a Binding.
Corresponds to the JSON property action
7725 7726 7727 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7725 def action @action end |
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example,
"foo@google.com".
Corresponds to the JSON property member
7731 7732 7733 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7731 def member @member end |
#role ⇒ String
Role that is assigned to "members". For example, "roles/viewer", "roles/editor"
, or "roles/owner".
Corresponds to the JSON property role
7737 7738 7739 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7737 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7744 7745 7746 7747 7748 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7744 def update!(**args) @action = args[:action] if args.key?(:action) @member = args[:member] if args.key?(:member) @role = args[:role] if args.key?(:role) end |