Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IpRules

Returns a new instance of GoogleCloudSecuritycenterV2IpRules.



7898
7899
7900
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Allowed

Allowed IP rule. Corresponds to the JSON property allowed



7865
7866
7867
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7865

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Denied

Denied IP rule. Corresponds to the JSON property denied



7870
7871
7872
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7870

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


7877
7878
7879
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7877

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


7882
7883
7884
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7882

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


7889
7890
7891
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7889

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


7896
7897
7898
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7896

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7903
7904
7905
7906
7907
7908
7909
7910
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7903

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end