Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Issue
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Security Command Center Issue.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The description of the issue in Markdown format.
-
#detection ⇒ String
The finding category or rule name that generated the issue.
-
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
-
#exposure_score ⇒ Float
The exposure score of the issue.
-
#issue_type ⇒ String
The type of the issue.
-
#last_observation_time ⇒ String
The time the issue was last observed.
-
#mute ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
-
#name ⇒ String
Identifier.
-
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
-
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
-
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
-
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
-
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
-
#severity ⇒ String
The severity of the issue.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
constructor
A new instance of GoogleCloudSecuritycenterV2Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
Returns a new instance of GoogleCloudSecuritycenterV2Issue.
7409 7410 7411 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the issue was created.
Corresponds to the JSON property createTime
7326 7327 7328 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7326 def create_time @create_time end |
#description ⇒ String
The description of the issue in Markdown format.
Corresponds to the JSON property description
7331 7332 7333 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7331 def description @description end |
#detection ⇒ String
The finding category or rule name that generated the issue.
Corresponds to the JSON property detection
7336 7337 7338 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7336 def detection @detection end |
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
Corresponds to the JSON property domains
7341 7342 7343 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7341 def domains @domains end |
#exposure_score ⇒ Float
The exposure score of the issue.
Corresponds to the JSON property exposureScore
7346 7347 7348 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7346 def exposure_score @exposure_score end |
#issue_type ⇒ String
The type of the issue.
Corresponds to the JSON property issueType
7351 7352 7353 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7351 def issue_type @issue_type end |
#last_observation_time ⇒ String
The time the issue was last observed.
Corresponds to the JSON property lastObservationTime
7356 7357 7358 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7356 def last_observation_time @last_observation_time end |
#mute ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
Corresponds to the JSON property mute
7361 7362 7363 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7361 def mute @mute end |
#name ⇒ String
Identifier. The name of the issue. Format: organizations/organization/
locations/location/issues/issue
Corresponds to the JSON property name
7367 7368 7369 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7367 def name @name end |
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
Corresponds to the JSON property primaryResource
7372 7373 7374 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7372 def primary_resource @primary_resource end |
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
Corresponds to the JSON property relatedFindings
7377 7378 7379 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7377 def @related_findings end |
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
Corresponds to the JSON property remediations
7382 7383 7384 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7382 def remediations @remediations end |
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
Corresponds to the JSON property secondaryResources
7387 7388 7389 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7387 def secondary_resources @secondary_resources end |
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
Corresponds to the JSON property securityContexts
7392 7393 7394 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7392 def security_contexts @security_contexts end |
#severity ⇒ String
The severity of the issue.
Corresponds to the JSON property severity
7397 7398 7399 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7397 def severity @severity end |
#state ⇒ String
Output only. The state of the issue.
Corresponds to the JSON property state
7402 7403 7404 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7402 def state @state end |
#update_time ⇒ String
Output only. The time the issue was last updated.
Corresponds to the JSON property updateTime
7407 7408 7409 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7407 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 7427 7428 7429 7430 7431 7432 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7414 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @detection = args[:detection] if args.key?(:detection) @domains = args[:domains] if args.key?(:domains) @exposure_score = args[:exposure_score] if args.key?(:exposure_score) @issue_type = args[:issue_type] if args.key?(:issue_type) @last_observation_time = args[:last_observation_time] if args.key?(:last_observation_time) @mute = args[:mute] if args.key?(:mute) @name = args[:name] if args.key?(:name) @primary_resource = args[:primary_resource] if args.key?(:primary_resource) @related_findings = args[:related_findings] if args.key?(:related_findings) @remediations = args[:remediations] if args.key?(:remediations) @secondary_resources = args[:secondary_resources] if args.key?(:secondary_resources) @security_contexts = args[:security_contexts] if args.key?(:security_contexts) @severity = args[:severity] if args.key?(:severity) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |