Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



8501
8502
8503
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



8479
8480
8481
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8479

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



8484
8485
8486
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8484

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



8489
8490
8491
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8489

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



8494
8495
8496
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8494

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



8499
8500
8501
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8499

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8506
8507
8508
8509
8510
8511
8512
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8506

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end