Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The AWS metadata of a resource associated with an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadata.



8199
8200
8201
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

The AWS account of the resource associated with the issue. Corresponds to the JSON property account



8197
8198
8199
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8197

def 
  @account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8204
8205
8206
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8204

def update!(**args)
  @account = args[:account] if args.key?(:account)
end