Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The AWS account of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount.



7781
7782
7783
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The AWS account ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


7774
7775
7776
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7774

def id
  @id
end

#nameString

The AWS account name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


7779
7780
7781
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7779

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7786
7787
7788
7789
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7786

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
end