Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The Azure subscription of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription.



8505
8506
8507
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The Azure subscription display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8498
8499
8500
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8498

def display_name
  @display_name
end

#idString

The Azure subscription ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


8503
8504
8505
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8503

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8510
8511
8512
8513
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8510

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end