Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job

Returns a new instance of GoogleCloudSecuritycenterV2Job.



8778
8779
8780
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


8761
8762
8763
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8761

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


8766
8767
8768
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8766

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


8771
8772
8773
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8771

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


8776
8777
8778
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8776

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8783
8784
8785
8786
8787
8788
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8783

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end