Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes

Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.



8921
8922
8923
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



8880
8881
8882
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8880

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



8887
8888
8889
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8887

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



8894
8895
8896
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8894

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



8900
8901
8902
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8900

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



8905
8906
8907
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8905

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



8912
8913
8914
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8912

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



8919
8920
8921
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8919

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8926
8927
8928
8929
8930
8931
8932
8933
8934
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8926

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end