Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MemoryHashSignature
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MemoryHashSignature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A signature corresponding to memory page hashes.
Instance Attribute Summary collapse
-
#binary_family ⇒ String
The binary family.
-
#detections ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Detection>
The list of memory hash detections contributing to the binary family match.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MemoryHashSignature
constructor
A new instance of GoogleCloudSecuritycenterV2MemoryHashSignature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MemoryHashSignature
Returns a new instance of GoogleCloudSecuritycenterV2MemoryHashSignature.
9019 9020 9021 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binary_family ⇒ String
The binary family.
Corresponds to the JSON property binaryFamily
9012 9013 9014 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9012 def binary_family @binary_family end |
#detections ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Detection>
The list of memory hash detections contributing to the binary family match.
Corresponds to the JSON property detections
9017 9018 9019 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9017 def detections @detections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9024 9025 9026 9027 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9024 def update!(**args) @binary_family = args[:binary_family] if args.key?(:binary_family) @detections = args[:detections] if args.key?(:detections) end |