Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
constructor
A new instance of GoogleCloudSecuritycenterV2Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
Returns a new instance of GoogleCloudSecuritycenterV2Notebook.
9147 9148 9149 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
9130 9131 9132 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9130 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
9135 9136 9137 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9135 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
9140 9141 9142 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9140 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
9145 9146 9147 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9145 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9152 9153 9154 9155 9156 9157 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9152 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |