Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NotificationMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Cloud SCC's Notification

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2NotificationMessage

Returns a new instance of GoogleCloudSecuritycenterV2NotificationMessage.



9327
9328
9329
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#findingGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Finding

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding. Corresponds to the JSON property finding



9315
9316
9317
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9315

def finding
  @finding
end

#notification_config_nameString

Name of the notification config that generated current notification. Corresponds to the JSON property notificationConfigName

Returns:

  • (String)


9320
9321
9322
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9320

def notification_config_name
  @notification_config_name
end

#resourceGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource

Information related to the Google Cloud resource. Corresponds to the JSON property resource



9325
9326
9327
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9325

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9332
9333
9334
9335
9336
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9332

def update!(**args)
  @finding = args[:finding] if args.key?(:finding)
  @notification_config_name = args[:notification_config_name] if args.key?(:notification_config_name)
  @resource = args[:resource] if args.key?(:resource)
end