Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object

Returns a new instance of GoogleCloudSecuritycenterV2Object.



9372
9373
9374
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



9347
9348
9349
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9347

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


9352
9353
9354
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9352

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


9357
9358
9359
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9357

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


9363
9364
9365
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9363

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


9370
9371
9372
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9370

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9377
9378
9379
9380
9381
9382
9383
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9377

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end