Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Package is a generic definition of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Package

Returns a new instance of GoogleCloudSecuritycenterV2Package.



9430
9431
9432
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

The CPE URI where the vulnerability was detected. Corresponds to the JSON property cpeUri

Returns:

  • (String)


9413
9414
9415
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9413

def cpe_uri
  @cpe_uri
end

#package_nameString

The name of the package where the vulnerability was detected. Corresponds to the JSON property packageName

Returns:

  • (String)


9418
9419
9420
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9418

def package_name
  @package_name
end

#package_typeString

Type of package, for example, os, maven, or go. Corresponds to the JSON property packageType

Returns:

  • (String)


9423
9424
9425
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9423

def package_type
  @package_type
end

#package_versionString

The version of the package. Corresponds to the JSON property packageVersion

Returns:

  • (String)


9428
9429
9430
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9428

def package_version
  @package_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9435
9436
9437
9438
9439
9440
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9435

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @package_name = args[:package_name] if args.key?(:package_name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @package_version = args[:package_version] if args.key?(:package_version)
end