Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2PolicyDriftDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The policy field that violates the deployed posture and its expected and detected values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PolicyDriftDetails

Returns a new instance of GoogleCloudSecuritycenterV2PolicyDriftDetails.



9147
9148
9149
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_valueString

The detected value that violates the deployed posture, for example, false or allowed_values="projects/22831892"`. Corresponds to the JSON propertydetectedValue`

Returns:

  • (String)


9133
9134
9135
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9133

def detected_value
  @detected_value
end

#expected_valueString

The value of this field that was configured in a posture, for example, true or allowed_values="projects/29831892"`. Corresponds to the JSON propertyexpectedValue`

Returns:

  • (String)


9139
9140
9141
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9139

def expected_value
  @expected_value
end

#fieldString

The name of the updated field, for example constraint.implementation. policy_rules[0].enforce Corresponds to the JSON property field

Returns:

  • (String)


9145
9146
9147
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9145

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9152
9153
9154
9155
9156
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9152

def update!(**args)
  @detected_value = args[:detected_value] if args.key?(:detected_value)
  @expected_value = args[:expected_value] if args.key?(:expected_value)
  @field = args[:field] if args.key?(:field)
end