Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



9884
9885
9886
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



9799
9800
9801
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9799

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



9804
9805
9806
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9804

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



9809
9810
9811
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9809

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



9814
9815
9816
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9814

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



9820
9821
9822
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9820

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



9826
9827
9828
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9826

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


9831
9832
9833
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9831

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


9836
9837
9838
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9836

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1beta2::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



9842
9843
9844
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9842

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


9847
9848
9849
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9847

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


9853
9854
9855
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9853

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



9859
9860
9861
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9859

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


9872
9873
9874
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9872

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


9877
9878
9879
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9877

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


9882
9883
9884
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9882

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9889

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end