Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents the path of resources leading up to the resource this finding is about.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePath

Returns a new instance of GoogleCloudSecuritycenterV2ResourcePath.



9620
9621
9622
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode>

The list of nodes that make the up resource path, ordered from lowest level to highest level. Corresponds to the JSON property nodes



9618
9619
9620
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9618

def nodes
  @nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9625
9626
9627
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9625

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
end