Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode

Returns a new instance of GoogleCloudSecuritycenterV2ResourcePathNode.



10075
10076
10077
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


10063
10064
10065
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10063

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


10068
10069
10070
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10068

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


10073
10074
10075
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10073

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10080
10081
10082
10083
10084
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10080

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end