Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceValueConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceValueConfig

Returns a new instance of GoogleCloudSecuritycenterV2ResourceValueConfig.



10161
10162
10163
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_providerString

Cloud provider this configuration applies to Corresponds to the JSON property cloudProvider

Returns:

  • (String)


10095
10096
10097
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10095

def cloud_provider
  @cloud_provider
end

#create_timeString

Output only. Timestamp this resource value configuration was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10100
10101
10102
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10100

def create_time
  @create_time
end

#descriptionString

Description of the resource value configuration. Corresponds to the JSON property description

Returns:

  • (String)


10105
10106
10107
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10105

def description
  @description
end

#nameString

Identifier. Name for the resource value configuration Corresponds to the JSON property name

Returns:

  • (String)


10110
10111
10112
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10110

def name
  @name
end

#resource_labels_selectorHash<String,String>

List of resource labels to search for, evaluated with AND. For example, " resource_labels_selector": "key": "value", "env": "prod" will match resources with labels "key": "value" AND "env": "prod" https://cloud.google. com/resource-manager/docs/creating-managing-labels Corresponds to the JSON property resourceLabelsSelector

Returns:

  • (Hash<String,String>)


10118
10119
10120
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10118

def resource_labels_selector
  @resource_labels_selector
end

#resource_typeString

Apply resource_value only to resources that match resource_type. resource_type will be checked with AND of other resources. For example, "storage. googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only to "storage.googleapis.com/Bucket" resources. Corresponds to the JSON property resourceType

Returns:

  • (String)


10126
10127
10128
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10126

def resource_type
  @resource_type
end

#resource_valueString

Resource value level this expression represents Only required when there is no Sensitive Data Protection mapping in the request Corresponds to the JSON property resourceValue

Returns:

  • (String)


10132
10133
10134
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10132

def resource_value
  @resource_value
end

#scopeString

Project or folder to scope this configuration to. For example, "project/456" would apply this configuration only to resources in "project/456" scope and will be checked with AND of other resources. Corresponds to the JSON property scope

Returns:

  • (String)


10139
10140
10141
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10139

def scope
  @scope
end

#sensitive_data_protection_mappingGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping

Resource value mapping for Sensitive Data Protection findings If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration. Corresponds to the JSON property sensitiveDataProtectionMapping



10146
10147
10148
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10146

def sensitive_data_protection_mapping
  @sensitive_data_protection_mapping
end

#tag_valuesArray<String>

Tag values combined with AND to check against. For Google Cloud resources, they are tag value IDs in the form of "tagValues/123". Example: [ "tagValues/ 123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/resource- manager/docs/tags/tags-creating-and-managing Corresponds to the JSON property tagValues

Returns:

  • (Array<String>)


10154
10155
10156
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10154

def tag_values
  @tag_values
end

#update_timeString

Output only. Timestamp this resource value configuration was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10159
10160
10161
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10159

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10166
10167
10168
10169
10170
10171
10172
10173
10174
10175
10176
10177
10178
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10166

def update!(**args)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @scope = args[:scope] if args.key?(:scope)
  @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping)
  @tag_values = args[:tag_values] if args.key?(:tag_values)
  @update_time = args[:update_time] if args.key?(:update_time)
end