Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Returns a new instance of GoogleCloudSecuritycenterV2SecretEnvironmentVariable.



9835
9836
9837
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


9833
9834
9835
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9833

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9840
9841
9842
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9840

def update!(**args)
  @key = args[:key] if args.key?(:key)
end