Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the Google Cloud Armor security policy relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecurityPolicy

Returns a new instance of GoogleCloudSecuritycenterV2SecurityPolicy.



10424
10425
10426
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the Google Cloud Armor security policy, for example, "my-security- policy". Corresponds to the JSON property name

Returns:

  • (String)


10409
10410
10411
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10409

def name
  @name
end

#previewBoolean Also known as: preview?

Whether or not the associated rule or policy is in preview mode. Corresponds to the JSON property preview

Returns:

  • (Boolean)


10414
10415
10416
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10414

def preview
  @preview
end

#typeString

The type of Google Cloud Armor security policy for example, 'backend security policy', 'edge security policy', 'network edge security policy', or 'always-on DDoS protection'. Corresponds to the JSON property type

Returns:

  • (String)


10422
10423
10424
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10422

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10429
10430
10431
10432
10433
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10429

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @preview = args[:preview] if args.key?(:preview)
  @type = args[:type] if args.key?(:type)
end