Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityPosture

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecurityPosture

Returns a new instance of GoogleCloudSecuritycenterV2SecurityPosture.



10343
10344
10345
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#changed_policyString

The name of the updated policy, for example, projects/project_id/policies/ constraint_name`. Corresponds to the JSON propertychangedPolicy`

Returns:

  • (String)


10303
10304
10305
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10303

def changed_policy
  @changed_policy
end

#nameString

Name of the posture, for example, CIS-Posture. Corresponds to the JSON property name

Returns:

  • (String)


10308
10309
10310
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10308

def name
  @name
end

#policyString

The ID of the updated policy, for example, compute-policy-1. Corresponds to the JSON property policy

Returns:

  • (String)


10313
10314
10315
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10313

def policy
  @policy
end

#policy_drift_detailsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2PolicyDriftDetails>

The details about a change in an updated policy that violates the deployed posture. Corresponds to the JSON property policyDriftDetails



10319
10320
10321
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10319

def policy_drift_details
  @policy_drift_details
end

#policy_setString

The name of the updated policy set, for example, cis-policyset. Corresponds to the JSON property policySet

Returns:

  • (String)


10324
10325
10326
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10324

def policy_set
  @policy_set
end

#posture_deploymentString

The name of the posture deployment, for example, organizations/org_id/ posturedeployments/posture_deployment_id`. Corresponds to the JSON propertypostureDeployment`

Returns:

  • (String)


10330
10331
10332
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10330

def posture_deployment
  @posture_deployment
end

#posture_deployment_resourceString

The project, folder, or organization on which the posture is deployed, for example, projects/project_number`. Corresponds to the JSON propertypostureDeploymentResource`

Returns:

  • (String)


10336
10337
10338
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10336

def posture_deployment_resource
  @posture_deployment_resource
end

#revision_idString

The version of the posture, for example, c7cfa2a8. Corresponds to the JSON property revisionId

Returns:

  • (String)


10341
10342
10343
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10341

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10348
10349
10350
10351
10352
10353
10354
10355
10356
10357
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10348

def update!(**args)
  @changed_policy = args[:changed_policy] if args.key?(:changed_policy)
  @name = args[:name] if args.key?(:name)
  @policy = args[:policy] if args.key?(:policy)
  @policy_drift_details = args[:policy_drift_details] if args.key?(:policy_drift_details)
  @policy_set = args[:policy_set] if args.key?(:policy_set)
  @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment)
  @posture_deployment_resource = args[:posture_deployment_resource] if args.key?(:posture_deployment_resource)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end