Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitivityScore
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitivityScore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.
Instance Attribute Summary collapse
-
#score ⇒ String
The sensitivity score applied to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitivityScore
constructor
A new instance of GoogleCloudSecuritycenterV2SensitivityScore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitivityScore
Returns a new instance of GoogleCloudSecuritycenterV2SensitivityScore.
10542 10543 10544 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#score ⇒ String
The sensitivity score applied to the resource.
Corresponds to the JSON property score
10540 10541 10542 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10540 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10547 10548 10549 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10547 def update!(**args) @score = args[:score] if args.key?(:score) end |