Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10677
10678
10679
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10650
10651
10652
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10650

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10655
10656
10657
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10655

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10660
10661
10662
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10660

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10665
10666
10667
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10665

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10670
10671
10672
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10670

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10675
10676
10677
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10675

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10682
10683
10684
10685
10686
10687
10688
10689
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10682

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end