Class: Google::Apis::SecuritycenterV1beta2::GroupMembership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GroupMembership

Returns a new instance of GroupMembership.



9958
9959
9960
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_idString

ID of the group. Corresponds to the JSON property groupId

Returns:

  • (String)


9951
9952
9953
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9951

def group_id
  @group_id
end

#group_typeString

Type of group. Corresponds to the JSON property groupType

Returns:

  • (String)


9956
9957
9958
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9956

def group_type
  @group_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9963
9964
9965
9966
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9963

def update!(**args)
  @group_id = args[:group_id] if args.key?(:group_id)
  @group_type = args[:group_type] if args.key?(:group_type)
end