Class: Google::Apis::SecuritycenterV1beta2::HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The http response returned by the web application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpResponse

Returns a new instance of HttpResponse.



10869
10870
10871
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

The http path for which response code was returned by web application, for example, "https://test-app.a.run.app/test". Corresponds to the JSON property path

Returns:

  • (String)


10862
10863
10864
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10862

def path
  @path
end

#status_codeString

The http response code returned by the web application, for example, 200. Corresponds to the JSON property statusCode

Returns:

  • (String)


10867
10868
10869
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10867

def status_code
  @status_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10874
10875
10876
10877
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10874

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @status_code = args[:status_code] if args.key?(:status_code)
end