Class: Google::Apis::SecuritycenterV1beta2::IpRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

IP rule information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRule

Returns a new instance of IpRule.



10099
10100
10101
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#port_rangesArray<Google::Apis::SecuritycenterV1beta2::PortRange>

Optional. An optional list of ports to which this rule applies. This field is only applicable for the UDP or (S)TCP protocols. Each entry must be either an integer or a range including a min and max port number. Corresponds to the JSON property portRanges



10090
10091
10092
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10090

def port_ranges
  @port_ranges
end

#protocolString

The IP protocol this rule applies to. This value can either be one of the following well known protocol strings (TCP, UDP, ICMP, ESP, AH, IPIP, SCTP) or a string representation of the integer value. Corresponds to the JSON property protocol

Returns:

  • (String)


10097
10098
10099
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10097

def protocol
  @protocol
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10104
10105
10106
10107
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10104

def update!(**args)
  @port_ranges = args[:port_ranges] if args.key?(:port_ranges)
  @protocol = args[:protocol] if args.key?(:protocol)
end