Class: Google::Apis::SecuritycenterV1beta2::IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRules

Returns a new instance of IpRules.



11061
11062
11063
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta2::Allowed

Allowed IP rule. Corresponds to the JSON property allowed



11028
11029
11030
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11028

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta2::Denied

Denied IP rule. Corresponds to the JSON property denied



11033
11034
11035
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11033

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


11040
11041
11042
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11040

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


11045
11046
11047
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11045

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


11052
11053
11054
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11052

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


11059
11060
11061
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11059

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11066
11067
11068
11069
11070
11071
11072
11073
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11066

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end