Class: Google::Apis::SecuritycenterV1beta2::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



11100
11101
11102
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


11083
11084
11085
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11083

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


11088
11089
11090
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11088

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


11093
11094
11095
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11093

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


11098
11099
11100
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11098

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11105
11106
11107
11108
11109
11110
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11105

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end