Class: Google::Apis::SecuritycenterV1beta2::Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Kubernetes

Returns a new instance of Kubernetes.



11243
11244
11245
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1beta2::AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



11202
11203
11204
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11202

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



11209
11210
11211
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11209

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1beta2::NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



11216
11217
11218
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11216

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1beta2::Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



11222
11223
11224
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11222

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1beta2::Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



11227
11228
11229
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11227

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1beta2::Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



11234
11235
11236
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11234

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1beta2::Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



11241
11242
11243
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11241

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11248
11249
11250
11251
11252
11253
11254
11255
11256
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11248

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end