Class: Google::Apis::SecuritycenterV1beta2::Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Notebook

Returns a new instance of Notebook.



11521
11522
11523
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


11504
11505
11506
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11504

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


11509
11510
11511
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11509

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


11514
11515
11516
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11514

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


11519
11520
11521
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11519

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11526
11527
11528
11529
11530
11531
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11526

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end