Class: Google::Apis::SecuritycenterV1beta2::Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Object

Returns a new instance of Object.



11567
11568
11569
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta2::Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



11542
11543
11544
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11542

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


11547
11548
11549
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11547

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


11552
11553
11554
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11552

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


11558
11559
11560
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11558

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


11565
11566
11567
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11565

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11572
11573
11574
11575
11576
11577
11578
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11572

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end