Class: Google::Apis::SecuritycenterV1beta2::Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Package is a generic definition of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Package

Returns a new instance of Package.



11455
11456
11457
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

The CPE URI where the vulnerability was detected. Corresponds to the JSON property cpeUri

Returns:

  • (String)


11438
11439
11440
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11438

def cpe_uri
  @cpe_uri
end

#package_nameString

The name of the package where the vulnerability was detected. Corresponds to the JSON property packageName

Returns:

  • (String)


11443
11444
11445
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11443

def package_name
  @package_name
end

#package_typeString

Type of package, for example, os, maven, or go. Corresponds to the JSON property packageType

Returns:

  • (String)


11448
11449
11450
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11448

def package_type
  @package_type
end

#package_versionString

The version of the package. Corresponds to the JSON property packageVersion

Returns:

  • (String)


11453
11454
11455
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11453

def package_version
  @package_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11460
11461
11462
11463
11464
11465
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11460

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @package_name = args[:package_name] if args.key?(:package_name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @package_version = args[:package_version] if args.key?(:package_version)
end