Class: Google::Apis::SecuritycenterV1beta2::PolicyViolationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Metadata summarizing policy violations of child resources of the affected resource. finding_category and resource determine the exact semantics of the counts. For example, when category= DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage. googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud Storage objects in my-bucket-name which violate a Public Access control.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyViolationSummary

Returns a new instance of PolicyViolationSummary.



11596
11597
11598
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conformant_resources_countFixnum

Total number of child resources that conform to the policy. Corresponds to the JSON property conformantResourcesCount

Returns:

  • (Fixnum)


11578
11579
11580
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11578

def conformant_resources_count
  @conformant_resources_count
end

#evaluation_errors_countFixnum

Number of child resources for which errors during evaluation occurred. The evaluation result for these child resources is effectively "unknown". Corresponds to the JSON property evaluationErrorsCount

Returns:

  • (Fixnum)


11584
11585
11586
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11584

def evaluation_errors_count
  @evaluation_errors_count
end

#out_of_scope_resources_countFixnum

Total count of child resources which were not in scope for evaluation. Corresponds to the JSON property outOfScopeResourcesCount

Returns:

  • (Fixnum)


11589
11590
11591
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11589

def out_of_scope_resources_count
  @out_of_scope_resources_count
end

#policy_violations_countFixnum

Count of child resources in violation of the policy. Corresponds to the JSON property policyViolationsCount

Returns:

  • (Fixnum)


11594
11595
11596
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11594

def policy_violations_count
  @policy_violations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11601
11602
11603
11604
11605
11606
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11601

def update!(**args)
  @conformant_resources_count = args[:conformant_resources_count] if args.key?(:conformant_resources_count)
  @evaluation_errors_count = args[:evaluation_errors_count] if args.key?(:evaluation_errors_count)
  @out_of_scope_resources_count = args[:out_of_scope_resources_count] if args.key?(:out_of_scope_resources_count)
  @policy_violations_count = args[:policy_violations_count] if args.key?(:policy_violations_count)
end