Class: Google::Apis::SecuritycenterV1beta2::Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Process
constructor
A new instance of Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Process
Returns a new instance of Process.
11871 11872 11873 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
11813 11814 11815 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11813 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
11818 11819 11820 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11818 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
11825 11826 11827 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11825 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
11830 11831 11832 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11830 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
11835 11836 11837 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11835 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
11841 11842 11843 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11841 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
11847 11848 11849 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11847 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
11852 11853 11854 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11852 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
11857 11858 11859 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11857 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
11863 11864 11865 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11863 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
11869 11870 11871 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11869 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 11887 11888 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11876 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |