Class: Google::Apis::SecuritycenterV1beta2::ProcessSignature
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::ProcessSignature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Indicates what signature matched this process.
Instance Attribute Summary collapse
-
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1beta2::MemoryHashSignature
A signature corresponding to memory page hashes.
-
#signature_type ⇒ String
Describes the type of resource associated with the signature.
-
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1beta2::YaraRuleSignature
A signature corresponding to a YARA rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProcessSignature
constructor
A new instance of ProcessSignature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProcessSignature
Returns a new instance of ProcessSignature.
11910 11911 11912 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1beta2::MemoryHashSignature
A signature corresponding to memory page hashes.
Corresponds to the JSON property memoryHashSignature
11898 11899 11900 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11898 def memory_hash_signature @memory_hash_signature end |
#signature_type ⇒ String
Describes the type of resource associated with the signature.
Corresponds to the JSON property signatureType
11903 11904 11905 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11903 def signature_type @signature_type end |
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1beta2::YaraRuleSignature
A signature corresponding to a YARA rule.
Corresponds to the JSON property yaraRuleSignature
11908 11909 11910 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11908 def yara_rule_signature @yara_rule_signature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11915 11916 11917 11918 11919 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11915 def update!(**args) @memory_hash_signature = args[:memory_hash_signature] if args.key?(:memory_hash_signature) @signature_type = args[:signature_type] if args.key?(:signature_type) @yara_rule_signature = args[:yara_rule_signature] if args.key?(:yara_rule_signature) end |