Class: Google::Apis::SecuritycenterV1beta2::ResourcePath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents the path of resources leading up to the resource this finding is about.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePath

Returns a new instance of ResourcePath.



12041
12042
12043
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::SecuritycenterV1beta2::ResourcePathNode>

The list of nodes that make the up resource path, ordered from lowest level to highest level. Corresponds to the JSON property nodes



12039
12040
12041
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12039

def nodes
  @nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12046
12047
12048
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12046

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
end