Class: Google::Apis::SecuritycenterV1beta2::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



11992
11993
11994
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


11990
11991
11992
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11990

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11997
11998
11999
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11997

def update!(**args)
  @key = args[:key] if args.key?(:key)
end