Class: Google::Apis::SecuritycenterV1beta2::SecurityBulletin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

SecurityBulletin are notifications of vulnerabilities of Google products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityBulletin

Returns a new instance of SecurityBulletin.



12236
12237
12238
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bulletin_idString

ID of the bulletin corresponding to the vulnerability. Corresponds to the JSON property bulletinId

Returns:

  • (String)


12223
12224
12225
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12223

def bulletin_id
  @bulletin_id
end

#submission_timeString

Submission time of this Security Bulletin. Corresponds to the JSON property submissionTime

Returns:

  • (String)


12228
12229
12230
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12228

def submission_time
  @submission_time
end

#suggested_upgrade_versionString

This represents a version that the cluster receiving this notification should be upgraded to, based on its current version. For example, 1.15.0 Corresponds to the JSON property suggestedUpgradeVersion

Returns:

  • (String)


12234
12235
12236
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12234

def suggested_upgrade_version
  @suggested_upgrade_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12241
12242
12243
12244
12245
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12241

def update!(**args)
  @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @suggested_upgrade_version = args[:suggested_upgrade_version] if args.key?(:suggested_upgrade_version)
end