Class: Google::Apis::SecuritycenterV1beta2::SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitivityScore

Returns a new instance of SensitivityScore.



12340
12341
12342
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


12338
12339
12340
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12338

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12345
12346
12347
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12345

def update!(**args)
  @score = args[:score] if args.key?(:score)
end