Class: Google::Apis::SecuritycenterV1beta2::StaticMute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the static mute state. A static mute state overrides any dynamic mute rules that apply to this finding. The static mute state can be set by a static mute rule or by muting the finding directly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StaticMute

Returns a new instance of StaticMute.



12568
12569
12570
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_timeString

When the static mute was applied. Corresponds to the JSON property applyTime

Returns:

  • (String)


12560
12561
12562
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12560

def apply_time
  @apply_time
end

#stateString

The static mute state. If the value is MUTED or UNMUTED, then the finding' s overall mute state will have the same value. Corresponds to the JSON property state

Returns:

  • (String)


12566
12567
12568
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12566

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12573
12574
12575
12576
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12573

def update!(**args)
  @apply_time = args[:apply_time] if args.key?(:apply_time)
  @state = args[:state] if args.key?(:state)
end