Class: Google::Apis::SecuritycenterV1beta2::ToxicCombination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToxicCombination

Returns a new instance of ToxicCombination.



11758
11759
11760
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_exposure_scoreFloat

The Attack exposure score of this toxic combination. The score is a measure of how much this toxic combination exposes one or more high-value resources to potential attack. Corresponds to the JSON property attackExposureScore

Returns:

  • (Float)


11750
11751
11752
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11750

def attack_exposure_score
  @attack_exposure_score
end

List of resource names of findings associated with this toxic combination. For example, organizations/123/sources/456/findings/789. Corresponds to the JSON property relatedFindings

Returns:

  • (Array<String>)


11756
11757
11758
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11756

def related_findings
  @related_findings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11763
11764
11765
11766
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11763

def update!(**args)
  @attack_exposure_score = args[:attack_exposure_score] if args.key?(:attack_exposure_score)
  @related_findings = args[:related_findings] if args.key?(:related_findings)
end