Class: Google::Apis::SecuritycenterV1beta2::WebSecurityScannerSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for the Web Security Scanner service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebSecurityScannerSettings

Returns a new instance of WebSecurityScannerSettings.



12776
12777
12778
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modulesHash<String,Google::Apis::SecuritycenterV1beta2::Config>

The configurations including the state of enablement for the service's different modules. The absence of a module in the map implies its configuration is inherited from its parent's configuration. Corresponds to the JSON property modules



12756
12757
12758
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12756

def modules
  @modules
end

#nameString

Identifier. The resource name of the WebSecurityScannerSettings. Formats: * organizations/organization/webSecurityScannerSettings * folders/folder/ webSecurityScannerSettings * projects/project/webSecurityScannerSettings Corresponds to the JSON property name

Returns:

  • (String)


12763
12764
12765
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12763

def name
  @name
end

#service_enablement_stateString

The state of enablement for the service at its level of the resource hierarchy. A DISABLED state will override all module enablement_states to DISABLED. Corresponds to the JSON property serviceEnablementState

Returns:

  • (String)


12769
12770
12771
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12769

def service_enablement_state
  @service_enablement_state
end

#update_timeString

Output only. The time the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12774
12775
12776
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12774

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12781
12782
12783
12784
12785
12786
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12781

def update!(**args)
  @modules = args[:modules] if args.key?(:modules)
  @name = args[:name] if args.key?(:name)
  @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state)
  @update_time = args[:update_time] if args.key?(:update_time)
end