Class: Google::Apis::SecuritycenterV1beta2::AiModel
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::AiModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Contains information about the AI model associated with the finding.
Instance Attribute Summary collapse
-
#deployment_platform ⇒ String
The platform on which the model is deployed.
-
#display_name ⇒ String
The user defined display name of model.
-
#domain ⇒ String
The domain of the model, for example, “image-classification”.
-
#library ⇒ String
The name of the model library, for example, “transformers”.
-
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
-
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
-
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
-
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Instance Method Summary collapse
-
#initialize(**args) ⇒ AiModel
constructor
A new instance of AiModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AiModel
Returns a new instance of AiModel.
277 278 279 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_platform ⇒ String
The platform on which the model is deployed.
Corresponds to the JSON property deploymentPlatform
240 241 242 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 240 def deployment_platform @deployment_platform end |
#display_name ⇒ String
The user defined display name of model. Ex. baseline-classification-model
Corresponds to the JSON property displayName
245 246 247 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 245 def display_name @display_name end |
#domain ⇒ String
The domain of the model, for example, “image-classification”.
Corresponds to the JSON property domain
250 251 252 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 250 def domain @domain end |
#library ⇒ String
The name of the model library, for example, “transformers”.
Corresponds to the JSON property library
255 256 257 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 255 def library @library end |
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
Corresponds to the JSON property location
260 261 262 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 260 def location @location end |
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
Corresponds to the JSON property name
265 266 267 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 265 def name @name end |
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
Corresponds to the JSON property publisher
270 271 272 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 270 def publisher @publisher end |
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Corresponds to the JSON property usageCategory
275 276 277 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 275 def usage_category @usage_category end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
282 283 284 285 286 287 288 289 290 291 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 282 def update!(**args) @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) @library = args[:library] if args.key?(:library) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @publisher = args[:publisher] if args.key?(:publisher) @usage_category = args[:usage_category] if args.key?(:usage_category) end |