Class: Google::Apis::SecuritycenterV1beta2::AttackExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::AttackExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
An attack exposure contains the results of an attack path simulation run.
Instance Attribute Summary collapse
-
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the details regarding this attack exposure score.
-
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this finding.
-
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
-
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this finding is to remediate.
-
#state ⇒ String
What state this AttackExposure is in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttackExposure
constructor
A new instance of AttackExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttackExposure
Returns a new instance of AttackExposure.
490 491 492 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the
details regarding this attack exposure score. Example: organizations/123/
simulations/456/attackExposureResults/789
Corresponds to the JSON property attackExposureResult
452 453 454 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 452 def attack_exposure_result @attack_exposure_result end |
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedHighValueResourcesCount
458 459 460 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 458 def exposed_high_value_resources_count @exposed_high_value_resources_count end |
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedLowValueResourcesCount
464 465 466 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 464 def exposed_low_value_resources_count @exposed_low_value_resources_count end |
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedMediumValueResourcesCount
470 471 472 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 470 def exposed_medium_value_resources_count @exposed_medium_value_resources_count end |
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
Corresponds to the JSON property latestCalculationTime
475 476 477 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 475 def latest_calculation_time @latest_calculation_time end |
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this
finding is to remediate. The higher the score, the more important it is to
remediate.
Corresponds to the JSON property score
482 483 484 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 482 def score @score end |
#state ⇒ String
What state this AttackExposure is in. This captures whether or not an attack
exposure has been calculated or not.
Corresponds to the JSON property state
488 489 490 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 488 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
495 496 497 498 499 500 501 502 503 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 495 def update!(**args) @attack_exposure_result = args[:attack_exposure_result] if args.key?(:attack_exposure_result) @exposed_high_value_resources_count = args[:exposed_high_value_resources_count] if args.key?(:exposed_high_value_resources_count) @exposed_low_value_resources_count = args[:exposed_low_value_resources_count] if args.key?(:exposed_low_value_resources_count) @exposed_medium_value_resources_count = args[:exposed_medium_value_resources_count] if args.key?(:exposed_medium_value_resources_count) @latest_calculation_time = args[:latest_calculation_time] if args.key?(:latest_calculation_time) @score = args[:score] if args.key?(:score) @state = args[:state] if args.key?(:state) end |