Class: Google::Apis::SecuritycenterV1beta2::Chokepoint
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Chokepoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.
Instance Attribute Summary collapse
-
#related_findings ⇒ Array<String>
List of resource names of findings associated with this chokepoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Chokepoint
constructor
A new instance of Chokepoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Chokepoint
Returns a new instance of Chokepoint.
893 894 895 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#related_findings ⇒ Array<String>
List of resource names of findings associated with this chokepoint. For
example, organizations/123/sources/456/findings/789. This list will have at
most 100 findings.
Corresponds to the JSON property relatedFindings
891 892 893 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 891 def @related_findings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
898 899 900 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 898 def update!(**args) @related_findings = args[:related_findings] if args.key?(:related_findings) end |