Class: Google::Apis::SecuritycenterV1beta2::ContainerThreatDetectionSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::ContainerThreatDetectionSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource capturing the settings for the Container Threat Detection service.
Instance Attribute Summary collapse
-
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's different modules.
-
#name ⇒ String
Identifier.
-
#service_account ⇒ String
Output only.
-
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerThreatDetectionSettings
constructor
A new instance of ContainerThreatDetectionSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerThreatDetectionSettings
Returns a new instance of ContainerThreatDetectionSettings.
1437 1438 1439 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's
different modules. The absence of a module in the map implies its
configuration is inherited from its parent's configuration.
Corresponds to the JSON property modules
1408 1409 1410 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1408 def modules @modules end |
#name ⇒ String
Identifier. The resource name of the ContainerThreatDetectionSettings. Formats:
- organizations/
organization/containerThreatDetectionSettings * folders/folder/containerThreatDetectionSettings * projects/project/ containerThreatDetectionSettings * projects/project/locations/location/ clusters/cluster/containerThreatDetectionSettings Corresponds to the JSON propertyname
1417 1418 1419 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1417 def name @name end |
#service_account ⇒ String
Output only. The service account used by Container Threat Detection for
scanning. Service accounts are scoped at the project level meaning this field
will be empty at any level above a project.
Corresponds to the JSON property serviceAccount
1424 1425 1426 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1424 def service_account @service_account end |
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
A DISABLED state will override all module enablement_states to DISABLED.
Corresponds to the JSON property serviceEnablementState
1430 1431 1432 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1430 def service_enablement_state @service_enablement_state end |
#update_time ⇒ String
Output only. The time the settings were last updated.
Corresponds to the JSON property updateTime
1435 1436 1437 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1435 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1442 def update!(**args) @modules = args[:modules] if args.key?(:modules) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state) @update_time = args[:update_time] if args.key?(:update_time) end |