Class: Google::Apis::SecuritycenterV1beta2::Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Database

Returns a new instance of Database.



1777
1778
1779
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The human-readable name of the database that the user connected to. Corresponds to the JSON property displayName

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1742

def display_name
  @display_name
end

#granteesArray<String>

The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change. Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


1748
1749
1750
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1748

def grantees
  @grantees
end

#nameString

Some database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In these cases only the display name will be provided. The full resource name of the database that the user connected to, if it is supported by Cloud Asset Inventory. Corresponds to the JSON property name

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1758

def name
  @name
end

#queryString

The SQL statement that is associated with the database access. Corresponds to the JSON property query

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1763

def query
  @query
end

#user_nameString

The username used to connect to the database. The username might not be an IAM principal and does not have a set format. Corresponds to the JSON property userName

Returns:

  • (String)


1769
1770
1771
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1769

def user_name
  @user_name
end

#versionString

The version of the database, for example, POSTGRES_14. See the complete list. Corresponds to the JSON property version

Returns:

  • (String)


1775
1776
1777
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1775

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1782
1783
1784
1785
1786
1787
1788
1789
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1782

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @grantees = args[:grantees] if args.key?(:grantees)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
  @user_name = args[:user_name] if args.key?(:user_name)
  @version = args[:version] if args.key?(:version)
end