Class: Google::Apis::SecuritycenterV1beta2::Detection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Memory hash detection contributing to the binary family match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Detection

Returns a new instance of Detection.



1957
1958
1959
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binaryString

The name of the binary associated with the memory hash signature detection. Corresponds to the JSON property binary

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1950

def binary
  @binary
end

#percent_pages_matchedFloat

The percentage of memory page hashes in the signature that were matched. Corresponds to the JSON property percentPagesMatched

Returns:

  • (Float)


1955
1956
1957
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1955

def percent_pages_matched
  @percent_pages_matched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1962
1963
1964
1965
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 1962

def update!(**args)
  @binary = args[:binary] if args.key?(:binary)
  @percent_pages_matched = args[:percent_pages_matched] if args.key?(:percent_pages_matched)
end