Class: Google::Apis::SecuritycenterV1beta2::EventThreatDetectionSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for the Event Threat Detection service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventThreatDetectionSettings

Returns a new instance of EventThreatDetectionSettings.



2029
2030
2031
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modulesHash<String,Google::Apis::SecuritycenterV1beta2::Config>

The configurations including the state of enablement for the service's different modules. The absence of a module in the map implies its configuration is inherited from its parent's configuration. Corresponds to the JSON property modules



2009
2010
2011
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2009

def modules
  @modules
end

#nameString

Identifier. The resource name of the EventThreatDetectionSettings. Formats: * organizations/organization/eventThreatDetectionSettings * folders/folder/ eventThreatDetectionSettings * projects/project/eventThreatDetectionSettings Corresponds to the JSON property name

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2016

def name
  @name
end

#service_enablement_stateString

The state of enablement for the service at its level of the resource hierarchy. A DISABLED state will override all module enablement_states to DISABLED. Corresponds to the JSON property serviceEnablementState

Returns:

  • (String)


2022
2023
2024
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2022

def service_enablement_state
  @service_enablement_state
end

#update_timeString

Output only. The time the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2027

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2034
2035
2036
2037
2038
2039
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2034

def update!(**args)
  @modules = args[:modules] if args.key?(:modules)
  @name = args[:name] if args.key?(:name)
  @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state)
  @update_time = args[:update_time] if args.key?(:update_time)
end