Class: Google::Apis::SecuritycenterV1beta2::ExfilResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::ExfilResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource where data was exfiltrated from or exfiltrated to.
Instance Attribute Summary collapse
-
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames.
-
#name ⇒ String
The resource's full resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExfilResource
constructor
A new instance of ExfilResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExfilResource
Returns a new instance of ExfilResource.
2060 2061 2062 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during
exfiltration, table names, databases, and filenames. For example, multiple
tables might have been exfiltrated from the same Cloud SQL instance, or
multiple files might have been exfiltrated from the same Cloud Storage bucket.
Corresponds to the JSON property components
2052 2053 2054 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2052 def components @components end |
#name ⇒ String
The resource's full resource name.
Corresponds to the JSON property name
2058 2059 2060 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2058 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2065 2066 2067 2068 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2065 def update!(**args) @components = args[:components] if args.key?(:components) @name = args[:name] if args.key?(:name) end |