Class: Google::Apis::SecuritycenterV1beta2::Exfiltration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Exfiltration

Returns a new instance of Exfiltration.



2096
2097
2098
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sourcesArray<Google::Apis::SecuritycenterV1beta2::ExfilResource>

If there are multiple sources, then the data is considered "joined" between them. For instance, BigQuery can join multiple tables, and each table would be considered a source. Corresponds to the JSON property sources



2083
2084
2085
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2083

def sources
  @sources
end

#targetsArray<Google::Apis::SecuritycenterV1beta2::ExfilResource>

If there are multiple targets, each target would get a complete copy of the " joined" source data. Corresponds to the JSON property targets



2089
2090
2091
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2089

def targets
  @targets
end

#total_exfiltrated_bytesFixnum

Total exfiltrated bytes processed for the entire job. Corresponds to the JSON property totalExfiltratedBytes

Returns:

  • (Fixnum)


2094
2095
2096
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2094

def total_exfiltrated_bytes
  @total_exfiltrated_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2101
2102
2103
2104
2105
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2101

def update!(**args)
  @sources = args[:sources] if args.key?(:sources)
  @targets = args[:targets] if args.key?(:targets)
  @total_exfiltrated_bytes = args[:total_exfiltrated_bytes] if args.key?(:total_exfiltrated_bytes)
end