Class: Google::Apis::SecuritycenterV1beta2::ExternalExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about the externally exposed resource associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalExposure

Returns a new instance of ExternalExposure.



2437
2438
2439
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceString

The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/project-id/global/backendServices/name". Corresponds to the JSON property backendService

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2371

def backend_service
  @backend_service
end

#exposed_endpointString

The resource which is running the exposed service, for example, "//compute. googleapis.com/projects/project-id/zones/zone/instances/instance.” Corresponds to the JSON property exposedEndpoint

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2377

def exposed_endpoint
  @exposed_endpoint
end

#exposed_serviceString

The name and version of the service, for example, "Jupyter Notebook 6.14.0". Corresponds to the JSON property exposedService

Returns:

  • (String)


2382
2383
2384
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2382

def exposed_service
  @exposed_service
end

#forwarding_ruleString

The full resource name of the forwarding rule, for example, "//compute. googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule- name". Corresponds to the JSON property forwardingRule

Returns:

  • (String)


2389
2390
2391
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2389

def forwarding_rule
  @forwarding_rule
end

#instance_groupString

The full resource name of the instance group, for example, "//compute. googleapis.com/projects/project-id/global/instanceGroups/name". Corresponds to the JSON property instanceGroup

Returns:

  • (String)


2395
2396
2397
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2395

def instance_group
  @instance_group
end

#load_balancer_firewall_policyString

The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/policy- name". Corresponds to the JSON property loadBalancerFirewallPolicy

Returns:

  • (String)


2402
2403
2404
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2402

def load_balancer_firewall_policy
  @load_balancer_firewall_policy
end

#network_endpoint_groupString

The full resource name of the network endpoint group, for example, "//compute. googleapis.com/projects/project-id/global/networkEndpointGroups/name". Corresponds to the JSON property networkEndpointGroup

Returns:

  • (String)


2408
2409
2410
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2408

def network_endpoint_group
  @network_endpoint_group
end

#private_ip_addressString

Private IP address of the exposed endpoint. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


2413
2414
2415
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2413

def private_ip_address
  @private_ip_address
end

#private_portString

Port number associated with private IP address. Corresponds to the JSON property privatePort

Returns:

  • (String)


2418
2419
2420
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2418

def private_port
  @private_port
end

#public_ip_addressString

Public IP address of the exposed endpoint. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


2423
2424
2425
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2423

def public_ip_address
  @public_ip_address
end

#public_portString

Public port number of the exposed endpoint. Corresponds to the JSON property publicPort

Returns:

  • (String)


2428
2429
2430
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2428

def public_port
  @public_port
end

#service_firewall_policyString

The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/project-id/global/ firewallPolicies/policy-name". Corresponds to the JSON property serviceFirewallPolicy

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2435

def service_firewall_policy
  @service_firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2442

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint)
  @exposed_service = args[:exposed_service] if args.key?(:exposed_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy)
  @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @private_port = args[:private_port] if args.key?(:private_port)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @public_port = args[:public_port] if args.key?(:public_port)
  @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy)
end