Class: Google::Apis::SecuritycenterV1beta2::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



2416
2417
2418
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2371

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1beta2::DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



2376
2377
2378
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2376

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


2381
2382
2383
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2381

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


2387
2388
2389
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2387

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1beta2::FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



2392
2393
2394
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2392

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


2397
2398
2399
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2397

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


2403
2404
2405
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2403

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2409

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2414
2415
2416
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2414

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2421

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end