Class: Google::Apis::SecuritycenterV1beta2::File
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
File information about the related binary/library used by an executable, or the script used by a script interpreter
Instance Attribute Summary collapse
-
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
-
#disk_path ⇒ Google::Apis::SecuritycenterV1beta2::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
-
#file_load_state ⇒ String
The load state of the file.
-
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed.
-
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta2::FileOperation>
Operation(s) performed on a file.
-
#partially_hashed ⇒ Boolean
(also: #partially_hashed?)
True when the hash covers only a prefix of the file.
-
#path ⇒ String
Absolute path of the file as a JSON encoded string.
-
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
-
#size ⇒ Fixnum
Size of the file in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ File
constructor
A new instance of File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ File
Returns a new instance of File.
2253 2254 2255 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
Corresponds to the JSON property contents
2208 2209 2210 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2208 def contents @contents end |
#disk_path ⇒ Google::Apis::SecuritycenterV1beta2::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
Corresponds to the JSON property diskPath
2213 2214 2215 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2213 def disk_path @disk_path end |
#file_load_state ⇒ String
The load state of the file.
Corresponds to the JSON property fileLoadState
2218 2219 2220 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2218 def file_load_state @file_load_state end |
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed. If hashed_size == size,
any hashes reported represent the entire file.
Corresponds to the JSON property hashedSize
2224 2225 2226 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2224 def hashed_size @hashed_size end |
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta2::FileOperation>
Operation(s) performed on a file.
Corresponds to the JSON property operations
2229 2230 2231 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2229 def operations @operations end |
#partially_hashed ⇒ Boolean Also known as: partially_hashed?
True when the hash covers only a prefix of the file.
Corresponds to the JSON property partiallyHashed
2234 2235 2236 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2234 def partially_hashed @partially_hashed end |
#path ⇒ String
Absolute path of the file as a JSON encoded string.
Corresponds to the JSON property path
2240 2241 2242 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2240 def path @path end |
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
If hashed_size == size, sha256 represents the SHA256 hash of the entire file.
Corresponds to the JSON property sha256
2246 2247 2248 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2246 def sha256 @sha256 end |
#size ⇒ Fixnum
Size of the file in bytes.
Corresponds to the JSON property size
2251 2252 2253 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2251 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2258 def update!(**args) @contents = args[:contents] if args.key?(:contents) @disk_path = args[:disk_path] if args.key?(:disk_path) @file_load_state = args[:file_load_state] if args.key?(:file_load_state) @hashed_size = args[:hashed_size] if args.key?(:hashed_size) @operations = args[:operations] if args.key?(:operations) @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed) @path = args[:path] if args.key?(:path) @sha256 = args[:sha256] if args.key?(:sha256) @size = args[:size] if args.key?(:size) end |