Class: Google::Apis::SecuritycenterV1beta2::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



2976
2977
2978
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessGoogle::Apis::SecuritycenterV1beta2::Access

Represents an access event. Corresponds to the JSON property access



2559
2560
2561
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2559

def access
  @access
end

#affected_resourcesGoogle::Apis::SecuritycenterV1beta2::AffectedResources

Details about resources affected by this finding. Corresponds to the JSON property affectedResources



2564
2565
2566
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2564

def affected_resources
  @affected_resources
end

#agent_data_access_eventsArray<Google::Apis::SecuritycenterV1beta2::AgentDataAccessEvent>

Agent data access events associated with the finding. Corresponds to the JSON property agentDataAccessEvents



2569
2570
2571
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2569

def agent_data_access_events
  @agent_data_access_events
end

#ai_modelGoogle::Apis::SecuritycenterV1beta2::AiModel

Contains information about the AI model associated with the finding. Corresponds to the JSON property aiModel



2574
2575
2576
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2574

def ai_model
  @ai_model
end

#applicationGoogle::Apis::SecuritycenterV1beta2::Application

Represents an application associated with a finding. Corresponds to the JSON property application



2579
2580
2581
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2579

def application
  @application
end

#artifact_guard_policiesGoogle::Apis::SecuritycenterV1beta2::ArtifactGuardPolicies

Represents the result of evaluating artifact guard policies. Corresponds to the JSON property artifactGuardPolicies



2584
2585
2586
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2584

def artifact_guard_policies
  @artifact_guard_policies
end

#attack_exposureGoogle::Apis::SecuritycenterV1beta2::AttackExposure

An attack exposure contains the results of an attack path simulation run. Corresponds to the JSON property attackExposure



2589
2590
2591
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2589

def attack_exposure
  @attack_exposure
end

#backup_disaster_recoveryGoogle::Apis::SecuritycenterV1beta2::BackupDisasterRecovery

Information related to Google Cloud Backup and DR Service findings. Corresponds to the JSON property backupDisasterRecovery



2594
2595
2596
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2594

def backup_disaster_recovery
  @backup_disaster_recovery
end

#canonical_nameString

The canonical name of the finding. It's either "organizations/organization_id /sources/source_id/findings/finding_id", "folders/folder_id/sources/ source_id/findings/finding_id" or "projects/project_number/sources/ source_id/findings/finding_id", depending on the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON property canonicalName

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2603

def canonical_name
  @canonical_name
end

#categoryString

The additional taxonomy group within findings from a given source. This field is immutable after creation time. Example: "XSS_FLASH_INJECTION" Corresponds to the JSON property category

Returns:

  • (String)


2609
2610
2611
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2609

def category
  @category
end

#chokepointGoogle::Apis::SecuritycenterV1beta2::Chokepoint

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations. Corresponds to the JSON property chokepoint



2617
2618
2619
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2617

def chokepoint
  @chokepoint
end

#cloud_armorGoogle::Apis::SecuritycenterV1beta2::CloudArmor

Fields related to Google Cloud Armor findings. Corresponds to the JSON property cloudArmor



2622
2623
2624
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2622

def cloud_armor
  @cloud_armor
end

#cloud_dlp_data_profileGoogle::Apis::SecuritycenterV1beta2::CloudDlpDataProfile

The data profile associated with the finding. Corresponds to the JSON property cloudDlpDataProfile



2628
2629
2630
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2628

def cloud_dlp_data_profile
  @cloud_dlp_data_profile
end

#cloud_dlp_inspectionGoogle::Apis::SecuritycenterV1beta2::CloudDlpInspection

Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding. Corresponds to the JSON property cloudDlpInspection



2635
2636
2637
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2635

def cloud_dlp_inspection
  @cloud_dlp_inspection
end

#compliance_detailsGoogle::Apis::SecuritycenterV1beta2::ComplianceDetails

Compliance Details associated with the finding. Corresponds to the JSON property complianceDetails



2640
2641
2642
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2640

def compliance_details
  @compliance_details
end

#compliancesArray<Google::Apis::SecuritycenterV1beta2::Compliance>

Contains compliance information for security standards associated to the finding. Corresponds to the JSON property compliances



2646
2647
2648
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2646

def compliances
  @compliances
end

#connectionsArray<Google::Apis::SecuritycenterV1beta2::Connection>

Contains information about the IP connection associated with the finding. Corresponds to the JSON property connections



2651
2652
2653
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2651

def connections
  @connections
end

#contactsHash<String,Google::Apis::SecuritycenterV1beta2::ContactDetails>

Output only. Map containing the points of contact for the given finding. The key represents the type of contact, while the value contains a list of all the contacts that pertain. Please refer to: https://cloud.google.com/resource- manager/docs/managing-notification-contacts#notification-categories " security": "contacts": [ "email": "person1@company.com", "email": " person2@company.com" ] Corresponds to the JSON property contacts



2661
2662
2663
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2661

def contacts
  @contacts
end

#containersArray<Google::Apis::SecuritycenterV1beta2::Container>

Containers associated with the finding. This field provides information for both Kubernetes and non-Kubernetes containers. Corresponds to the JSON property containers



2667
2668
2669
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2667

def containers
  @containers
end

#create_timeString

The time at which the finding was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


2672
2673
2674
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2672

def create_time
  @create_time
end

#data_access_eventsArray<Google::Apis::SecuritycenterV1beta2::DataAccessEvent>

Data access events associated with the finding. Corresponds to the JSON property dataAccessEvents



2677
2678
2679
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2677

def data_access_events
  @data_access_events
end

#data_flow_eventsArray<Google::Apis::SecuritycenterV1beta2::DataFlowEvent>

Data flow events associated with the finding. Corresponds to the JSON property dataFlowEvents



2682
2683
2684
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2682

def data_flow_events
  @data_flow_events
end

#data_retention_deletion_eventsArray<Google::Apis::SecuritycenterV1beta2::DataRetentionDeletionEvent>

Data retention deletion events associated with the finding. Corresponds to the JSON property dataRetentionDeletionEvents



2687
2688
2689
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2687

def data_retention_deletion_events
  @data_retention_deletion_events
end

#databaseGoogle::Apis::SecuritycenterV1beta2::Database

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided. Corresponds to the JSON property database



2698
2699
2700
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2698

def database
  @database
end

#descriptionString

Contains more details about the finding. Corresponds to the JSON property description

Returns:

  • (String)


2703
2704
2705
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2703

def description
  @description
end

#discovered_workloadGoogle::Apis::SecuritycenterV1beta2::DiscoveredWorkload

Represents discovered, customer managed workload that is not registered with the respective GCP service. Corresponds to the JSON property discoveredWorkload



2709
2710
2711
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2709

def discovered_workload
  @discovered_workload
end

#diskGoogle::Apis::SecuritycenterV1beta2::Disk

Contains information about the disk associated with the finding. Corresponds to the JSON property disk



2714
2715
2716
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2714

def disk
  @disk
end

#event_timeString

The time the finding was first detected. If an existing finding is updated, then this is the time the update occurred. For example, if the finding represents an open firewall, this property captures the time the detector believes the firewall became open. The accuracy is determined by the detector. If the finding is later resolved, then this time reflects when the finding was resolved. This must not be set to a value greater than the current timestamp. Corresponds to the JSON property eventTime

Returns:

  • (String)


2724
2725
2726
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2724

def event_time
  @event_time
end

#exfiltrationGoogle::Apis::SecuritycenterV1beta2::Exfiltration

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to. Corresponds to the JSON property exfiltration



2732
2733
2734
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2732

def exfiltration
  @exfiltration
end

#external_exposureGoogle::Apis::SecuritycenterV1beta2::ExternalExposure

Details about the externally exposed resource associated with the finding. Corresponds to the JSON property externalExposure



2737
2738
2739
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2737

def external_exposure
  @external_exposure
end

#external_systemsHash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem>

Output only. Third party SIEM/SOAR fields within SCC, contains external system information and external system finding fields. Corresponds to the JSON property externalSystems



2743
2744
2745
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2743

def external_systems
  @external_systems
end

#external_uriString

The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found. This field is guaranteed to be either empty or a well formed URL. Corresponds to the JSON property externalUri

Returns:

  • (String)


2750
2751
2752
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2750

def external_uri
  @external_uri
end

#filesArray<Google::Apis::SecuritycenterV1beta2::File>

File associated with the finding. Corresponds to the JSON property files



2755
2756
2757
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2755

def files
  @files
end

#finding_classString

The class of the finding. Corresponds to the JSON property findingClass

Returns:

  • (String)


2760
2761
2762
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2760

def finding_class
  @finding_class
end

#group_membershipsArray<Google::Apis::SecuritycenterV1beta2::GroupMembership>

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way. This field cannot be updated. Its value is ignored in all update requests. Corresponds to the JSON property groupMemberships



2767
2768
2769
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2767

def group_memberships
  @group_memberships
end

#iam_bindingsArray<Google::Apis::SecuritycenterV1beta2::IamBinding>

Represents IAM bindings associated with the finding. Corresponds to the JSON property iamBindings



2772
2773
2774
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2772

def iam_bindings
  @iam_bindings
end

#indicatorGoogle::Apis::SecuritycenterV1beta2::Indicator

Represents what's commonly known as an indicator of compromise (IoC) in computer forensics. This is an artifact observed on a network or in an operating system that, with high confidence, indicates a computer intrusion. For more information, see Indicator of compromise. Corresponds to the JSON property indicator



2781
2782
2783
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2781

def indicator
  @indicator
end

#ip_rulesGoogle::Apis::SecuritycenterV1beta2::IpRules

IP rules associated with the finding. Corresponds to the JSON property ipRules



2786
2787
2788
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2786

def ip_rules
  @ip_rules
end

#jobGoogle::Apis::SecuritycenterV1beta2::Job

Describes a job Corresponds to the JSON property job



2791
2792
2793
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2791

def job
  @job
end

#kernel_rootkitGoogle::Apis::SecuritycenterV1beta2::KernelRootkit

Kernel mode rootkit signatures. Corresponds to the JSON property kernelRootkit



2796
2797
2798
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2796

def kernel_rootkit
  @kernel_rootkit
end

#kubernetesGoogle::Apis::SecuritycenterV1beta2::Kubernetes

Kubernetes-related attributes. Corresponds to the JSON property kubernetes



2801
2802
2803
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2801

def kubernetes
  @kubernetes
end

#load_balancersArray<Google::Apis::SecuritycenterV1beta2::LoadBalancer>

The load balancers associated with the finding. Corresponds to the JSON property loadBalancers



2806
2807
2808
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2806

def load_balancers
  @load_balancers
end

#log_entriesArray<Google::Apis::SecuritycenterV1beta2::LogEntry>

Log entries that are relevant to the finding. Corresponds to the JSON property logEntries



2811
2812
2813
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2811

def log_entries
  @log_entries
end

#mitre_attackGoogle::Apis::SecuritycenterV1beta2::MitreAttack

MITRE ATT&CK tactics and techniques related to this finding. See: https:// attack.mitre.org Corresponds to the JSON property mitreAttack



2817
2818
2819
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2817

def mitre_attack
  @mitre_attack
end

#module_nameString

Unique identifier of the module which generated the finding. Example: folders/ 598186756061/securityHealthAnalyticsSettings/customModules/56799441161885 Corresponds to the JSON property moduleName

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2823

def module_name
  @module_name
end

#muteString

Indicates the mute state of a finding (either muted, unmuted or undefined). Unlike other attributes of a finding, a finding provider shouldn't set the value of mute. Corresponds to the JSON property mute

Returns:

  • (String)


2830
2831
2832
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2830

def mute
  @mute
end

#mute_infoGoogle::Apis::SecuritycenterV1beta2::MuteInfo

Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules. Corresponds to the JSON property muteInfo



2836
2837
2838
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2836

def mute_info
  @mute_info
end

#mute_initiatorString

Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding. Corresponds to the JSON property muteInitiator

Returns:

  • (String)


2843
2844
2845
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2843

def mute_initiator
  @mute_initiator
end

#mute_update_timeString

Output only. The most recent time this finding was muted or unmuted. Corresponds to the JSON property muteUpdateTime

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2848

def mute_update_time
  @mute_update_time
end

#nameString

The relative resource name of the finding. Example: "organizations/ organization_id/sources/source_id/findings/finding_id", "folders/ folder_id/sources/source_id/findings/finding_id", "projects/project_id/ sources/source_id/findings/finding_id". Corresponds to the JSON property name

Returns:

  • (String)


2857
2858
2859
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2857

def name
  @name
end

#networksArray<Google::Apis::SecuritycenterV1beta2::Network>

Represents the VPC networks that the resource is attached to. Corresponds to the JSON property networks



2862
2863
2864
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2862

def networks
  @networks
end

#next_stepsString

Steps to address the finding. Corresponds to the JSON property nextSteps

Returns:

  • (String)


2867
2868
2869
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2867

def next_steps
  @next_steps
end

#notebookGoogle::Apis::SecuritycenterV1beta2::Notebook

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding. Corresponds to the JSON property notebook



2874
2875
2876
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2874

def notebook
  @notebook
end

#org_policiesArray<Google::Apis::SecuritycenterV1beta2::OrgPolicy>

Contains information about the org policies associated with the finding. Corresponds to the JSON property orgPolicies



2879
2880
2881
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2879

def org_policies
  @org_policies
end

#parentString

The relative resource name of the source the finding belongs to. See: https:// cloud.google.com/apis/design/resource_names#relative_resource_name This field is immutable after creation time. For example: "organizations/organization_id /sources/source_id" Corresponds to the JSON property parent

Returns:

  • (String)


2887
2888
2889
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2887

def parent
  @parent
end

#parent_display_nameString

Output only. The human readable display name of the finding source such as " Event Threat Detection" or "Security Health Analytics". Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


2893
2894
2895
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2893

def parent_display_name
  @parent_display_name
end

#policy_violation_summaryGoogle::Apis::SecuritycenterV1beta2::PolicyViolationSummary

Metadata summarizing policy violations of child resources of the affected resource. finding_category and resource determine the exact semantics of the counts. For example, when category= DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage. googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud Storage objects in my-bucket-name which violate a Public Access control. Corresponds to the JSON property policyViolationSummary



2903
2904
2905
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2903

def policy_violation_summary
  @policy_violation_summary
end

#processesArray<Google::Apis::SecuritycenterV1beta2::Process>

Represents operating system processes associated with the Finding. Corresponds to the JSON property processes



2908
2909
2910
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2908

def processes
  @processes
end

#resource_nameString

For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for. See: https://cloud.google.com/apis/design/ resource_names#full_resource_name When the finding is for a non-Google Cloud resource, the resourceName can be a customer or partner defined string. This field is immutable after creation time. Corresponds to the JSON property resourceName

Returns:

  • (String)


2917
2918
2919
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2917

def resource_name
  @resource_name
end

#secretGoogle::Apis::SecuritycenterV1beta2::Secret

Details about a secret or credential associated with the finding. Corresponds to the JSON property secret



2922
2923
2924
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2922

def secret
  @secret
end

#security_marksGoogle::Apis::SecuritycenterV1beta2::SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



2930
2931
2932
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2930

def security_marks
  @security_marks
end

#security_postureGoogle::Apis::SecuritycenterV1beta2::SecurityPosture

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud. Corresponds to the JSON property securityPosture



2938
2939
2940
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2938

def security_posture
  @security_posture
end

#severityString

The severity of the finding. This field is managed by the source that writes the finding. Corresponds to the JSON property severity

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2944

def severity
  @severity
end

#source_propertiesHash<String,Object>

Source specific properties. These properties are managed by the source that writes the finding. The key names in the source_properties map must be between 1 and 255 characters, and must start with a letter and contain alphanumeric characters or underscores only. Corresponds to the JSON property sourceProperties

Returns:



2952
2953
2954
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2952

def source_properties
  @source_properties
end

#stateString

The state of the finding. Corresponds to the JSON property state

Returns:

  • (String)


2957
2958
2959
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2957

def state
  @state
end

#toxic_combinationGoogle::Apis::SecuritycenterV1beta2::ToxicCombination

Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination. Corresponds to the JSON property toxicCombination



2964
2965
2966
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2964

def toxic_combination
  @toxic_combination
end

#vertex_aiGoogle::Apis::SecuritycenterV1beta2::VertexAi

Vertex AI-related information associated with the finding. Corresponds to the JSON property vertexAi



2969
2970
2971
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2969

def vertex_ai
  @vertex_ai
end

#vulnerabilityGoogle::Apis::SecuritycenterV1beta2::Vulnerability

Refers to common vulnerability fields e.g. cve, cvss, cwe etc. Corresponds to the JSON property vulnerability



2974
2975
2976
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2974

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2981

def update!(**args)
  @access = args[:access] if args.key?(:access)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @agent_data_access_events = args[:agent_data_access_events] if args.key?(:agent_data_access_events)
  @ai_model = args[:ai_model] if args.key?(:ai_model)
  @application = args[:application] if args.key?(:application)
  @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies)
  @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure)
  @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @category = args[:category] if args.key?(:category)
  @chokepoint = args[:chokepoint] if args.key?(:chokepoint)
  @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor)
  @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile)
  @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection)
  @compliance_details = args[:compliance_details] if args.key?(:compliance_details)
  @compliances = args[:compliances] if args.key?(:compliances)
  @connections = args[:connections] if args.key?(:connections)
  @contacts = args[:contacts] if args.key?(:contacts)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_access_events = args[:data_access_events] if args.key?(:data_access_events)
  @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events)
  @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events)
  @database = args[:database] if args.key?(:database)
  @description = args[:description] if args.key?(:description)
  @discovered_workload = args[:discovered_workload] if args.key?(:discovered_workload)
  @disk = args[:disk] if args.key?(:disk)
  @event_time = args[:event_time] if args.key?(:event_time)
  @exfiltration = args[:exfiltration] if args.key?(:exfiltration)
  @external_exposure = args[:external_exposure] if args.key?(:external_exposure)
  @external_systems = args[:external_systems] if args.key?(:external_systems)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @files = args[:files] if args.key?(:files)
  @finding_class = args[:finding_class] if args.key?(:finding_class)
  @group_memberships = args[:group_memberships] if args.key?(:group_memberships)
  @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings)
  @indicator = args[:indicator] if args.key?(:indicator)
  @ip_rules = args[:ip_rules] if args.key?(:ip_rules)
  @job = args[:job] if args.key?(:job)
  @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit)
  @kubernetes = args[:kubernetes] if args.key?(:kubernetes)
  @load_balancers = args[:load_balancers] if args.key?(:load_balancers)
  @log_entries = args[:log_entries] if args.key?(:log_entries)
  @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack)
  @module_name = args[:module_name] if args.key?(:module_name)
  @mute = args[:mute] if args.key?(:mute)
  @mute_info = args[:mute_info] if args.key?(:mute_info)
  @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator)
  @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @next_steps = args[:next_steps] if args.key?(:next_steps)
  @notebook = args[:notebook] if args.key?(:notebook)
  @org_policies = args[:org_policies] if args.key?(:org_policies)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @policy_violation_summary = args[:policy_violation_summary] if args.key?(:policy_violation_summary)
  @processes = args[:processes] if args.key?(:processes)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @secret = args[:secret] if args.key?(:secret)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @security_posture = args[:security_posture] if args.key?(:security_posture)
  @severity = args[:severity] if args.key?(:severity)
  @source_properties = args[:source_properties] if args.key?(:source_properties)
  @state = args[:state] if args.key?(:state)
  @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination)
  @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end