Class: Google::Apis::SecuritycenterV1beta2::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



2860
2861
2862
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessGoogle::Apis::SecuritycenterV1beta2::Access

Represents an access event. Corresponds to the JSON property access



2464
2465
2466
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2464

def access
  @access
end

#affected_resourcesGoogle::Apis::SecuritycenterV1beta2::AffectedResources

Details about resources affected by this finding. Corresponds to the JSON property affectedResources



2469
2470
2471
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2469

def affected_resources
  @affected_resources
end

#ai_modelGoogle::Apis::SecuritycenterV1beta2::AiModel

Contains information about the AI model associated with the finding. Corresponds to the JSON property aiModel



2474
2475
2476
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2474

def ai_model
  @ai_model
end

#applicationGoogle::Apis::SecuritycenterV1beta2::Application

Represents an application associated with a finding. Corresponds to the JSON property application



2479
2480
2481
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2479

def application
  @application
end

#artifact_guard_policiesGoogle::Apis::SecuritycenterV1beta2::ArtifactGuardPolicies

Represents the result of evaluating artifact guard policies. Corresponds to the JSON property artifactGuardPolicies



2484
2485
2486
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2484

def artifact_guard_policies
  @artifact_guard_policies
end

#attack_exposureGoogle::Apis::SecuritycenterV1beta2::AttackExposure

An attack exposure contains the results of an attack path simulation run. Corresponds to the JSON property attackExposure



2489
2490
2491
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2489

def attack_exposure
  @attack_exposure
end

#backup_disaster_recoveryGoogle::Apis::SecuritycenterV1beta2::BackupDisasterRecovery

Information related to Google Cloud Backup and DR Service findings. Corresponds to the JSON property backupDisasterRecovery



2494
2495
2496
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2494

def backup_disaster_recovery
  @backup_disaster_recovery
end

#canonical_nameString

The canonical name of the finding. It's either "organizations/organization_id /sources/source_id/findings/finding_id", "folders/folder_id/sources/ source_id/findings/finding_id" or "projects/project_number/sources/ source_id/findings/finding_id", depending on the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON property canonicalName

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2503

def canonical_name
  @canonical_name
end

#categoryString

The additional taxonomy group within findings from a given source. This field is immutable after creation time. Example: "XSS_FLASH_INJECTION" Corresponds to the JSON property category

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2509

def category
  @category
end

#chokepointGoogle::Apis::SecuritycenterV1beta2::Chokepoint

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations. Corresponds to the JSON property chokepoint



2517
2518
2519
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2517

def chokepoint
  @chokepoint
end

#cloud_armorGoogle::Apis::SecuritycenterV1beta2::CloudArmor

Fields related to Google Cloud Armor findings. Corresponds to the JSON property cloudArmor



2522
2523
2524
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2522

def cloud_armor
  @cloud_armor
end

#cloud_dlp_data_profileGoogle::Apis::SecuritycenterV1beta2::CloudDlpDataProfile

The data profile associated with the finding. Corresponds to the JSON property cloudDlpDataProfile



2528
2529
2530
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2528

def cloud_dlp_data_profile
  @cloud_dlp_data_profile
end

#cloud_dlp_inspectionGoogle::Apis::SecuritycenterV1beta2::CloudDlpInspection

Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding. Corresponds to the JSON property cloudDlpInspection



2535
2536
2537
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2535

def cloud_dlp_inspection
  @cloud_dlp_inspection
end

#compliance_detailsGoogle::Apis::SecuritycenterV1beta2::ComplianceDetails

Compliance Details associated with the finding. Corresponds to the JSON property complianceDetails



2540
2541
2542
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2540

def compliance_details
  @compliance_details
end

#compliancesArray<Google::Apis::SecuritycenterV1beta2::Compliance>

Contains compliance information for security standards associated to the finding. Corresponds to the JSON property compliances



2546
2547
2548
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2546

def compliances
  @compliances
end

#connectionsArray<Google::Apis::SecuritycenterV1beta2::Connection>

Contains information about the IP connection associated with the finding. Corresponds to the JSON property connections



2551
2552
2553
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2551

def connections
  @connections
end

#contactsHash<String,Google::Apis::SecuritycenterV1beta2::ContactDetails>

Output only. Map containing the points of contact for the given finding. The key represents the type of contact, while the value contains a list of all the contacts that pertain. Please refer to: https://cloud.google.com/resource- manager/docs/managing-notification-contacts#notification-categories " security": "contacts": [ "email": "person1@company.com", "email": " person2@company.com" ] Corresponds to the JSON property contacts



2561
2562
2563
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2561

def contacts
  @contacts
end

#containersArray<Google::Apis::SecuritycenterV1beta2::Container>

Containers associated with the finding. This field provides information for both Kubernetes and non-Kubernetes containers. Corresponds to the JSON property containers



2567
2568
2569
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2567

def containers
  @containers
end

#create_timeString

The time at which the finding was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


2572
2573
2574
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2572

def create_time
  @create_time
end

#data_access_eventsArray<Google::Apis::SecuritycenterV1beta2::DataAccessEvent>

Data access events associated with the finding. Corresponds to the JSON property dataAccessEvents



2577
2578
2579
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2577

def data_access_events
  @data_access_events
end

#data_flow_eventsArray<Google::Apis::SecuritycenterV1beta2::DataFlowEvent>

Data flow events associated with the finding. Corresponds to the JSON property dataFlowEvents



2582
2583
2584
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2582

def data_flow_events
  @data_flow_events
end

#data_retention_deletion_eventsArray<Google::Apis::SecuritycenterV1beta2::DataRetentionDeletionEvent>

Data retention deletion events associated with the finding. Corresponds to the JSON property dataRetentionDeletionEvents



2587
2588
2589
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2587

def data_retention_deletion_events
  @data_retention_deletion_events
end

#databaseGoogle::Apis::SecuritycenterV1beta2::Database

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided. Corresponds to the JSON property database



2598
2599
2600
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2598

def database
  @database
end

#descriptionString

Contains more details about the finding. Corresponds to the JSON property description

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2603

def description
  @description
end

#diskGoogle::Apis::SecuritycenterV1beta2::Disk

Contains information about the disk associated with the finding. Corresponds to the JSON property disk



2608
2609
2610
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2608

def disk
  @disk
end

#event_timeString

The time the finding was first detected. If an existing finding is updated, then this is the time the update occurred. For example, if the finding represents an open firewall, this property captures the time the detector believes the firewall became open. The accuracy is determined by the detector. If the finding is later resolved, then this time reflects when the finding was resolved. This must not be set to a value greater than the current timestamp. Corresponds to the JSON property eventTime

Returns:

  • (String)


2618
2619
2620
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2618

def event_time
  @event_time
end

#exfiltrationGoogle::Apis::SecuritycenterV1beta2::Exfiltration

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to. Corresponds to the JSON property exfiltration



2626
2627
2628
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2626

def exfiltration
  @exfiltration
end

#external_exposureGoogle::Apis::SecuritycenterV1beta2::ExternalExposure

Details about the externally exposed resource associated with the finding. Corresponds to the JSON property externalExposure



2631
2632
2633
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2631

def external_exposure
  @external_exposure
end

#external_systemsHash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem>

Output only. Third party SIEM/SOAR fields within SCC, contains external system information and external system finding fields. Corresponds to the JSON property externalSystems



2637
2638
2639
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2637

def external_systems
  @external_systems
end

#external_uriString

The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found. This field is guaranteed to be either empty or a well formed URL. Corresponds to the JSON property externalUri

Returns:

  • (String)


2644
2645
2646
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2644

def external_uri
  @external_uri
end

#filesArray<Google::Apis::SecuritycenterV1beta2::File>

File associated with the finding. Corresponds to the JSON property files



2649
2650
2651
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2649

def files
  @files
end

#finding_classString

The class of the finding. Corresponds to the JSON property findingClass

Returns:

  • (String)


2654
2655
2656
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2654

def finding_class
  @finding_class
end

#group_membershipsArray<Google::Apis::SecuritycenterV1beta2::GroupMembership>

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way. This field cannot be updated. Its value is ignored in all update requests. Corresponds to the JSON property groupMemberships



2661
2662
2663
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2661

def group_memberships
  @group_memberships
end

#iam_bindingsArray<Google::Apis::SecuritycenterV1beta2::IamBinding>

Represents IAM bindings associated with the finding. Corresponds to the JSON property iamBindings



2666
2667
2668
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2666

def iam_bindings
  @iam_bindings
end

#indicatorGoogle::Apis::SecuritycenterV1beta2::Indicator

Represents what's commonly known as an indicator of compromise (IoC) in computer forensics. This is an artifact observed on a network or in an operating system that, with high confidence, indicates a computer intrusion. For more information, see Indicator of compromise. Corresponds to the JSON property indicator



2675
2676
2677
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2675

def indicator
  @indicator
end

#ip_rulesGoogle::Apis::SecuritycenterV1beta2::IpRules

IP rules associated with the finding. Corresponds to the JSON property ipRules



2680
2681
2682
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2680

def ip_rules
  @ip_rules
end

#jobGoogle::Apis::SecuritycenterV1beta2::Job

Describes a job Corresponds to the JSON property job



2685
2686
2687
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2685

def job
  @job
end

#kernel_rootkitGoogle::Apis::SecuritycenterV1beta2::KernelRootkit

Kernel mode rootkit signatures. Corresponds to the JSON property kernelRootkit



2690
2691
2692
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2690

def kernel_rootkit
  @kernel_rootkit
end

#kubernetesGoogle::Apis::SecuritycenterV1beta2::Kubernetes

Kubernetes-related attributes. Corresponds to the JSON property kubernetes



2695
2696
2697
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2695

def kubernetes
  @kubernetes
end

#load_balancersArray<Google::Apis::SecuritycenterV1beta2::LoadBalancer>

The load balancers associated with the finding. Corresponds to the JSON property loadBalancers



2700
2701
2702
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2700

def load_balancers
  @load_balancers
end

#log_entriesArray<Google::Apis::SecuritycenterV1beta2::LogEntry>

Log entries that are relevant to the finding. Corresponds to the JSON property logEntries



2705
2706
2707
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2705

def log_entries
  @log_entries
end

#mitre_attackGoogle::Apis::SecuritycenterV1beta2::MitreAttack

MITRE ATT&CK tactics and techniques related to this finding. See: https:// attack.mitre.org Corresponds to the JSON property mitreAttack



2711
2712
2713
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2711

def mitre_attack
  @mitre_attack
end

#module_nameString

Unique identifier of the module which generated the finding. Example: folders/ 598186756061/securityHealthAnalyticsSettings/customModules/56799441161885 Corresponds to the JSON property moduleName

Returns:

  • (String)


2717
2718
2719
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2717

def module_name
  @module_name
end

#muteString

Indicates the mute state of a finding (either muted, unmuted or undefined). Unlike other attributes of a finding, a finding provider shouldn't set the value of mute. Corresponds to the JSON property mute

Returns:

  • (String)


2724
2725
2726
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2724

def mute
  @mute
end

#mute_infoGoogle::Apis::SecuritycenterV1beta2::MuteInfo

Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules. Corresponds to the JSON property muteInfo



2730
2731
2732
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2730

def mute_info
  @mute_info
end

#mute_initiatorString

Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding. Corresponds to the JSON property muteInitiator

Returns:

  • (String)


2737
2738
2739
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2737

def mute_initiator
  @mute_initiator
end

#mute_update_timeString

Output only. The most recent time this finding was muted or unmuted. Corresponds to the JSON property muteUpdateTime

Returns:

  • (String)


2742
2743
2744
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2742

def mute_update_time
  @mute_update_time
end

#nameString

The relative resource name of the finding. Example: "organizations/ organization_id/sources/source_id/findings/finding_id", "folders/ folder_id/sources/source_id/findings/finding_id", "projects/project_id/ sources/source_id/findings/finding_id". Corresponds to the JSON property name

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2751

def name
  @name
end

#networksArray<Google::Apis::SecuritycenterV1beta2::Network>

Represents the VPC networks that the resource is attached to. Corresponds to the JSON property networks



2756
2757
2758
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2756

def networks
  @networks
end

#next_stepsString

Steps to address the finding. Corresponds to the JSON property nextSteps

Returns:

  • (String)


2761
2762
2763
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2761

def next_steps
  @next_steps
end

#notebookGoogle::Apis::SecuritycenterV1beta2::Notebook

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding. Corresponds to the JSON property notebook



2768
2769
2770
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2768

def notebook
  @notebook
end

#org_policiesArray<Google::Apis::SecuritycenterV1beta2::OrgPolicy>

Contains information about the org policies associated with the finding. Corresponds to the JSON property orgPolicies



2773
2774
2775
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2773

def org_policies
  @org_policies
end

#parentString

The relative resource name of the source the finding belongs to. See: https:// cloud.google.com/apis/design/resource_names#relative_resource_name This field is immutable after creation time. For example: "organizations/organization_id /sources/source_id" Corresponds to the JSON property parent

Returns:

  • (String)


2781
2782
2783
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2781

def parent
  @parent
end

#parent_display_nameString

Output only. The human readable display name of the finding source such as " Event Threat Detection" or "Security Health Analytics". Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2787

def parent_display_name
  @parent_display_name
end

#processesArray<Google::Apis::SecuritycenterV1beta2::Process>

Represents operating system processes associated with the Finding. Corresponds to the JSON property processes



2792
2793
2794
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2792

def processes
  @processes
end

#resource_nameString

For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for. See: https://cloud.google.com/apis/design/ resource_names#full_resource_name When the finding is for a non-Google Cloud resource, the resourceName can be a customer or partner defined string. This field is immutable after creation time. Corresponds to the JSON property resourceName

Returns:

  • (String)


2801
2802
2803
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2801

def resource_name
  @resource_name
end

#secretGoogle::Apis::SecuritycenterV1beta2::Secret

Details about a secret or credential associated with the finding. Corresponds to the JSON property secret



2806
2807
2808
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2806

def secret
  @secret
end

#security_marksGoogle::Apis::SecuritycenterV1beta2::SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



2814
2815
2816
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2814

def security_marks
  @security_marks
end

#security_postureGoogle::Apis::SecuritycenterV1beta2::SecurityPosture

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud. Corresponds to the JSON property securityPosture



2822
2823
2824
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2822

def security_posture
  @security_posture
end

#severityString

The severity of the finding. This field is managed by the source that writes the finding. Corresponds to the JSON property severity

Returns:

  • (String)


2828
2829
2830
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2828

def severity
  @severity
end

#source_propertiesHash<String,Object>

Source specific properties. These properties are managed by the source that writes the finding. The key names in the source_properties map must be between 1 and 255 characters, and must start with a letter and contain alphanumeric characters or underscores only. Corresponds to the JSON property sourceProperties

Returns:



2836
2837
2838
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2836

def source_properties
  @source_properties
end

#stateString

The state of the finding. Corresponds to the JSON property state

Returns:

  • (String)


2841
2842
2843
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2841

def state
  @state
end

#toxic_combinationGoogle::Apis::SecuritycenterV1beta2::ToxicCombination

Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination. Corresponds to the JSON property toxicCombination



2848
2849
2850
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2848

def toxic_combination
  @toxic_combination
end

#vertex_aiGoogle::Apis::SecuritycenterV1beta2::VertexAi

Vertex AI-related information associated with the finding. Corresponds to the JSON property vertexAi



2853
2854
2855
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2853

def vertex_ai
  @vertex_ai
end

#vulnerabilityGoogle::Apis::SecuritycenterV1beta2::Vulnerability

Refers to common vulnerability fields e.g. cve, cvss, cwe etc. Corresponds to the JSON property vulnerability



2858
2859
2860
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2858

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2865

def update!(**args)
  @access = args[:access] if args.key?(:access)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @ai_model = args[:ai_model] if args.key?(:ai_model)
  @application = args[:application] if args.key?(:application)
  @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies)
  @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure)
  @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @category = args[:category] if args.key?(:category)
  @chokepoint = args[:chokepoint] if args.key?(:chokepoint)
  @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor)
  @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile)
  @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection)
  @compliance_details = args[:compliance_details] if args.key?(:compliance_details)
  @compliances = args[:compliances] if args.key?(:compliances)
  @connections = args[:connections] if args.key?(:connections)
  @contacts = args[:contacts] if args.key?(:contacts)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_access_events = args[:data_access_events] if args.key?(:data_access_events)
  @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events)
  @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events)
  @database = args[:database] if args.key?(:database)
  @description = args[:description] if args.key?(:description)
  @disk = args[:disk] if args.key?(:disk)
  @event_time = args[:event_time] if args.key?(:event_time)
  @exfiltration = args[:exfiltration] if args.key?(:exfiltration)
  @external_exposure = args[:external_exposure] if args.key?(:external_exposure)
  @external_systems = args[:external_systems] if args.key?(:external_systems)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @files = args[:files] if args.key?(:files)
  @finding_class = args[:finding_class] if args.key?(:finding_class)
  @group_memberships = args[:group_memberships] if args.key?(:group_memberships)
  @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings)
  @indicator = args[:indicator] if args.key?(:indicator)
  @ip_rules = args[:ip_rules] if args.key?(:ip_rules)
  @job = args[:job] if args.key?(:job)
  @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit)
  @kubernetes = args[:kubernetes] if args.key?(:kubernetes)
  @load_balancers = args[:load_balancers] if args.key?(:load_balancers)
  @log_entries = args[:log_entries] if args.key?(:log_entries)
  @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack)
  @module_name = args[:module_name] if args.key?(:module_name)
  @mute = args[:mute] if args.key?(:mute)
  @mute_info = args[:mute_info] if args.key?(:mute_info)
  @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator)
  @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @next_steps = args[:next_steps] if args.key?(:next_steps)
  @notebook = args[:notebook] if args.key?(:notebook)
  @org_policies = args[:org_policies] if args.key?(:org_policies)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @processes = args[:processes] if args.key?(:processes)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @secret = args[:secret] if args.key?(:secret)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @security_posture = args[:security_posture] if args.key?(:security_posture)
  @severity = args[:severity] if args.key?(:severity)
  @source_properties = args[:source_properties] if args.key?(:source_properties)
  @state = args[:state] if args.key?(:state)
  @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination)
  @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end