Class: Google::Apis::SecuritycenterV1beta2::Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta2::Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Framework
constructor
A new instance of Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Framework
Returns a new instance of Framework.
2994 2995 2996 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
2968 2969 2970 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2968 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta2::Control>
The controls associated with the framework.
Corresponds to the JSON property controls
2973 2974 2975 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2973 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
2980 2981 2982 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2980 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
2985 2986 2987 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2985 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
2992 2993 2994 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2992 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2999 3000 3001 3002 3003 3004 3005 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2999 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |