Class: Google::Apis::SecuritycenterV1beta2::Framework

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Compliance framework associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Framework

Returns a new instance of Framework.



2825
2826
2827
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryArray<String>

Category of the framework associated with the finding. E.g. Security Benchmark, or Assured Workloads Corresponds to the JSON property category

Returns:

  • (Array<String>)


2799
2800
2801
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2799

def category
  @category
end

#controlsArray<Google::Apis::SecuritycenterV1beta2::Control>

The controls associated with the framework. Corresponds to the JSON property controls



2804
2805
2806
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2804

def controls
  @controls
end

#display_nameString

Display name of the framework. For a standard framework, this will look like e. g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined string like MyFramework Corresponds to the JSON property displayName

Returns:

  • (String)


2811
2812
2813
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2811

def display_name
  @display_name
end

#nameString

Name of the framework associated with the finding Corresponds to the JSON property name

Returns:

  • (String)


2816
2817
2818
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2816

def name
  @name
end

#typeString

Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property type

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2823

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2830
2831
2832
2833
2834
2835
2836
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2830

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @controls = args[:controls] if args.key?(:controls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end