Class: Google::Apis::SecuritycenterV1beta2::GcpMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GcpMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Folder>
Output only.
-
#organization ⇒ String
The name of the organization that the resource belongs to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpMetadata
constructor
A new instance of GcpMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpMetadata
Returns a new instance of GcpMetadata.
3164 3165 3166 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
3137 3138 3139 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3137 def folders @folders end |
#organization ⇒ String
The name of the organization that the resource belongs to.
Corresponds to the JSON property organization
3142 3143 3144 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3142 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
3147 3148 3149 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3147 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
3152 3153 3154 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3152 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
3157 3158 3159 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3157 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
3162 3163 3164 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3162 def project_display_name @project_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3169 3170 3171 3172 3173 3174 3175 3176 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3169 def update!(**args) @folders = args[:folders] if args.key?(:folders) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) end |