Class: Google::Apis::SecuritycenterV1beta2::GcpMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GcpMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Folder>
Output only.
-
#organization ⇒ String
The name of the organization that the resource belongs to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpMetadata
constructor
A new instance of GcpMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpMetadata
Returns a new instance of GcpMetadata.
3045 3046 3047 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
3018 3019 3020 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3018 def folders @folders end |
#organization ⇒ String
The name of the organization that the resource belongs to.
Corresponds to the JSON property organization
3023 3024 3025 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3023 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
3028 3029 3030 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3028 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
3033 3034 3035 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3033 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
3038 3039 3040 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3038 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
3043 3044 3045 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3043 def project_display_name @project_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3050 3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3050 def update!(**args) @folders = args[:folders] if args.key?(:folders) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) end |