Class: Google::Apis::SecuritycenterV1beta2::GcpMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpMetadata

Returns a new instance of GcpMetadata.



2876
2877
2878
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



2849
2850
2851
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2849

def folders
  @folders
end

#organizationString

The name of the organization that the resource belongs to. Corresponds to the JSON property organization

Returns:

  • (String)


2854
2855
2856
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2854

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


2859
2860
2861
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2859

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


2864
2865
2866
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2864

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


2869
2870
2871
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2869

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


2874
2875
2876
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2874

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2881
2882
2883
2884
2885
2886
2887
2888
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 2881

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end