Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Binding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Binding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a Kubernetes RoleBinding or ClusterRoleBinding.
Instance Attribute Summary collapse
-
#name ⇒ String
Name for the binding.
-
#ns ⇒ String
Namespace for the binding.
-
#role ⇒ Google::Apis::SecuritycenterV1beta2::Role
Kubernetes Role or ClusterRole.
-
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta2::Subject>
Represents one or more subjects that are bound to the role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Binding
constructor
A new instance of GoogleCloudSecuritycenterV1Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Binding
Returns a new instance of GoogleCloudSecuritycenterV1Binding.
3187 3188 3189 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name for the binding.
Corresponds to the JSON property name
3169 3170 3171 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3169 def name @name end |
#ns ⇒ String
Namespace for the binding.
Corresponds to the JSON property ns
3174 3175 3176 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3174 def ns @ns end |
#role ⇒ Google::Apis::SecuritycenterV1beta2::Role
Kubernetes Role or ClusterRole.
Corresponds to the JSON property role
3179 3180 3181 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3179 def role @role end |
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta2::Subject>
Represents one or more subjects that are bound to the role. Not always
available for PATCH requests.
Corresponds to the JSON property subjects
3185 3186 3187 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3185 def subjects @subjects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3192 3193 3194 3195 3196 3197 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3192 def update!(**args) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @role = args[:role] if args.key?(:role) @subjects = args[:subjects] if args.key?(:subjects) end |