Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Defines the properties in a custom module configuration for Security Health Analytics. Use the custom module configuration to create custom detectors that generate custom findings for resources that you specify.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomConfig

Returns a new instance of GoogleCloudSecuritycenterV1CustomConfig.



3102
3103
3104
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_outputGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomOutputSpec

A set of optional name-value pairs that define custom source properties to return with each finding that is generated by the custom module. The custom source properties that are defined here are included in the finding JSON under sourceProperties. Corresponds to the JSON property customOutput



3056
3057
3058
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3056

def custom_output
  @custom_output
end

#descriptionString

Text that describes the vulnerability or misconfiguration that the custom module detects. This explanation is returned with each finding instance to help investigators understand the detected issue. The text must be enclosed in quotation marks. Corresponds to the JSON property description

Returns:

  • (String)


3064
3065
3066
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3064

def description
  @description
end

#predicateGoogle::Apis::SecuritycenterV1beta2::Expr

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information. Corresponds to the JSON property predicate



3083
3084
3085
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3083

def predicate
  @predicate
end

#recommendationString

An explanation of the recommended steps that security teams can take to resolve the detected issue. This explanation is returned with each finding generated by this module in the nextSteps property of the finding JSON. Corresponds to the JSON property recommendation

Returns:

  • (String)


3090
3091
3092
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3090

def recommendation
  @recommendation
end

#resource_selectorGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceSelector

Resource for selecting resource type. Corresponds to the JSON property resourceSelector



3095
3096
3097
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3095

def resource_selector
  @resource_selector
end

#severityString

The severity to assign to findings generated by the module. Corresponds to the JSON property severity

Returns:

  • (String)


3100
3101
3102
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3100

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3107
3108
3109
3110
3111
3112
3113
3114
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3107

def update!(**args)
  @custom_output = args[:custom_output] if args.key?(:custom_output)
  @description = args[:description] if args.key?(:description)
  @predicate = args[:predicate] if args.key?(:predicate)
  @recommendation = args[:recommendation] if args.key?(:recommendation)
  @resource_selector = args[:resource_selector] if args.key?(:resource_selector)
  @severity = args[:severity] if args.key?(:severity)
end