Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomOutputSpec
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomOutputSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A set of optional name-value pairs that define custom source properties to
return with each finding that is generated by the custom module. The custom
source properties that are defined here are included in the finding JSON under
sourceProperties.
Instance Attribute Summary collapse
-
#properties ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Property>
A list of custom output properties to add to the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec
constructor
A new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec
Returns a new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.
3417 3418 3419 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#properties ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Property>
A list of custom output properties to add to the finding.
Corresponds to the JSON property properties
3415 3416 3417 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3415 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3422 3423 3424 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3422 def update!(**args) @properties = args[:properties] if args.key?(:properties) end |