Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomOutputSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A set of optional name-value pairs that define custom source properties to return with each finding that is generated by the custom module. The custom source properties that are defined here are included in the finding JSON under sourceProperties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec

Returns a new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.



3298
3299
3300
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#propertiesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Property>

A list of custom output properties to add to the finding. Corresponds to the JSON property properties



3296
3297
3298
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3296

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3303
3304
3305
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3303

def update!(**args)
  @properties = args[:properties] if args.key?(:properties)
end