Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
An EffectiveSecurityHealthAnalyticsCustomModule is the representation of a
Security Health Analytics custom module at a specified level of the resource
hierarchy: organization, folder, or project. If a custom module is inherited
from a parent organization or folder, the value of the enablementState
property in EffectiveSecurityHealthAnalyticsCustomModule is set to the value
that is effective in the parent, instead of INHERITED. For example, if the
module is enabled in a parent organization or folder, the effective
enablement_state for the module in all child folders or projects is also
enabled. EffectiveSecurityHealthAnalyticsCustomModule is read-only.
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
The cloud provider of the custom module.
-
#custom_config ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health Analytics.
-
#display_name ⇒ String
Output only.
-
#enablement_state ⇒ String
Output only.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule
constructor
A new instance of GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule
Returns a new instance of GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule.
3533 3534 3535 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
The cloud provider of the custom module.
Corresponds to the JSON property cloudProvider
3501 3502 3503 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3501 def cloud_provider @cloud_provider end |
#custom_config ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health
Analytics. Use the custom module configuration to create custom detectors that
generate custom findings for resources that you specify.
Corresponds to the JSON property customConfig
3508 3509 3510 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3508 def custom_config @custom_config end |
#display_name ⇒ String
Output only. The display name for the custom module. The name must be between
1 and 128 characters, start with a lowercase letter, and contain alphanumeric
characters or underscores only.
Corresponds to the JSON property displayName
3515 3516 3517 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3515 def display_name @display_name end |
#enablement_state ⇒ String
Output only. The effective state of enablement for the module at the given
level of the hierarchy.
Corresponds to the JSON property enablementState
3521 3522 3523 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3521 def enablement_state @enablement_state end |
#name ⇒ String
Output only. The resource name of the custom module. Its format is "
organizations/organization/securityHealthAnalyticsSettings/
effectiveCustomModules/customModule", or "folders/folder/
securityHealthAnalyticsSettings/effectiveCustomModules/customModule", or "
projects/project/securityHealthAnalyticsSettings/effectiveCustomModules/
customModule"
Corresponds to the JSON property name
3531 3532 3533 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3531 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3538 3539 3540 3541 3542 3543 3544 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3538 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @custom_config = args[:custom_config] if args.key?(:custom_config) @display_name = args[:display_name] if args.key?(:display_name) @enablement_state = args[:enablement_state] if args.key?(:enablement_state) @name = args[:name] if args.key?(:name) end |