Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Representation of third party SIEM/SOAR fields within SCC.
Instance Attribute Summary collapse
-
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
-
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
-
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
-
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
-
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
-
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
-
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
-
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the external system.
-
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property
name. -
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the external system.
-
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
constructor
A new instance of GoogleCloudSecuritycenterV1ExternalSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.
3612 3613 3614 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
Corresponds to the JSON property assignees
3554 3555 3556 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3554 def assignees @assignees end |
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
Corresponds to the JSON property caseCloseTime
3559 3560 3561 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3559 def case_close_time @case_close_time end |
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
Corresponds to the JSON property caseCreateTime
3564 3565 3566 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3564 def case_create_time @case_create_time end |
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
Corresponds to the JSON property casePriority
3569 3570 3571 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3569 def case_priority @case_priority end |
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
Corresponds to the JSON property caseSla
3574 3575 3576 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3574 def case_sla @case_sla end |
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
Corresponds to the JSON property caseUri
3579 3580 3581 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3579 def case_uri @case_uri end |
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
Corresponds to the JSON property externalSystemUpdateTime
3584 3585 3586 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3584 def external_system_update_time @external_system_update_time end |
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the
external system.
Corresponds to the JSON property externalUid
3590 3591 3592 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3590 def external_uid @external_uid end |
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/
sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/
findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/
123456/externalSystems/jira"
Corresponds to the JSON property name
3598 3599 3600 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3598 def name @name end |
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the
external system.
Corresponds to the JSON property status
3604 3605 3606 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3604 def status @status end |
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the
resolution of the issue that is identified by this finding.
Corresponds to the JSON property ticketInfo
3610 3611 3612 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3610 def ticket_info @ticket_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3617 def update!(**args) @assignees = args[:assignees] if args.key?(:assignees) @case_close_time = args[:case_close_time] if args.key?(:case_close_time) @case_create_time = args[:case_create_time] if args.key?(:case_create_time) @case_priority = args[:case_priority] if args.key?(:case_priority) @case_sla = args[:case_sla] if args.key?(:case_sla) @case_uri = args[:case_uri] if args.key?(:case_uri) @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time) @external_uid = args[:external_uid] if args.key?(:external_uid) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @ticket_info = args[:ticket_info] if args.key?(:ticket_info) end |