Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Representation of third party SIEM/SOAR fields within SCC.
Instance Attribute Summary collapse
-
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
-
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
-
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
-
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
-
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
-
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
-
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
-
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the external system.
-
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property
name. -
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the external system.
-
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
constructor
A new instance of GoogleCloudSecuritycenterV1ExternalSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.
3553 3554 3555 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
Corresponds to the JSON property assignees
3495 3496 3497 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3495 def assignees @assignees end |
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
Corresponds to the JSON property caseCloseTime
3500 3501 3502 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3500 def case_close_time @case_close_time end |
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
Corresponds to the JSON property caseCreateTime
3505 3506 3507 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3505 def case_create_time @case_create_time end |
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
Corresponds to the JSON property casePriority
3510 3511 3512 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3510 def case_priority @case_priority end |
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
Corresponds to the JSON property caseSla
3515 3516 3517 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3515 def case_sla @case_sla end |
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
Corresponds to the JSON property caseUri
3520 3521 3522 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3520 def case_uri @case_uri end |
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
Corresponds to the JSON property externalSystemUpdateTime
3525 3526 3527 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3525 def external_system_update_time @external_system_update_time end |
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the
external system.
Corresponds to the JSON property externalUid
3531 3532 3533 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3531 def external_uid @external_uid end |
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/
sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/
findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/
123456/externalSystems/jira"
Corresponds to the JSON property name
3539 3540 3541 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3539 def name @name end |
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the
external system.
Corresponds to the JSON property status
3545 3546 3547 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3545 def status @status end |
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the
resolution of the issue that is identified by this finding.
Corresponds to the JSON property ticketInfo
3551 3552 3553 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3551 def ticket_info @ticket_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3558 def update!(**args) @assignees = args[:assignees] if args.key?(:assignees) @case_close_time = args[:case_close_time] if args.key?(:case_close_time) @case_create_time = args[:case_create_time] if args.key?(:case_create_time) @case_priority = args[:case_priority] if args.key?(:case_priority) @case_sla = args[:case_sla] if args.key?(:case_sla) @case_uri = args[:case_uri] if args.key?(:case_uri) @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time) @external_uid = args[:external_uid] if args.key?(:external_uid) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @ticket_info = args[:ticket_info] if args.key?(:ticket_info) end |