Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.



3265
3266
3267
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


3207
3208
3209
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3207

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


3212
3213
3214
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3212

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


3217
3218
3219
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3217

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


3222
3223
3224
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3222

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3227

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


3232
3233
3234
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3232

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


3237
3238
3239
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3237

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


3243
3244
3245
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3243

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property name

Returns:

  • (String)


3251
3252
3253
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3251

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


3257
3258
3259
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3257

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1beta2::TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



3263
3264
3265
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3263

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3270

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end