Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ExternalSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Representation of third party SIEM/SOAR fields within SCC.
Instance Attribute Summary collapse
-
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
-
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
-
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
-
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
-
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
-
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
-
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
-
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the external system.
-
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property
name. -
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the external system.
-
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
constructor
A new instance of GoogleCloudSecuritycenterV1ExternalSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.
3265 3266 3267 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
Corresponds to the JSON property assignees
3207 3208 3209 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3207 def assignees @assignees end |
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
Corresponds to the JSON property caseCloseTime
3212 3213 3214 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3212 def case_close_time @case_close_time end |
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
Corresponds to the JSON property caseCreateTime
3217 3218 3219 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3217 def case_create_time @case_create_time end |
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
Corresponds to the JSON property casePriority
3222 3223 3224 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3222 def case_priority @case_priority end |
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
Corresponds to the JSON property caseSla
3227 3228 3229 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3227 def case_sla @case_sla end |
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
Corresponds to the JSON property caseUri
3232 3233 3234 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3232 def case_uri @case_uri end |
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
Corresponds to the JSON property externalSystemUpdateTime
3237 3238 3239 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3237 def external_system_update_time @external_system_update_time end |
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the
external system.
Corresponds to the JSON property externalUid
3243 3244 3245 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3243 def external_uid @external_uid end |
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/
sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/
findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/
123456/externalSystems/jira"
Corresponds to the JSON property name
3251 3252 3253 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3251 def name @name end |
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the
external system.
Corresponds to the JSON property status
3257 3258 3259 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3257 def status @status end |
#ticket_info ⇒ Google::Apis::SecuritycenterV1beta2::TicketInfo
Information about the ticket, if any, that is being used to track the
resolution of the issue that is identified by this finding.
Corresponds to the JSON property ticketInfo
3263 3264 3265 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3263 def ticket_info @ticket_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3270 def update!(**args) @assignees = args[:assignees] if args.key?(:assignees) @case_close_time = args[:case_close_time] if args.key?(:case_close_time) @case_create_time = args[:case_create_time] if args.key?(:case_create_time) @case_priority = args[:case_priority] if args.key?(:case_priority) @case_sla = args[:case_sla] if args.key?(:case_sla) @case_uri = args[:case_uri] if args.key?(:case_uri) @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time) @external_uid = args[:external_uid] if args.key?(:external_uid) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @ticket_info = args[:ticket_info] if args.key?(:ticket_info) end |