Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource

Returns a new instance of GoogleCloudSecuritycenterV1Resource.



3739
3740
3741
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta2::AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



3626
3627
3628
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3626

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta2::AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



3631
3632
3633
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3631

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta2::AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



3636
3637
3638
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3636

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



3641
3642
3643
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3641

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta2::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



3647
3648
3649
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3647

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta2::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



3653
3654
3655
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3653

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the resource resides in. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


3658
3659
3660
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3658

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


3663
3664
3665
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3663

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1beta2::Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



3670
3671
3672
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3670

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


3675
3676
3677
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3675

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


3681
3682
3683
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3681

def name
  @name
end

#organizationString

Indicates which organization or tenant in the cloud provider the finding applies to. Corresponds to the JSON property organization

Returns:

  • (String)


3687
3688
3689
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3687

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


3692
3693
3694
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3692

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


3697
3698
3699
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3697

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


3702
3703
3704
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3702

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


3707
3708
3709
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3707

def project_display_name
  @project_display_name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta2::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



3713
3714
3715
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3713

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


3726
3727
3728
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3726

def resource_path_string
  @resource_path_string
end

#serviceString

The parent service or product from which the resource is provided, for example, GKE or SNS. Corresponds to the JSON property service

Returns:

  • (String)


3732
3733
3734
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3732

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


3737
3738
3739
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3737

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3744

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end