Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
-
#display_name ⇒ String
The human readable name of the resource.
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::Folder>
Output only.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding applies to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The parent service or product from which the resource is provided, for example, GKE or SNS.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
Returns a new instance of GoogleCloudSecuritycenterV1Resource.
3555 3556 3557 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
3457 3458 3459 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3457 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
3463 3464 3465 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3463 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
3469 3470 3471 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3469 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
Corresponds to the JSON property cloudProvider
3474 3475 3476 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3474 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
3479 3480 3481 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3479 def display_name @display_name end |
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta2::Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
3486 3487 3488 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3486 def folders @folders end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
3491 3492 3493 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3491 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
3497 3498 3499 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3497 def name @name end |
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding
applies to.
Corresponds to the JSON property organization
3503 3504 3505 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3503 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
3508 3509 3510 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3508 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
3513 3514 3515 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3513 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
3518 3519 3520 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3518 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
3523 3524 3525 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3523 def project_display_name @project_display_name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
3529 3530 3531 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3529 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
3542 3543 3544 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3542 def resource_path_string @resource_path_string end |
#service ⇒ String
The parent service or product from which the resource is provided, for example,
GKE or SNS.
Corresponds to the JSON property service
3548 3549 3550 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3548 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
3553 3554 3555 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3553 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3560 def update!(**args) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @folders = args[:folders] if args.key?(:folders) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |