Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.



3823
3824
3825
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



3801
3802
3803
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3801

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



3806
3807
3808
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3806

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



3811
3812
3813
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3811

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



3816
3817
3818
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3816

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



3821
3822
3823
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3821

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3828
3829
3830
3831
3832
3833
3834
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 3828

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end