Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an instance of a Security Health Analytics custom module, including its full module name, display name, enablement state, and last updated time. You can create a custom module at the organization, folder, or project level. Custom modules that you create at the organization or folder level are inherited by the child folders and projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule

Returns a new instance of GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule.



4213
4214
4215
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ancestor_moduleString

Output only. If empty, indicates that the custom module was created in the organization, folder, or project in which you are viewing the custom module. Otherwise, ancestor_module specifies the organization or folder from which the custom module is inherited. Corresponds to the JSON property ancestorModule

Returns:

  • (String)


4164
4165
4166
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4164

def ancestor_module
  @ancestor_module
end

#cloud_providerString

The cloud provider of the custom module. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


4169
4170
4171
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4169

def cloud_provider
  @cloud_provider
end

#custom_configGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1CustomConfig

Defines the properties in a custom module configuration for Security Health Analytics. Use the custom module configuration to create custom detectors that generate custom findings for resources that you specify. Corresponds to the JSON property customConfig



4176
4177
4178
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4176

def custom_config
  @custom_config
end

#display_nameString

The display name of the Security Health Analytics custom module. This display name becomes the finding category for all findings that are returned by this custom module. The display name must be between 1 and 128 characters, start with a lowercase letter, and contain alphanumeric characters or underscores only. Corresponds to the JSON property displayName

Returns:

  • (String)


4185
4186
4187
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4185

def display_name
  @display_name
end

#enablement_stateString

The enablement state of the custom module. Corresponds to the JSON property enablementState

Returns:

  • (String)


4190
4191
4192
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4190

def enablement_state
  @enablement_state
end

#last_editorString

Output only. The editor that last updated the custom module. Corresponds to the JSON property lastEditor

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4195

def last_editor
  @last_editor
end

#nameString

Immutable. The resource name of the custom module. Its format is " organizations/organization/securityHealthAnalyticsSettings/customModules/ customModule", or "folders/folder/securityHealthAnalyticsSettings/ customModules/customModule", or "projects/project/ securityHealthAnalyticsSettings/customModules/customModule" The id customModule is server-generated and is not user settable. It will be a numeric id containing 1-20 digits. Corresponds to the JSON property name

Returns:

  • (String)


4206
4207
4208
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4206

def name
  @name
end

#update_timeString

Output only. The time at which the custom module was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4211
4212
4213
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4211

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4218
4219
4220
4221
4222
4223
4224
4225
4226
4227
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4218

def update!(**args)
  @ancestor_module = args[:ancestor_module] if args.key?(:ancestor_module)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @custom_config = args[:custom_config] if args.key?(:custom_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enablement_state = args[:enablement_state] if args.key?(:enablement_state)
  @last_editor = args[:last_editor] if args.key?(:last_editor)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end