Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Security Command Center finding. A finding is a record of assessment data ( security, risk, health or privacy) ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, an XSS vulnerability in an App Engine application is a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Finding

Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Finding.



4259
4260
4261
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_nameString

The canonical name of the finding. It's either "organizations/organization_id /sources/source_id/findings/finding_id", "folders/folder_id/sources/ source_id/findings/finding_id" or "projects/project_number/sources/ source_id/findings/finding_id", depending on the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON property canonicalName

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4178

def canonical_name
  @canonical_name
end

#categoryString

The additional taxonomy group within findings from a given source. This field is immutable after creation time. Example: "XSS_FLASH_INJECTION" Corresponds to the JSON property category

Returns:

  • (String)


4184
4185
4186
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4184

def category
  @category
end

#create_timeString

The time at which the finding was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


4189
4190
4191
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4189

def create_time
  @create_time
end

#event_timeString

The time at which the event took place, or when an update to the finding occurred. For example, if the finding represents an open firewall it would capture the time the detector believes the firewall became open. The accuracy is determined by the detector. If the finding were to be resolved afterward, this time would reflect when the finding was resolved. Must not be set to a value greater than the current timestamp. Corresponds to the JSON property eventTime

Returns:

  • (String)


4199
4200
4201
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4199

def event_time
  @event_time
end

#external_uriString

The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found. This field is guaranteed to be either empty or a well formed URL. Corresponds to the JSON property externalUri

Returns:

  • (String)


4206
4207
4208
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4206

def external_uri
  @external_uri
end

#nameString

The relative resource name of this finding. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/sources/source_id/findings/finding_id" Corresponds to the JSON property name

Returns:

  • (String)


4213
4214
4215
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4213

def name
  @name
end

#parentString

The relative resource name of the source the finding belongs to. See: https:// cloud.google.com/apis/design/resource_names#relative_resource_name This field is immutable after creation time. For example: "organizations/organization_id /sources/source_id" Corresponds to the JSON property parent

Returns:

  • (String)


4221
4222
4223
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4221

def parent
  @parent
end

#resource_nameString

For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for. See: https://cloud.google.com/apis/design/ resource_names#full_resource_name When the finding is for a non-Google Cloud resource, the resourceName can be a customer or partner defined string. This field is immutable after creation time. Corresponds to the JSON property resourceName

Returns:

  • (String)


4230
4231
4232
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4230

def resource_name
  @resource_name
end

#security_marksGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



4238
4239
4240
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4238

def security_marks
  @security_marks
end

#severityString

The severity of the finding. This field is managed by the source that writes the finding. Corresponds to the JSON property severity

Returns:

  • (String)


4244
4245
4246
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4244

def severity
  @severity
end

#source_propertiesHash<String,Object>

Source specific properties. These properties are managed by the source that writes the finding. The key names in the source_properties map must be between 1 and 255 characters, and must start with a letter and contain alphanumeric characters or underscores only. Corresponds to the JSON property sourceProperties

Returns:



4252
4253
4254
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4252

def source_properties
  @source_properties
end

#stateString

The state of the finding. Corresponds to the JSON property state

Returns:

  • (String)


4257
4258
4259
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4257

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4264

def update!(**args)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @category = args[:category] if args.key?(:category)
  @create_time = args[:create_time] if args.key?(:create_time)
  @event_time = args[:event_time] if args.key?(:event_time)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @severity = args[:severity] if args.key?(:severity)
  @source_properties = args[:source_properties] if args.key?(:source_properties)
  @state = args[:state] if args.key?(:state)
end