Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource

Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Resource.



4190
4191
4192
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV1p1beta1Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



4162
4163
4164
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4162

def folders
  @folders
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


4168
4169
4170
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4168

def name
  @name
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4173

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4178

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4183

def project
  @project
end

#project_display_nameString

The project id that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4188

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4195
4196
4197
4198
4199
4200
4201
4202
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4195

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end