Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Access

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an access event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Access

Returns a new instance of GoogleCloudSecuritycenterV2Access.



4548
4549
4550
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#caller_ipString

Caller's IP address, such as "1.1.1.1". Corresponds to the JSON property callerIp

Returns:

  • (String)


4471
4472
4473
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4471

def caller_ip
  @caller_ip
end

#caller_ip_geoGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Geolocation

Represents a geographical location for a given access. Corresponds to the JSON property callerIpGeo



4476
4477
4478
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4476

def caller_ip_geo
  @caller_ip_geo
end

#method_nameString

The method that the service account called, e.g. "SetIamPolicy". Corresponds to the JSON property methodName

Returns:

  • (String)


4481
4482
4483
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4481

def method_name
  @method_name
end

#principal_emailString

Associated email, such as "foo@google.com". The email address of the authenticated user or a service account acting on behalf of a third party principal making the request. For third party identity callers, the principal_subject field is populated instead of this field. For privacy reasons, the principal email address is sometimes redacted. For more information, see Caller identities in audit logs. Corresponds to the JSON property principalEmail

Returns:

  • (String)


4492
4493
4494
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4492

def principal_email
  @principal_email
end

#principal_subjectString

A string that represents the principal_subject that is associated with the identity. Unlike principal_email, principal_subject supports principals that aren't associated with email addresses, such as third party principals. For most identities, the format is principal://iam.googleapis.com/identity pool name/subject/subject`. Some GKE identities, such as GKE_WORKLOAD, FREEFORM, and GKE_HUB_WORKLOAD, still use the legacy formatserviceAccount: identity pool name[subject]. Corresponds to the JSON propertyprincipalSubject`

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4503

def principal_subject
  @principal_subject
end

#service_account_delegation_infoArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ServiceAccountDelegationInfo>

The identity delegation history of an authenticated service account that made the request. The serviceAccountDelegationInfo[] object contains information about the real authorities that try to access Google Cloud resources by delegating on a service account. When multiple authorities are present, they are guaranteed to be sorted based on the original ordering of the identity delegation events. Corresponds to the JSON property serviceAccountDelegationInfo



4513
4514
4515
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4513

def 
  @service_account_delegation_info
end

#service_account_key_nameString

The name of the service account key that was used to create or exchange credentials when authenticating the service account that made the request. This is a scheme-less URI full resource name. For example: "//iam.googleapis. com/projects/PROJECT_ID/serviceAccounts/ACCOUNT/keys/key". Corresponds to the JSON property serviceAccountKeyName

Returns:

  • (String)


4521
4522
4523
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4521

def 
  @service_account_key_name
end

#service_nameString

This is the API service that the service account made a call to, e.g. "iam. googleapis.com" Corresponds to the JSON property serviceName

Returns:

  • (String)


4527
4528
4529
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4527

def service_name
  @service_name
end

#user_agentString

The caller's user agent string associated with the finding. Corresponds to the JSON property userAgent

Returns:

  • (String)


4532
4533
4534
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4532

def user_agent
  @user_agent
end

#user_agent_familyString

Type of user agent associated with the finding. For example, an operating system shell or an embedded or standalone application. Corresponds to the JSON property userAgentFamily

Returns:

  • (String)


4538
4539
4540
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4538

def user_agent_family
  @user_agent_family
end

#user_nameString

A string that represents a username. The username provided depends on the type of the finding and is likely not an IAM principal. For example, this can be a system username if the finding is related to a virtual machine, or it can be an application login username. Corresponds to the JSON property userName

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4546

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4553
4554
4555
4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4553

def update!(**args)
  @caller_ip = args[:caller_ip] if args.key?(:caller_ip)
  @caller_ip_geo = args[:caller_ip_geo] if args.key?(:caller_ip_geo)
  @method_name = args[:method_name] if args.key?(:method_name)
  @principal_email = args[:principal_email] if args.key?(:principal_email)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
  @service_account_delegation_info = args[:service_account_delegation_info] if args.key?(:service_account_delegation_info)
  @service_account_key_name = args[:service_account_key_name] if args.key?(:service_account_key_name)
  @service_name = args[:service_name] if args.key?(:service_name)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_agent_family = args[:user_agent_family] if args.key?(:user_agent_family)
  @user_name = args[:user_name] if args.key?(:user_name)
end