Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



4731
4732
4733
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


4697
4698
4699
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4697

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


4702
4703
4704
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4702

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


4708
4709
4710
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4708

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


4713
4714
4715
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4713

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4718

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


4724
4725
4726
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4724

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


4729
4730
4731
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4729

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4736
4737
4738
4739
4740
4741
4742
4743
4744
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4736

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end