Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



4612
4613
4614
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


4578
4579
4580
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4578

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


4583
4584
4585
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4583

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


4589
4590
4591
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4589

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


4594
4595
4596
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4594

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4599

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4605

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


4610
4611
4612
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4610

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4617
4618
4619
4620
4621
4622
4623
4624
4625
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4617

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end