Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



4425
4426
4427
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


4391
4392
4393
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4391

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


4396
4397
4398
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4396

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


4402
4403
4404
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4402

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


4407
4408
4409
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4407

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


4412
4413
4414
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4412

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


4418
4419
4420
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4418

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


4423
4424
4425
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4423

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4430
4431
4432
4433
4434
4435
4436
4437
4438
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4430

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end