Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AgentDataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about a data access attempt made by an agent principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AgentDataAccessEvent

Returns a new instance of GoogleCloudSecuritycenterV2AgentDataAccessEvent.



4884
4885
4886
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


4867
4868
4869
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4867

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


4872
4873
4874
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4872

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


4877
4878
4879
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4877

def operation
  @operation
end

#principal_subjectString

The agent principal that accessed the data. Corresponds to the JSON property principalSubject

Returns:

  • (String)


4882
4883
4884
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4882

def principal_subject
  @principal_subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4889
4890
4891
4892
4893
4894
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4889

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
end