Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel

Returns a new instance of GoogleCloudSecuritycenterV2AiModel.



4941
4942
4943
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


4904
4905
4906
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4904

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


4909
4910
4911
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4909

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


4914
4915
4916
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4914

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


4919
4920
4921
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4919

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


4924
4925
4926
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4924

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


4929
4930
4931
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4929

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


4934
4935
4936
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4934

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


4939
4940
4941
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4939

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4946

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end