Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel

Returns a new instance of GoogleCloudSecuritycenterV2AiModel.



4784
4785
4786
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


4747
4748
4749
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4747

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


4752
4753
4754
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4752

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4757

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


4762
4763
4764
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4762

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


4767
4768
4769
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4767

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


4772
4773
4774
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4772

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


4777
4778
4779
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4777

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


4782
4783
4784
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4782

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4789

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end