Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Contains information about the AI model associated with the finding.
Instance Attribute Summary collapse
-
#deployment_platform ⇒ String
The platform on which the model is deployed.
-
#display_name ⇒ String
The user defined display name of model.
-
#domain ⇒ String
The domain of the model, for example, “image-classification”.
-
#library ⇒ String
The name of the model library, for example, “transformers”.
-
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
-
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
-
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
-
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
constructor
A new instance of GoogleCloudSecuritycenterV2AiModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
Returns a new instance of GoogleCloudSecuritycenterV2AiModel.
4529 4530 4531 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_platform ⇒ String
The platform on which the model is deployed.
Corresponds to the JSON property deploymentPlatform
4492 4493 4494 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4492 def deployment_platform @deployment_platform end |
#display_name ⇒ String
The user defined display name of model. Ex. baseline-classification-model
Corresponds to the JSON property displayName
4497 4498 4499 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4497 def display_name @display_name end |
#domain ⇒ String
The domain of the model, for example, “image-classification”.
Corresponds to the JSON property domain
4502 4503 4504 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4502 def domain @domain end |
#library ⇒ String
The name of the model library, for example, “transformers”.
Corresponds to the JSON property library
4507 4508 4509 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4507 def library @library end |
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
Corresponds to the JSON property location
4512 4513 4514 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4512 def location @location end |
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
Corresponds to the JSON property name
4517 4518 4519 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4517 def name @name end |
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
Corresponds to the JSON property publisher
4522 4523 4524 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4522 def publisher @publisher end |
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Corresponds to the JSON property usageCategory
4527 4528 4529 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4527 def usage_category @usage_category end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4534 def update!(**args) @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) @library = args[:library] if args.key?(:library) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @publisher = args[:publisher] if args.key?(:publisher) @usage_category = args[:usage_category] if args.key?(:usage_category) end |