Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
An attack exposure contains the results of an attack path simulation run.
Instance Attribute Summary collapse
-
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the details regarding this attack exposure score.
-
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this finding.
-
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this finding.
-
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
-
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this finding is to remediate.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure
constructor
A new instance of GoogleCloudSecuritycenterV2AttackExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure
Returns a new instance of GoogleCloudSecuritycenterV2AttackExposure.
4742 4743 4744 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_exposure_result ⇒ String
The resource name of the attack path simulation result that contains the
details regarding this attack exposure score. Example: organizations/123/
simulations/456/attackExposureResults/789
Corresponds to the JSON property attackExposureResult
4704 4705 4706 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4704 def attack_exposure_result @attack_exposure_result end |
#exposed_high_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedHighValueResourcesCount
4710 4711 4712 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4710 def exposed_high_value_resources_count @exposed_high_value_resources_count end |
#exposed_low_value_resources_count ⇒ Fixnum
The number of high value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedLowValueResourcesCount
4716 4717 4718 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4716 def exposed_low_value_resources_count @exposed_low_value_resources_count end |
#exposed_medium_value_resources_count ⇒ Fixnum
The number of medium value resources that are exposed as a result of this
finding.
Corresponds to the JSON property exposedMediumValueResourcesCount
4722 4723 4724 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4722 def exposed_medium_value_resources_count @exposed_medium_value_resources_count end |
#latest_calculation_time ⇒ String
The most recent time the attack exposure was updated on this finding.
Corresponds to the JSON property latestCalculationTime
4727 4728 4729 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4727 def latest_calculation_time @latest_calculation_time end |
#score ⇒ Float
A number between 0 (inclusive) and infinity that represents how important this
finding is to remediate. The higher the score, the more important it is to
remediate.
Corresponds to the JSON property score
4734 4735 4736 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4734 def score @score end |
#state ⇒ String
Output only. What state this AttackExposure is in. This captures whether or
not an attack exposure has been calculated or not.
Corresponds to the JSON property state
4740 4741 4742 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4740 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4747 4748 4749 4750 4751 4752 4753 4754 4755 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4747 def update!(**args) @attack_exposure_result = args[:attack_exposure_result] if args.key?(:attack_exposure_result) @exposed_high_value_resources_count = args[:exposed_high_value_resources_count] if args.key?(:exposed_high_value_resources_count) @exposed_low_value_resources_count = args[:exposed_low_value_resources_count] if args.key?(:exposed_low_value_resources_count) @exposed_medium_value_resources_count = args[:exposed_medium_value_resources_count] if args.key?(:exposed_medium_value_resources_count) @latest_calculation_time = args[:latest_calculation_time] if args.key?(:latest_calculation_time) @score = args[:score] if args.key?(:score) @state = args[:state] if args.key?(:state) end |