Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsOrganization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AwsOrganization

Returns a new instance of GoogleCloudSecuritycenterV2AwsOrganization.



5243
5244
5245
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier (ID) for the organization. The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits. Corresponds to the JSON property id

Returns:

  • (String)


5241
5242
5243
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5241

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5248
5249
5250
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5248

def update!(**args)
  @id = args[:id] if args.key?(:id)
end