Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
Instance Attribute Summary collapse
-
#management_groups ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureManagementGroup>
A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level.
-
#resource_group ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureResourceGroup
Represents an Azure resource group.
-
#subscription ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureSubscription
Represents an Azure subscription.
-
#tenant ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureTenant
Represents a Microsoft Entra tenant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata
constructor
A new instance of GoogleCloudSecuritycenterV2AzureMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata
Returns a new instance of GoogleCloudSecuritycenterV2AzureMetadata.
4924 4925 4926 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#management_groups ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureManagementGroup>
A list of Azure management groups associated with the resource, ordered from
lowest level (closest to the subscription) to highest level.
Corresponds to the JSON property managementGroups
4907 4908 4909 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4907 def management_groups @management_groups end |
#resource_group ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureResourceGroup
Represents an Azure resource group.
Corresponds to the JSON property resourceGroup
4912 4913 4914 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4912 def resource_group @resource_group end |
#subscription ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureSubscription
Represents an Azure subscription.
Corresponds to the JSON property subscription
4917 4918 4919 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4917 def subscription @subscription end |
#tenant ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureTenant
Represents a Microsoft Entra tenant.
Corresponds to the JSON property tenant
4922 4923 4924 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4922 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4929 4930 4931 4932 4933 4934 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 4929 def update!(**args) @management_groups = args[:management_groups] if args.key?(:management_groups) @resource_group = args[:resource_group] if args.key?(:resource_group) @subscription = args[:subscription] if args.key?(:subscription) @tenant = args[:tenant] if args.key?(:tenant) end |