Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
The data profile associated with the finding.
Instance Attribute Summary collapse
-
#data_profile ⇒ String
Name of the data profile, for example,
projects/123/locations/europe/ tableProfiles/8383929. -
#info_types ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2InfoType>
Type of information detected by SDP.
-
#parent_type ⇒ String
The resource hierarchy level at which the data profile was generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile
constructor
A new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile
Returns a new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.
5392 5393 5394 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile ⇒ String
Name of the data profile, for example, projects/123/locations/europe/
tableProfiles/8383929.
Corresponds to the JSON property dataProfile
5379 5380 5381 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5379 def data_profile @data_profile end |
#info_types ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2InfoType>
Type of information detected by SDP. Info type includes name, version and
sensitivity of the detected information type.
Corresponds to the JSON property infoTypes
5385 5386 5387 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5385 def info_types @info_types end |
#parent_type ⇒ String
The resource hierarchy level at which the data profile was generated.
Corresponds to the JSON property parentType
5390 5391 5392 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5390 def parent_type @parent_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5397 5398 5399 5400 5401 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5397 def update!(**args) @data_profile = args[:data_profile] if args.key?(:data_profile) @info_types = args[:info_types] if args.key?(:info_types) @parent_type = args[:parent_type] if args.key?(:parent_type) end |