Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Metadata taken from a Cloud Logging LogEntry
Instance Attribute Summary collapse
-
#insert_id ⇒ String
A unique identifier for the log entry.
-
#log_id ⇒ String
The type of the log (part of
log_name.log_nameis the resource name of the log to which this log entry belongs). -
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced this log entry.
-
#timestamp ⇒ String
The time the event described by the log entry occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
constructor
A new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
Returns a new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
5730 5731 5732 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insert_id ⇒ String
A unique identifier for the log entry.
Corresponds to the JSON property insertId
5709 5710 5711 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5709 def insert_id @insert_id end |
#log_id ⇒ String
The type of the log (part of log_name. log_name is the resource name of
the log to which this log entry belongs). For example: cloudresourcemanager.
googleapis.com/activity Note that this field is not URL-encoded, unlike in
LogEntry.
Corresponds to the JSON property logId
5717 5718 5719 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5717 def log_id @log_id end |
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced
this log entry.
Corresponds to the JSON property resourceContainer
5723 5724 5725 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5723 def resource_container @resource_container end |
#timestamp ⇒ String
The time the event described by the log entry occurred.
Corresponds to the JSON property timestamp
5728 5729 5730 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5728 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5735 5736 5737 5738 5739 5740 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5735 def update!(**args) @insert_id = args[:insert_id] if args.key?(:insert_id) @log_id = args[:log_id] if args.key?(:log_id) @resource_container = args[:resource_container] if args.key?(:resource_container) @timestamp = args[:timestamp] if args.key?(:timestamp) end |