Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Compliance

Returns a new instance of GoogleCloudSecuritycenterV2Compliance.



5920
5921
5922
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property ids

Returns:

  • (Array<String>)


5908
5909
5910
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5908

def ids
  @ids
end

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


5913
5914
5915
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5913

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


5918
5919
5920
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5918

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5925
5926
5927
5928
5929
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5925

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end