Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Connection

Returns a new instance of GoogleCloudSecuritycenterV2Connection.



5838
5839
5840
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


5816
5817
5818
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5816

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


5821
5822
5823
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5821

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


5826
5827
5828
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5826

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


5831
5832
5833
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5831

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


5836
5837
5838
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5836

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5843
5844
5845
5846
5847
5848
5849
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5843

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end