Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Connection

Returns a new instance of GoogleCloudSecuritycenterV2Connection.



5583
5584
5585
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


5561
5562
5563
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5561

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


5566
5567
5568
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5566

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


5571
5572
5573
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5571

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


5576
5577
5578
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5576

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


5581
5582
5583
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5581

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5588
5589
5590
5591
5592
5593
5594
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5588

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end