Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Container

Returns a new instance of GoogleCloudSecuritycenterV2Container.



5666
5667
5668
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5642
5643
5644
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5642

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


5648
5649
5650
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5648

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



5653
5654
5655
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5653

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


5658
5659
5660
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5658

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


5664
5665
5666
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5664

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5671
5672
5673
5674
5675
5676
5677
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5671

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end