Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Cvssv3

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Common Vulnerability Scoring System version 3.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Cvssv3

Returns a new instance of GoogleCloudSecuritycenterV2Cvssv3.



5843
5844
5845
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

This metric describes the conditions beyond the attacker's control that must exist in order to exploit the vulnerability. Corresponds to the JSON property attackComplexity

Returns:

  • (String)


5792
5793
5794
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5792

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. This metric reflects the context by which vulnerability exploitation is possible. Corresponds to the JSON property attackVector

Returns:

  • (String)


5799
5800
5801
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5799

def attack_vector
  @attack_vector
end

#availability_impactString

This metric measures the impact to the availability of the impacted component resulting from a successfully exploited vulnerability. Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


5805
5806
5807
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5805

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


5810
5811
5812
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5810

def base_score
  @base_score
end

#confidentiality_impactString

This metric measures the impact to the confidentiality of the information resources managed by a software component due to a successfully exploited vulnerability. Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


5817
5818
5819
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5817

def confidentiality_impact
  @confidentiality_impact
end

#integrity_impactString

This metric measures the impact to integrity of a successfully exploited vulnerability. Corresponds to the JSON property integrityImpact

Returns:

  • (String)


5823
5824
5825
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5823

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

This metric describes the level of privileges an attacker must possess before successfully exploiting the vulnerability. Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


5829
5830
5831
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5829

def privileges_required
  @privileges_required
end

#scopeString

The Scope metric captures whether a vulnerability in one vulnerable component impacts resources in components beyond its security scope. Corresponds to the JSON property scope

Returns:

  • (String)


5835
5836
5837
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5835

def scope
  @scope
end

#user_interactionString

This metric captures the requirement for a human user, other than the attacker, to participate in the successful compromise of the vulnerable component. Corresponds to the JSON property userInteraction

Returns:

  • (String)


5841
5842
5843
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5841

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5848
5849
5850
5851
5852
5853
5854
5855
5856
5857
5858
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5848

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end