Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about a data access attempt made by a principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataAccessEvent

Returns a new instance of GoogleCloudSecuritycenterV2DataAccessEvent.



5914
5915
5916
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5896

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5901

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


5906
5907
5908
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5906

def operation
  @operation
end

#principal_emailString

The email address of the principal that accessed the data. The principal could be a user account, service account, Google group, or other. Corresponds to the JSON property principalEmail

Returns:

  • (String)


5912
5913
5914
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5912

def principal_email
  @principal_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5919
5920
5921
5922
5923
5924
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 5919

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_email = args[:principal_email] if args.key?(:principal_email)
end