Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Database

Returns a new instance of GoogleCloudSecuritycenterV2Database.



6329
6330
6331
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The human-readable name of the database that the user connected to. Corresponds to the JSON property displayName

Returns:

  • (String)


6294
6295
6296
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6294

def display_name
  @display_name
end

#granteesArray<String>

The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change. Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


6300
6301
6302
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6300

def grantees
  @grantees
end

#nameString

Some database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In these cases only the display name will be provided. The full resource name of the database that the user connected to, if it is supported by Cloud Asset Inventory. Corresponds to the JSON property name

Returns:

  • (String)


6310
6311
6312
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6310

def name
  @name
end

#queryString

The SQL statement that is associated with the database access. Corresponds to the JSON property query

Returns:

  • (String)


6315
6316
6317
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6315

def query
  @query
end

#user_nameString

The username used to connect to the database. The username might not be an IAM principal and does not have a set format. Corresponds to the JSON property userName

Returns:

  • (String)


6321
6322
6323
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6321

def user_name
  @user_name
end

#versionString

The version of the database, for example, POSTGRES_14. See the complete list. Corresponds to the JSON property version

Returns:

  • (String)


6327
6328
6329
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6327

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6334
6335
6336
6337
6338
6339
6340
6341
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6334

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @grantees = args[:grantees] if args.key?(:grantees)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
  @user_name = args[:user_name] if args.key?(:user_name)
  @version = args[:version] if args.key?(:version)
end