Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DiscoveredWorkload
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DiscoveredWorkload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents discovered, customer managed workload that is not registered with the respective GCP service.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The confidence in detection of this workload.
-
#detected_relevant_hardware ⇒ Boolean
(also: #detected_relevant_hardware?)
A boolean flag set to true if associated hardware strongly predicts the workload type.
-
#detected_relevant_keywords ⇒ Boolean
(also: #detected_relevant_keywords?)
A boolean flag set to true if associated keywords strongly predict the workload type.
-
#detected_relevant_packages ⇒ Boolean
(also: #detected_relevant_packages?)
A boolean flag set to true if installed packages strongly predict the workload type.
-
#workload_type ⇒ String
The type of workload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DiscoveredWorkload
constructor
A new instance of GoogleCloudSecuritycenterV2DiscoveredWorkload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DiscoveredWorkload
Returns a new instance of GoogleCloudSecuritycenterV2DiscoveredWorkload.
6621 6622 6623 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The confidence in detection of this workload.
Corresponds to the JSON property confidence
6593 6594 6595 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6593 def confidence @confidence end |
#detected_relevant_hardware ⇒ Boolean Also known as: detected_relevant_hardware?
A boolean flag set to true if associated hardware strongly predicts the
workload type.
Corresponds to the JSON property detectedRelevantHardware
6599 6600 6601 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6599 def detected_relevant_hardware @detected_relevant_hardware end |
#detected_relevant_keywords ⇒ Boolean Also known as: detected_relevant_keywords?
A boolean flag set to true if associated keywords strongly predict the
workload type.
Corresponds to the JSON property detectedRelevantKeywords
6606 6607 6608 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6606 def detected_relevant_keywords @detected_relevant_keywords end |
#detected_relevant_packages ⇒ Boolean Also known as: detected_relevant_packages?
A boolean flag set to true if installed packages strongly predict the workload
type.
Corresponds to the JSON property detectedRelevantPackages
6613 6614 6615 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6613 def detected_relevant_packages @detected_relevant_packages end |
#workload_type ⇒ String
The type of workload.
Corresponds to the JSON property workloadType
6619 6620 6621 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6619 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6626 6627 6628 6629 6630 6631 6632 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6626 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @detected_relevant_hardware = args[:detected_relevant_hardware] if args.key?(:detected_relevant_hardware) @detected_relevant_keywords = args[:detected_relevant_keywords] if args.key?(:detected_relevant_keywords) @detected_relevant_packages = args[:detected_relevant_packages] if args.key?(:detected_relevant_packages) @workload_type = args[:workload_type] if args.key?(:workload_type) end |