Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ExternalExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Details about the externally exposed resource associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalExposure

Returns a new instance of GoogleCloudSecuritycenterV2ExternalExposure.



6661
6662
6663
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceString

The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/project-id/global/backendServices/name". Corresponds to the JSON property backendService

Returns:

  • (String)


6595
6596
6597
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6595

def backend_service
  @backend_service
end

#exposed_endpointString

The resource which is running the exposed service, for example, "//compute. googleapis.com/projects/project-id/zones/zone/instances/instance.” Corresponds to the JSON property exposedEndpoint

Returns:

  • (String)


6601
6602
6603
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6601

def exposed_endpoint
  @exposed_endpoint
end

#exposed_serviceString

The name and version of the service, for example, "Jupyter Notebook 6.14.0". Corresponds to the JSON property exposedService

Returns:

  • (String)


6606
6607
6608
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6606

def exposed_service
  @exposed_service
end

#forwarding_ruleString

The full resource name of the forwarding rule, for example, "//compute. googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule- name". Corresponds to the JSON property forwardingRule

Returns:

  • (String)


6613
6614
6615
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6613

def forwarding_rule
  @forwarding_rule
end

#instance_groupString

The full resource name of the instance group, for example, "//compute. googleapis.com/projects/project-id/global/instanceGroups/name". Corresponds to the JSON property instanceGroup

Returns:

  • (String)


6619
6620
6621
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6619

def instance_group
  @instance_group
end

#load_balancer_firewall_policyString

The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/policy- name". Corresponds to the JSON property loadBalancerFirewallPolicy

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6626

def load_balancer_firewall_policy
  @load_balancer_firewall_policy
end

#network_endpoint_groupString

The full resource name of the network endpoint group, for example, "//compute. googleapis.com/projects/project-id/global/networkEndpointGroups/name". Corresponds to the JSON property networkEndpointGroup

Returns:

  • (String)


6632
6633
6634
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6632

def network_endpoint_group
  @network_endpoint_group
end

#private_ip_addressString

Private IP address of the exposed endpoint. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


6637
6638
6639
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6637

def private_ip_address
  @private_ip_address
end

#private_portString

Port number associated with private IP address. Corresponds to the JSON property privatePort

Returns:

  • (String)


6642
6643
6644
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6642

def private_port
  @private_port
end

#public_ip_addressString

Public IP address of the exposed endpoint. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


6647
6648
6649
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6647

def public_ip_address
  @public_ip_address
end

#public_portString

Public port number of the exposed endpoint. Corresponds to the JSON property publicPort

Returns:

  • (String)


6652
6653
6654
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6652

def public_port
  @public_port
end

#service_firewall_policyString

The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/project-id/global/ firewallPolicies/policy-name". Corresponds to the JSON property serviceFirewallPolicy

Returns:

  • (String)


6659
6660
6661
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6659

def service_firewall_policy
  @service_firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6666

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint)
  @exposed_service = args[:exposed_service] if args.key?(:exposed_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy)
  @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @private_port = args[:private_port] if args.key?(:private_port)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @public_port = args[:public_port] if args.key?(:public_port)
  @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy)
end