Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV2ExternalSystem.



6965
6966
6967
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


6903
6904
6905
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6903

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


6908
6909
6910
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6908

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


6913
6914
6915
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6913

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


6918
6919
6920
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6918

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


6923
6924
6925
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6923

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


6928
6929
6930
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6928

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


6933
6934
6935
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6933

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


6939
6940
6941
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6939

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system. The following list shows some examples: + organizations/1234/sources/5678/findings/123456/externalSystems/ jira + organizations/1234/sources/5678/locations/us/findings/123456/ externalSystems/jira + folders/1234/sources/5678/findings/123456/ externalSystems/jira + folders/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira + projects/1234/sources/5678/findings/123456/ externalSystems/jira + projects/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira Corresponds to the JSON property name

Returns:

  • (String)


6951
6952
6953
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6951

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


6957
6958
6959
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6957

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



6963
6964
6965
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6963

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6970

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end