Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2File

Returns a new instance of GoogleCloudSecuritycenterV2File.



6474
6475
6476
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


6429
6430
6431
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6429

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



6434
6435
6436
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6434

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


6439
6440
6441
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6439

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


6445
6446
6447
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6445

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



6450
6451
6452
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6450

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


6455
6456
6457
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6455

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


6461
6462
6463
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6461

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


6467
6468
6469
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6467

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


6472
6473
6474
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6472

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6479

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end