Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Finding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.
Instance Attribute Summary collapse
-
#access ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Access
Represents an access event.
-
#affected_resources ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AffectedResources
Details about resources affected by this finding.
-
#ai_model ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel
Contains information about the AI model associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Application
Represents an application associated with a finding.
-
#artifact_guard_policies ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicies
Represents the result of evaluating artifact guard policies.
-
#attack_exposure ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
An attack exposure contains the results of an attack path simulation run.
-
#backup_disaster_recovery ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2BackupDisasterRecovery
Information related to Google Cloud Backup and DR Service findings.
-
#canonical_name ⇒ String
Output only.
-
#category ⇒ String
Immutable.
-
#chokepoint ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Chokepoint
Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.
-
#cloud_armor ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudArmor
Fields related to Google Cloud Armor findings.
-
#cloud_dlp_data_profile ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpDataProfile
The data profile associated with the finding.
-
#cloud_dlp_inspection ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpInspection
Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding.
-
#compliance_details ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ComplianceDetails
Compliance Details associated with the finding.
-
#compliances ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Compliance>
Contains compliance information for security standards associated to the finding.
-
#connections ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Connection>
Contains information about the IP connection associated with the finding.
-
#contacts ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ContactDetails>
Output only.
-
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>
Containers associated with the finding.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Output only.
-
#data_access_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataAccessEvent>
Data access events associated with the finding.
-
#data_flow_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataFlowEvent>
Data flow events associated with the finding.
-
#data_retention_deletion_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent>
Data retention deletion events associated with the finding.
-
#database ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Database
Represents database access information, such as queries.
-
#description ⇒ String
Contains more details about the finding.
-
#disk ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Disk
Contains information about the disk associated with the finding.
-
#event_time ⇒ String
The time the finding was first detected.
-
#exfiltration ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Exfiltration
Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets.
-
#external_systems ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ExternalSystem>
Output only.
-
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found.
-
#files ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>
File associated with the finding.
-
#finding_class ⇒ String
The class of the finding.
-
#group_memberships ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2GroupMembership>
Contains details about groups of which this finding is a member.
-
#iam_bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IamBinding>
Represents IAM bindings associated with the finding.
-
#indicator ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Indicator
Represents what's commonly known as an indicator of compromise (IoC) in computer forensics.
-
#ip_rules ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IpRules
IP rules associated with the finding.
-
#job ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job
Describes a job Corresponds to the JSON property
job. -
#kernel_rootkit ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2KernelRootkit
Kernel mode rootkit signatures.
-
#kubernetes ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
Kubernetes-related attributes.
-
#load_balancers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2LoadBalancer>
The load balancers associated with the finding.
-
#log_entries ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2LogEntry>
Log entries that are relevant to the finding.
-
#mitre_attack ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MitreAttack
MITRE ATT&CK tactics and techniques related to this finding.
-
#module_name ⇒ String
Unique identifier of the module which generated the finding.
-
#mute ⇒ String
Indicates the mute state of a finding (either muted, unmuted or undefined).
-
#mute_info ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteInfo
Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules.
-
#mute_initiator ⇒ String
Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding.
-
#mute_update_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#networks ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Network>
Represents the VPC networks that the resource is attached to.
-
#next_steps ⇒ String
Steps to address the finding.
-
#notebook ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Notebook
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
-
#org_policies ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2OrgPolicy>
Contains information about the org policies associated with the finding.
-
#parent ⇒ String
The relative resource name of the source and location the finding belongs to.
-
#parent_display_name ⇒ String
Output only.
-
#processes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process>
Represents operating system processes associated with the Finding.
-
#resource_name ⇒ String
Immutable.
-
#secret ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Secret
Details about a secret or credential associated with the finding.
-
#security_marks ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityMarks
User specified security marks that are attached to the parent Security Command Center resource.
-
#security_posture ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityPosture
Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service.
-
#severity ⇒ String
The severity of the finding.
-
#source_properties ⇒ Hash<String,Object>
Source specific properties.
-
#state ⇒ String
Output only.
-
#toxic_combination ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ToxicCombination
Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently.
-
#vertex_ai ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2VertexAi
Vertex AI-related information associated with the finding.
-
#vulnerability ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Vulnerability
Refers to common vulnerability fields e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Finding
constructor
A new instance of GoogleCloudSecuritycenterV2Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Finding
Returns a new instance of GoogleCloudSecuritycenterV2Finding.
6930 6931 6932 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Access
Represents an access event.
Corresponds to the JSON property access
6522 6523 6524 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6522 def access @access end |
#affected_resources ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AffectedResources
Details about resources affected by this finding.
Corresponds to the JSON property affectedResources
6527 6528 6529 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6527 def affected_resources @affected_resources end |
#ai_model ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AiModel
Contains information about the AI model associated with the finding.
Corresponds to the JSON property aiModel
6532 6533 6534 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6532 def ai_model @ai_model end |
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Application
Represents an application associated with a finding.
Corresponds to the JSON property application
6537 6538 6539 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6537 def application @application end |
#artifact_guard_policies ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ArtifactGuardPolicies
Represents the result of evaluating artifact guard policies.
Corresponds to the JSON property artifactGuardPolicies
6542 6543 6544 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6542 def artifact_guard_policies @artifact_guard_policies end |
#attack_exposure ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AttackExposure
An attack exposure contains the results of an attack path simulation run.
Corresponds to the JSON property attackExposure
6547 6548 6549 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6547 def attack_exposure @attack_exposure end |
#backup_disaster_recovery ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2BackupDisasterRecovery
Information related to Google Cloud Backup and DR Service findings.
Corresponds to the JSON property backupDisasterRecovery
6552 6553 6554 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6552 def backup_disaster_recovery @backup_disaster_recovery end |
#canonical_name ⇒ String
Output only. The canonical name of the finding. The following list shows some
examples: + organizations/organization_id/sources/source_id/locations/
location_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/
locations/`location_id`/findings/`finding_id + projects/project_id/
sources/source_id/locations/location_id/findings/finding_id`The prefix
is the closest CRM ancestor of the resource associated with the finding.
Corresponds to the JSON propertycanonicalName`
6562 6563 6564 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6562 def canonical_name @canonical_name end |
#category ⇒ String
Immutable. The additional taxonomy group within findings from a given source.
Example: "XSS_FLASH_INJECTION"
Corresponds to the JSON property category
6568 6569 6570 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6568 def category @category end |
#chokepoint ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Chokepoint
Contains details about a chokepoint, which is a resource or resource group
where high-risk attack paths converge, based on attack path simulations.
Corresponds to the JSON property chokepoint
6576 6577 6578 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6576 def chokepoint @chokepoint end |
#cloud_armor ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudArmor
Fields related to Google Cloud Armor findings.
Corresponds to the JSON property cloudArmor
6581 6582 6583 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6581 def cloud_armor @cloud_armor end |
#cloud_dlp_data_profile ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpDataProfile
The data profile associated
with the finding.
Corresponds to the JSON property cloudDlpDataProfile
6587 6588 6589 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6587 def cloud_dlp_data_profile @cloud_dlp_data_profile end |
#cloud_dlp_inspection ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2CloudDlpInspection
Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the
finding.
Corresponds to the JSON property cloudDlpInspection
6594 6595 6596 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6594 def cloud_dlp_inspection @cloud_dlp_inspection end |
#compliance_details ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ComplianceDetails
Compliance Details associated with the finding.
Corresponds to the JSON property complianceDetails
6599 6600 6601 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6599 def compliance_details @compliance_details end |
#compliances ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Compliance>
Contains compliance information for security standards associated to the
finding.
Corresponds to the JSON property compliances
6605 6606 6607 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6605 def compliances @compliances end |
#connections ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Connection>
Contains information about the IP connection associated with the finding.
Corresponds to the JSON property connections
6610 6611 6612 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6610 def connections @connections end |
#contacts ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ContactDetails>
Output only. Map containing the points of contact for the given finding. The
key represents the type of contact, while the value contains a list of all the
contacts that pertain. Please refer to: https://cloud.google.com/resource-
manager/docs/managing-notification-contacts#notification-categories "
security": "contacts": [ "email": "person1@company.com", "email": "
person2@company.com" ]
Corresponds to the JSON property contacts
6620 6621 6622 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6620 def contacts @contacts end |
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>
Containers associated with the finding. This field provides information for
both Kubernetes and non-Kubernetes containers.
Corresponds to the JSON property containers
6626 6627 6628 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6626 def containers @containers end |
#create_time ⇒ String
Output only. The time at which the finding was created in Security Command
Center.
Corresponds to the JSON property createTime
6632 6633 6634 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6632 def create_time @create_time end |
#crypto_key_name ⇒ String
Output only. The name of the Cloud KMS key used to encrypt this finding, if
any.
Corresponds to the JSON property cryptoKeyName
6638 6639 6640 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6638 def crypto_key_name @crypto_key_name end |
#data_access_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataAccessEvent>
Data access events associated with the finding.
Corresponds to the JSON property dataAccessEvents
6643 6644 6645 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6643 def data_access_events @data_access_events end |
#data_flow_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataFlowEvent>
Data flow events associated with the finding.
Corresponds to the JSON property dataFlowEvents
6648 6649 6650 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6648 def data_flow_events @data_flow_events end |
#data_retention_deletion_events ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent>
Data retention deletion events associated with the finding.
Corresponds to the JSON property dataRetentionDeletionEvents
6653 6654 6655 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6653 def data_retention_deletion_events @data_retention_deletion_events end |
#database ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Database
Represents database access information, such as queries. A database may be a
sub-resource of an instance (as in the case of Cloud SQL instances or Cloud
Spanner instances), or the database instance itself. Some database resources
might not have the full resource name populated because these resource types, such as Cloud SQL
databases, are not yet supported by Cloud Asset Inventory. In these cases only
the display name is provided.
Corresponds to the JSON property database
6664 6665 6666 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6664 def database @database end |
#description ⇒ String
Contains more details about the finding.
Corresponds to the JSON property description
6669 6670 6671 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6669 def description @description end |
#disk ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Disk
Contains information about the disk associated with the finding.
Corresponds to the JSON property disk
6674 6675 6676 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6674 def disk @disk end |
#event_time ⇒ String
The time the finding was first detected. If an existing finding is updated,
then this is the time the update occurred. For example, if the finding
represents an open firewall, this property captures the time the detector
believes the firewall became open. The accuracy is determined by the detector.
If the finding is later resolved, then this time reflects when the finding was
resolved. This must not be set to a value greater than the current timestamp.
Corresponds to the JSON property eventTime
6684 6685 6686 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6684 def event_time @event_time end |
#exfiltration ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Exfiltration
Exfiltration represents a data exfiltration attempt from one or more sources
to one or more targets. The sources attribute lists the sources of the
exfiltrated data. The targets attribute lists the destinations the data was
copied to.
Corresponds to the JSON property exfiltration
6692 6693 6694 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6692 def exfiltration @exfiltration end |
#external_systems ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ExternalSystem>
Output only. Third party SIEM/SOAR fields within SCC, contains external system
information and external system finding fields.
Corresponds to the JSON property externalSystems
6698 6699 6700 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6698 def external_systems @external_systems end |
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command
Center where additional information about the finding can be found. This field
is guaranteed to be either empty or a well formed URL.
Corresponds to the JSON property externalUri
6705 6706 6707 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6705 def external_uri @external_uri end |
#files ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>
File associated with the finding.
Corresponds to the JSON property files
6710 6711 6712 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6710 def files @files end |
#finding_class ⇒ String
The class of the finding.
Corresponds to the JSON property findingClass
6715 6716 6717 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6715 def finding_class @finding_class end |
#group_memberships ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2GroupMembership>
Contains details about groups of which this finding is a member. A group is a
collection of findings that are related in some way. This field cannot be
updated. Its value is ignored in all update requests.
Corresponds to the JSON property groupMemberships
6722 6723 6724 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6722 def group_memberships @group_memberships end |
#iam_bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IamBinding>
Represents IAM bindings associated with the finding.
Corresponds to the JSON property iamBindings
6727 6728 6729 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6727 def iam_bindings @iam_bindings end |
#indicator ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Indicator
Represents what's commonly known as an indicator of compromise (IoC) in
computer forensics. This is an artifact observed on a network or in an
operating system that, with high confidence, indicates a computer intrusion.
For more information, see Indicator of compromise.
Corresponds to the JSON property indicator
6736 6737 6738 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6736 def indicator @indicator end |
#ip_rules ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IpRules
IP rules associated with the finding.
Corresponds to the JSON property ipRules
6741 6742 6743 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6741 def ip_rules @ip_rules end |
#job ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job
Describes a job
Corresponds to the JSON property job
6746 6747 6748 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6746 def job @job end |
#kernel_rootkit ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2KernelRootkit
Kernel mode rootkit signatures.
Corresponds to the JSON property kernelRootkit
6751 6752 6753 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6751 def kernel_rootkit @kernel_rootkit end |
#kubernetes ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
Kubernetes-related attributes.
Corresponds to the JSON property kubernetes
6756 6757 6758 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6756 def kubernetes @kubernetes end |
#load_balancers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2LoadBalancer>
The load balancers associated with the finding.
Corresponds to the JSON property loadBalancers
6761 6762 6763 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6761 def load_balancers @load_balancers end |
#log_entries ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2LogEntry>
Log entries that are relevant to the finding.
Corresponds to the JSON property logEntries
6766 6767 6768 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6766 def log_entries @log_entries end |
#mitre_attack ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MitreAttack
MITRE ATT&CK tactics and techniques related to this finding. See: https://
attack.mitre.org
Corresponds to the JSON property mitreAttack
6772 6773 6774 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6772 def mitre_attack @mitre_attack end |
#module_name ⇒ String
Unique identifier of the module which generated the finding. Example: folders/
598186756061/securityHealthAnalyticsSettings/customModules/56799441161885
Corresponds to the JSON property moduleName
6778 6779 6780 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6778 def module_name @module_name end |
#mute ⇒ String
Indicates the mute state of a finding (either muted, unmuted or undefined).
Unlike other attributes of a finding, a finding provider shouldn't set the
value of mute.
Corresponds to the JSON property mute
6785 6786 6787 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6785 def mute @mute end |
#mute_info ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteInfo
Mute information about the finding, including whether the finding has a static
mute or any matching dynamic mute rules.
Corresponds to the JSON property muteInfo
6791 6792 6793 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6791 def mute_info @mute_info end |
#mute_initiator ⇒ String
Records additional information about the mute operation, for example, the
mute configuration that muted the finding and the user who muted the finding.
Corresponds to the JSON property muteInitiator
6798 6799 6800 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6798 def mute_initiator @mute_initiator end |
#mute_update_time ⇒ String
Output only. The most recent time this finding was muted or unmuted.
Corresponds to the JSON property muteUpdateTime
6803 6804 6805 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6803 def mute_update_time @mute_update_time end |
#name ⇒ String
Identifier. The relative resource name of the finding. The following list
shows some examples: + organizations/organization_id/sources/source_id/
findings/finding_id+ `organizations/`organization_id`/sources/`source_id`/
locations/`location_id`/findings/`finding_id + folders/folder_id/sources/
source_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/
locations/`location_id`/findings/`finding_id + projects/project_id/
sources/source_id/findings/finding_id+ `projects/`project_id`/sources/`
source_id`/locations/`location_id`/findings/`finding_id
Corresponds to the JSON property name
6816 6817 6818 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6816 def name @name end |
#networks ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Network>
Represents the VPC networks that the resource is attached to.
Corresponds to the JSON property networks
6821 6822 6823 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6821 def networks @networks end |
#next_steps ⇒ String
Steps to address the finding.
Corresponds to the JSON property nextSteps
6826 6827 6828 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6826 def next_steps @next_steps end |
#notebook ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Notebook
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated
with a finding.
Corresponds to the JSON property notebook
6833 6834 6835 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6833 def notebook @notebook end |
#org_policies ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2OrgPolicy>
Contains information about the org policies associated with the finding.
Corresponds to the JSON property orgPolicies
6838 6839 6840 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6838 def org_policies @org_policies end |
#parent ⇒ String
The relative resource name of the source and location the finding belongs to.
See: https://cloud.google.com/apis/design/resource_names#
relative_resource_name This field is immutable after creation time. The
following list shows some examples: + organizations/organization_id/sources/
source_id+ `folders/`folders_id`/sources/`source_id + projects/
projects_id/sources/source_id+ `organizations/`organization_id`/sources/`
source_id`/locations/`location_id + folders/folders_id/sources/source_id
/locations/location_id+ `projects/`projects_id`/sources/`source_id`/
locations/`location_id
Corresponds to the JSON property parent
6851 6852 6853 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6851 def parent @parent end |
#parent_display_name ⇒ String
Output only. The human readable display name of the finding source such as "
Event Threat Detection" or "Security Health Analytics".
Corresponds to the JSON property parentDisplayName
6857 6858 6859 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6857 def parent_display_name @parent_display_name end |
#processes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process>
Represents operating system processes associated with the Finding.
Corresponds to the JSON property processes
6862 6863 6864 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6862 def processes @processes end |
#resource_name ⇒ String
Immutable. For findings on Google Cloud resources, the full resource name of
the Google Cloud resource this finding is for. See: https://cloud.google.com/
apis/design/resource_names#full_resource_name When the finding is for a non-
Google Cloud resource, the resourceName can be a customer or partner defined
string.
Corresponds to the JSON property resourceName
6871 6872 6873 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6871 def resource_name @resource_name end |
#secret ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Secret
Details about a secret or credential associated with the finding.
Corresponds to the JSON property secret
6876 6877 6878 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6876 def secret @secret end |
#security_marks ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityMarks
User specified security marks that are attached to the parent Security Command
Center resource. Security marks are scoped within a Security Command Center
organization -- they can be modified and viewed by all users who have proper
permissions on the organization.
Corresponds to the JSON property securityMarks
6884 6885 6886 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6884 def security_marks @security_marks end |
#security_posture ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityPosture
Represents a posture that is deployed on Google Cloud by the Security Command
Center Posture Management service. A posture contains one or more policy sets.
A policy set is a group of policies that enforce a set of security rules on
Google Cloud.
Corresponds to the JSON property securityPosture
6892 6893 6894 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6892 def security_posture @security_posture end |
#severity ⇒ String
The severity of the finding. This field is managed by the source that writes
the finding.
Corresponds to the JSON property severity
6898 6899 6900 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6898 def severity @severity end |
#source_properties ⇒ Hash<String,Object>
Source specific properties. These properties are managed by the source that
writes the finding. The key names in the source_properties map must be between
1 and 255 characters, and must start with a letter and contain alphanumeric
characters or underscores only.
Corresponds to the JSON property sourceProperties
6906 6907 6908 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6906 def source_properties @source_properties end |
#state ⇒ String
Output only. The state of the finding.
Corresponds to the JSON property state
6911 6912 6913 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6911 def state @state end |
#toxic_combination ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ToxicCombination
Contains details about a group of security issues that, when the issues occur
together, represent a greater risk than when the issues occur independently. A
group of such issues is referred to as a toxic combination.
Corresponds to the JSON property toxicCombination
6918 6919 6920 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6918 def toxic_combination @toxic_combination end |
#vertex_ai ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2VertexAi
Vertex AI-related information associated with the finding.
Corresponds to the JSON property vertexAi
6923 6924 6925 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6923 def vertex_ai @vertex_ai end |
#vulnerability ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Vulnerability
Refers to common vulnerability fields e.g. cve, cvss, cwe etc.
Corresponds to the JSON property vulnerability
6928 6929 6930 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6928 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 6998 6999 7000 7001 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 6935 def update!(**args) @access = args[:access] if args.key?(:access) @affected_resources = args[:affected_resources] if args.key?(:affected_resources) @ai_model = args[:ai_model] if args.key?(:ai_model) @application = args[:application] if args.key?(:application) @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies) @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure) @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery) @canonical_name = args[:canonical_name] if args.key?(:canonical_name) @category = args[:category] if args.key?(:category) @chokepoint = args[:chokepoint] if args.key?(:chokepoint) @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor) @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile) @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection) @compliance_details = args[:compliance_details] if args.key?(:compliance_details) @compliances = args[:compliances] if args.key?(:compliances) @connections = args[:connections] if args.key?(:connections) @contacts = args[:contacts] if args.key?(:contacts) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @data_access_events = args[:data_access_events] if args.key?(:data_access_events) @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events) @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events) @database = args[:database] if args.key?(:database) @description = args[:description] if args.key?(:description) @disk = args[:disk] if args.key?(:disk) @event_time = args[:event_time] if args.key?(:event_time) @exfiltration = args[:exfiltration] if args.key?(:exfiltration) @external_systems = args[:external_systems] if args.key?(:external_systems) @external_uri = args[:external_uri] if args.key?(:external_uri) @files = args[:files] if args.key?(:files) @finding_class = args[:finding_class] if args.key?(:finding_class) @group_memberships = args[:group_memberships] if args.key?(:group_memberships) @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings) @indicator = args[:indicator] if args.key?(:indicator) @ip_rules = args[:ip_rules] if args.key?(:ip_rules) @job = args[:job] if args.key?(:job) @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit) @kubernetes = args[:kubernetes] if args.key?(:kubernetes) @load_balancers = args[:load_balancers] if args.key?(:load_balancers) @log_entries = args[:log_entries] if args.key?(:log_entries) @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack) @module_name = args[:module_name] if args.key?(:module_name) @mute = args[:mute] if args.key?(:mute) @mute_info = args[:mute_info] if args.key?(:mute_info) @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator) @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @next_steps = args[:next_steps] if args.key?(:next_steps) @notebook = args[:notebook] if args.key?(:notebook) @org_policies = args[:org_policies] if args.key?(:org_policies) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @processes = args[:processes] if args.key?(:processes) @resource_name = args[:resource_name] if args.key?(:resource_name) @secret = args[:secret] if args.key?(:secret) @security_marks = args[:security_marks] if args.key?(:security_marks) @security_posture = args[:security_posture] if args.key?(:security_posture) @severity = args[:severity] if args.key?(:severity) @source_properties = args[:source_properties] if args.key?(:source_properties) @state = args[:state] if args.key?(:state) @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination) @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |