Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
constructor
A new instance of GoogleCloudSecuritycenterV2Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
Returns a new instance of GoogleCloudSecuritycenterV2Framework.
7064 7065 7066 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
7038 7039 7040 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7038 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
Corresponds to the JSON property controls
7043 7044 7045 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7043 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
7050 7051 7052 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7050 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
7055 7056 7057 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7055 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
7062 7063 7064 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7062 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7069 7070 7071 7072 7073 7074 7075 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7069 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |