Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IpRules

Returns a new instance of GoogleCloudSecuritycenterV2IpRules.



7304
7305
7306
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Allowed

Allowed IP rule. Corresponds to the JSON property allowed



7271
7272
7273
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7271

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Denied

Denied IP rule. Corresponds to the JSON property denied



7276
7277
7278
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7276

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


7283
7284
7285
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7283

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


7288
7289
7290
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7288

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


7295
7296
7297
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7295

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


7302
7303
7304
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7302

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7309
7310
7311
7312
7313
7314
7315
7316
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7309

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end