Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueMute
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueMute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
The mute information of the issue.
Instance Attribute Summary collapse
-
#mute_initiator ⇒ String
The email address of the user who last changed the mute state of the issue.
-
#mute_reason ⇒ String
The user-provided reason for muting the issue.
-
#mute_state ⇒ String
Output only.
-
#mute_update_time ⇒ String
The time the issue was muted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueMute
constructor
A new instance of GoogleCloudSecuritycenterV2IssueMute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueMute
Returns a new instance of GoogleCloudSecuritycenterV2IssueMute.
7547 7548 7549 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mute_initiator ⇒ String
The email address of the user who last changed the mute state of the issue.
Corresponds to the JSON property muteInitiator
7530 7531 7532 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7530 def mute_initiator @mute_initiator end |
#mute_reason ⇒ String
The user-provided reason for muting the issue.
Corresponds to the JSON property muteReason
7535 7536 7537 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7535 def mute_reason @mute_reason end |
#mute_state ⇒ String
Output only. The mute state of the issue.
Corresponds to the JSON property muteState
7540 7541 7542 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7540 def mute_state @mute_state end |
#mute_update_time ⇒ String
The time the issue was muted.
Corresponds to the JSON property muteUpdateTime
7545 7546 7547 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7545 def mute_update_time @mute_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7552 7553 7554 7555 7556 7557 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7552 def update!(**args) @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator) @mute_reason = args[:mute_reason] if args.key?(:mute_reason) @mute_state = args[:mute_state] if args.key?(:mute_state) @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time) end |