Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A resource associated with the an issue.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
-
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
-
#display_name ⇒ String
The resource-type specific display name of the resource associated with the issue.
-
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
-
#name ⇒ String
The full resource name of the resource associated with the issue.
-
#type ⇒ String
The type of the resource associated with the issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.
8358 8359 8360 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8358 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
8305 8306 8307 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8305 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
8310 8311 8312 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8310 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
8315 8316 8317 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8315 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
Corresponds to the JSON property application
8320 8321 8322 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8320 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
Corresponds to the JSON property awsMetadata
8325 8326 8327 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8325 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
Corresponds to the JSON property azureMetadata
8330 8331 8332 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8330 def @azure_metadata end |
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
Corresponds to the JSON property cloudProvider
8335 8336 8337 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8335 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The resource-type specific display name of the resource associated with the
issue.
Corresponds to the JSON property displayName
8341 8342 8343 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8341 def display_name @display_name end |
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
Corresponds to the JSON property googleCloudMetadata
8346 8347 8348 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8346 def @google_cloud_metadata end |
#name ⇒ String
The full resource name of the resource associated with the issue.
Corresponds to the JSON property name
8351 8352 8353 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8351 def name @name end |
#type ⇒ String
The type of the resource associated with the issue.
Corresponds to the JSON property type
8356 8357 8358 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8356 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8363 8364 8365 8366 8367 8368 8369 8370 8371 8372 8373 8374 8375 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8363 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |