Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A resource associated with the an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource

Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.



7976
7977
7978
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



7923
7924
7925
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7923

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



7928
7929
7930
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7928

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



7933
7934
7935
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7933

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication

The AppHub application associated with the resource, if any. Corresponds to the JSON property application



7938
7939
7940
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7938

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

The AWS metadata of a resource associated with an issue. Corresponds to the JSON property awsMetadata



7943
7944
7945
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7943

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

The Azure metadata of a resource associated with an issue. Corresponds to the JSON property azureMetadata



7948
7949
7950
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7948

def 
  @azure_metadata
end

#cloud_providerString

The cloud provider of the resource associated with the issue. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


7953
7954
7955
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7953

def cloud_provider
  @cloud_provider
end

#display_nameString

The resource-type specific display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


7959
7960
7961
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7959

def display_name
  @display_name
end

#google_cloud_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata

Google Cloud metadata of a resource associated with an issue. Corresponds to the JSON property googleCloudMetadata



7964
7965
7966
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7964

def 
  @google_cloud_metadata
end

#nameString

The full resource name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


7969
7970
7971
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7969

def name
  @name
end

#typeString

The type of the resource associated with the issue. Corresponds to the JSON property type

Returns:

  • (String)


7974
7975
7976
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7974

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7981

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end