Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A resource associated with the an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource

Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.



7605
7606
7607
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicationGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication

The AppHub application associated with the resource, if any. Corresponds to the JSON property application



7567
7568
7569
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7567

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

The AWS metadata of a resource associated with an issue. Corresponds to the JSON property awsMetadata



7572
7573
7574
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7572

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

The Azure metadata of a resource associated with an issue. Corresponds to the JSON property azureMetadata



7577
7578
7579
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7577

def 
  @azure_metadata
end

#cloud_providerString

The cloud provider of the resource associated with the issue. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


7582
7583
7584
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7582

def cloud_provider
  @cloud_provider
end

#display_nameString

The resource-type specific display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


7588
7589
7590
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7588

def display_name
  @display_name
end

#google_cloud_metadataGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata

Google Cloud metadata of a resource associated with an issue. Corresponds to the JSON property googleCloudMetadata



7593
7594
7595
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7593

def 
  @google_cloud_metadata
end

#nameString

The full resource name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


7598
7599
7600
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7598

def name
  @name
end

#typeString

The type of the resource associated with the issue. Corresponds to the JSON property type

Returns:

  • (String)


7603
7604
7605
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7603

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7610

def update!(**args)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end