Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A resource associated with the an issue.
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
-
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
-
#display_name ⇒ String
The resource-type specific display name of the resource associated with the issue.
-
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
-
#name ⇒ String
The full resource name of the resource associated with the issue.
-
#type ⇒ String
The type of the resource associated with the issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.
7605 7606 7607 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
Corresponds to the JSON property application
7567 7568 7569 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7567 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
Corresponds to the JSON property awsMetadata
7572 7573 7574 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7572 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
Corresponds to the JSON property azureMetadata
7577 7578 7579 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7577 def @azure_metadata end |
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
Corresponds to the JSON property cloudProvider
7582 7583 7584 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7582 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The resource-type specific display name of the resource associated with the
issue.
Corresponds to the JSON property displayName
7588 7589 7590 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7588 def display_name @display_name end |
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
Corresponds to the JSON property googleCloudMetadata
7593 7594 7595 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7593 def @google_cloud_metadata end |
#name ⇒ String
The full resource name of the resource associated with the issue.
Corresponds to the JSON property name
7598 7599 7600 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7598 def name @name end |
#type ⇒ String
The type of the resource associated with the issue.
Corresponds to the JSON property type
7603 7604 7605 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7603 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7610 def update!(**args) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |