Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



8357
8358
8359
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



8335
8336
8337
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8335

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



8340
8341
8342
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8340

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



8345
8346
8347
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8345

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



8350
8351
8352
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8350

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



8355
8356
8357
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8355

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8362
8363
8364
8365
8366
8367
8368
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8362

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end