Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.
7677 7678 7679 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
7655 7656 7657 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7655 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
7660 7661 7662 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7660 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
7665 7666 7667 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7665 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
7670 7671 7672 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7670 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
7675 7676 7677 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7675 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7682 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |