Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The AWS metadata of a resource associated with an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadata.



7757
7758
7759
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

The AWS account of the resource associated with the issue. Corresponds to the JSON property account



7755
7756
7757
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7755

def 
  @account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7762
7763
7764
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7762

def update!(**args)
  @account = args[:account] if args.key?(:account)
end