Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

The Azure subscription of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription.



7825
7826
7827
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The Azure subscription display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


7818
7819
7820
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7818

def display_name
  @display_name
end

#idString

The Azure subscription ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


7823
7824
7825
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7823

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7830
7831
7832
7833
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7830

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end