Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
constructor
A new instance of GoogleCloudSecuritycenterV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
Returns a new instance of GoogleCloudSecuritycenterV2Job.
8396 8397 8398 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
8379 8380 8381 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8379 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
8384 8385 8386 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8384 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
8389 8390 8391 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8389 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
8394 8395 8396 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8394 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8401 8402 8403 8404 8405 8406 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8401 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |