Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job

Returns a new instance of GoogleCloudSecuritycenterV2Job.



7954
7955
7956
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


7937
7938
7939
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7937

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


7942
7943
7944
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7942

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


7947
7948
7949
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7947

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


7952
7953
7954
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7952

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7959
7960
7961
7962
7963
7964
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 7959

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end