Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Kubernetes-related attributes.
Instance Attribute Summary collapse
-
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
-
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
-
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding.
-
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
-
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
-
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods associated with the finding.
-
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
constructor
A new instance of GoogleCloudSecuritycenterV2Kubernetes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.
8777 8778 8779 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks)
relevant to the finding.
Corresponds to the JSON property accessReviews
8736 8737 8738 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8736 def access_reviews @access_reviews end |
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve
RoleBindings or ClusterRoleBindings.
Corresponds to the JSON property bindings
8743 8744 8745 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8743 def bindings @bindings end |
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding. This field contains node pool information
for each node, when it is available.
Corresponds to the JSON property nodePools
8750 8751 8752 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8750 def node_pools @node_pools end |
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
Corresponds to the JSON property nodes
8756 8757 8758 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8756 def nodes @nodes end |
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
Corresponds to the JSON property objects
8761 8762 8763 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8761 def objects @objects end |
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods
associated with the finding. This field contains Pod records for each
container that is owned by a Pod.
Corresponds to the JSON property pods
8768 8769 8770 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8768 def pods @pods end |
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or
ClusterRoles.
Corresponds to the JSON property roles
8775 8776 8777 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8775 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8782 8783 8784 8785 8786 8787 8788 8789 8790 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8782 def update!(**args) @access_reviews = args[:access_reviews] if args.key?(:access_reviews) @bindings = args[:bindings] if args.key?(:bindings) @node_pools = args[:node_pools] if args.key?(:node_pools) @nodes = args[:nodes] if args.key?(:nodes) @objects = args[:objects] if args.key?(:objects) @pods = args[:pods] if args.key?(:pods) @roles = args[:roles] if args.key?(:roles) end |