Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Kubernetes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Kubernetes-related attributes.
Instance Attribute Summary collapse
-
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
-
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
-
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding.
-
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
-
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
-
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods associated with the finding.
-
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
constructor
A new instance of GoogleCloudSecuritycenterV2Kubernetes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.
8097 8098 8099 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks)
relevant to the finding.
Corresponds to the JSON property accessReviews
8056 8057 8058 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8056 def access_reviews @access_reviews end |
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve
RoleBindings or ClusterRoleBindings.
Corresponds to the JSON property bindings
8063 8064 8065 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8063 def bindings @bindings end |
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding. This field contains node pool information
for each node, when it is available.
Corresponds to the JSON property nodePools
8070 8071 8072 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8070 def node_pools @node_pools end |
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
Corresponds to the JSON property nodes
8076 8077 8078 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8076 def nodes @nodes end |
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
Corresponds to the JSON property objects
8081 8082 8083 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8081 def objects @objects end |
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods
associated with the finding. This field contains Pod records for each
container that is owned by a Pod.
Corresponds to the JSON property pods
8088 8089 8090 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8088 def pods @pods end |
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or
ClusterRoles.
Corresponds to the JSON property roles
8095 8096 8097 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8095 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8102 8103 8104 8105 8106 8107 8108 8109 8110 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8102 def update!(**args) @access_reviews = args[:access_reviews] if args.key?(:access_reviews) @bindings = args[:bindings] if args.key?(:bindings) @node_pools = args[:node_pools] if args.key?(:node_pools) @nodes = args[:nodes] if args.key?(:nodes) @objects = args[:objects] if args.key?(:objects) @pods = args[:pods] if args.key?(:pods) @roles = args[:roles] if args.key?(:roles) end |