Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig

Returns a new instance of GoogleCloudSecuritycenterV2MuteConfig.



9010
9011
9012
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the mute config was created. This field is set by the server and will be ignored if provided on config creation. Corresponds to the JSON property createTime

Returns:

  • (String)


8945
8946
8947
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8945

def create_time
  @create_time
end

#crypto_key_nameString

Output only. The resource name of the Cloud KMS CryptoKey used to encrypt this configuration data, if CMEK was enabled during Security Command Center activation. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


8952
8953
8954
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8952

def crypto_key_name
  @crypto_key_name
end

#descriptionString

A description of the mute config. Corresponds to the JSON property description

Returns:

  • (String)


8957
8958
8959
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8957

def description
  @description
end

#expiry_timeString

Optional. The expiry of the mute config. Only applicable for dynamic configs. If the expiry is set, when the config expires, it is removed from all findings. Corresponds to the JSON property expiryTime

Returns:

  • (String)


8963
8964
8965
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8963

def expiry_time
  @expiry_time
end

#filterString

Required. An expression that defines the filter to apply across create/update events of findings. While creating a filter string, be mindful of the scope in which the mute configuration is being created. E.g., If a filter contains project = X but is created under the project = Y scope, it might not match any findings. The following field and operator combinations are supported: * severity: =, : * category: =, : * resource.name: =, : * resource. project_name: =, : * resource.project_display_name: =, : * resource. folders.resource_folder: =, : * resource.parent_name: =, : * resource. parent_display_name: =, : * resource.type: =, : * finding_class: =, : * indicator.ip_addresses: =, : * indicator.domains: =, : Corresponds to the JSON property filter

Returns:

  • (String)


8977
8978
8979
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8977

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the mute config. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


8984
8985
8986
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8984

def most_recent_editor
  @most_recent_editor
end

#nameString

Identifier. This field will be ignored if provided on config creation. The following list shows some examples of the format: + organizations/ organization/muteConfigs/mute_config+ `organizations/`organization` locations/`location`//muteConfigs/`mute_config + folders/folder/ muteConfigs/mute_config+ `folders/`folder`/locations/`location`/ muteConfigs/`mute_config + projects/project/muteConfigs/mute_config+ ` projects/`project`/locations/`location`/muteConfigs/`mute_config Corresponds to the JSON property name

Returns:

  • (String)


8995
8996
8997
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8995

def name
  @name
end

#typeString

Required. The type of the mute config, which determines what type of mute state the config affects. Immutable after creation. Corresponds to the JSON property type

Returns:

  • (String)


9001
9002
9003
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9001

def type
  @type
end

#update_timeString

Output only. The most recent time at which the mute config was updated. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


9008
9009
9010
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9008

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
9025
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9015

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @description = args[:description] if args.key?(:description)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end