Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig

Returns a new instance of GoogleCloudSecuritycenterV2MuteConfig.



8772
8773
8774
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the mute config was created. This field is set by the server and will be ignored if provided on config creation. Corresponds to the JSON property createTime

Returns:

  • (String)


8707
8708
8709
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8707

def create_time
  @create_time
end

#crypto_key_nameString

Output only. The resource name of the Cloud KMS CryptoKey used to encrypt this configuration data, if CMEK was enabled during Security Command Center activation. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


8714
8715
8716
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8714

def crypto_key_name
  @crypto_key_name
end

#descriptionString

A description of the mute config. Corresponds to the JSON property description

Returns:

  • (String)


8719
8720
8721
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8719

def description
  @description
end

#expiry_timeString

Optional. The expiry of the mute config. Only applicable for dynamic configs. If the expiry is set, when the config expires, it is removed from all findings. Corresponds to the JSON property expiryTime

Returns:

  • (String)


8725
8726
8727
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8725

def expiry_time
  @expiry_time
end

#filterString

Required. An expression that defines the filter to apply across create/update events of findings. While creating a filter string, be mindful of the scope in which the mute configuration is being created. E.g., If a filter contains project = X but is created under the project = Y scope, it might not match any findings. The following field and operator combinations are supported: * severity: =, : * category: =, : * resource.name: =, : * resource. project_name: =, : * resource.project_display_name: =, : * resource. folders.resource_folder: =, : * resource.parent_name: =, : * resource. parent_display_name: =, : * resource.type: =, : * finding_class: =, : * indicator.ip_addresses: =, : * indicator.domains: =, : Corresponds to the JSON property filter

Returns:

  • (String)


8739
8740
8741
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8739

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the mute config. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


8746
8747
8748
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8746

def most_recent_editor
  @most_recent_editor
end

#nameString

Identifier. This field will be ignored if provided on config creation. The following list shows some examples of the format: + organizations/ organization/muteConfigs/mute_config+ `organizations/`organization` locations/`location`//muteConfigs/`mute_config + folders/folder/ muteConfigs/mute_config+ `folders/`folder`/locations/`location`/ muteConfigs/`mute_config + projects/project/muteConfigs/mute_config+ ` projects/`project`/locations/`location`/muteConfigs/`mute_config Corresponds to the JSON property name

Returns:

  • (String)


8757
8758
8759
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8757

def name
  @name
end

#typeString

Required. The type of the mute config, which determines what type of mute state the config affects. Immutable after creation. Corresponds to the JSON property type

Returns:

  • (String)


8763
8764
8765
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8763

def type
  @type
end

#update_timeString

Output only. The most recent time at which the mute config was updated. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


8770
8771
8772
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8770

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8777
8778
8779
8780
8781
8782
8783
8784
8785
8786
8787
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8777

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @description = args[:description] if args.key?(:description)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end