Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2MuteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Output only.
-
#description ⇒ String
A description of the mute config.
-
#expiry_time ⇒ String
Optional.
-
#filter ⇒ String
Required.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig
constructor
A new instance of GoogleCloudSecuritycenterV2MuteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig
Returns a new instance of GoogleCloudSecuritycenterV2MuteConfig.
8330 8331 8332 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the mute config was created. This field is set
by the server and will be ignored if provided on config creation.
Corresponds to the JSON property createTime
8265 8266 8267 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8265 def create_time @create_time end |
#crypto_key_name ⇒ String
Output only. The resource name of the Cloud KMS CryptoKey used to encrypt
this configuration data, if CMEK was enabled during Security Command Center
activation.
Corresponds to the JSON property cryptoKeyName
8272 8273 8274 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8272 def crypto_key_name @crypto_key_name end |
#description ⇒ String
A description of the mute config.
Corresponds to the JSON property description
8277 8278 8279 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8277 def description @description end |
#expiry_time ⇒ String
Optional. The expiry of the mute config. Only applicable for dynamic configs.
If the expiry is set, when the config expires, it is removed from all findings.
Corresponds to the JSON property expiryTime
8283 8284 8285 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8283 def expiry_time @expiry_time end |
#filter ⇒ String
Required. An expression that defines the filter to apply across create/update
events of findings. While creating a filter string, be mindful of the scope in
which the mute configuration is being created. E.g., If a filter contains
project = X but is created under the project = Y scope, it might not match any
findings. The following field and operator combinations are supported: *
severity: =, : * category: =, : * resource.name: =, : * resource.
project_name: =, : * resource.project_display_name: =, : * resource.
folders.resource_folder: =, : * resource.parent_name: =, : * resource.
parent_display_name: =, : * resource.type: =, : * finding_class: =,
: * indicator.ip_addresses: =, : * indicator.domains: =, :
Corresponds to the JSON property filter
8297 8298 8299 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8297 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the mute config. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property mostRecentEditor
8304 8305 8306 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8304 def most_recent_editor @most_recent_editor end |
#name ⇒ String
Identifier. This field will be ignored if provided on config creation. The
following list shows some examples of the format: + organizations/
organization/muteConfigs/mute_config+ `organizations/`organization`
locations/`location`//muteConfigs/`mute_config + folders/folder/
muteConfigs/mute_config+ `folders/`folder`/locations/`location`/
muteConfigs/`mute_config + projects/project/muteConfigs/mute_config+ `
projects/`project`/locations/`location`/muteConfigs/`mute_config
Corresponds to the JSON property name
8315 8316 8317 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8315 def name @name end |
#type ⇒ String
Required. The type of the mute config, which determines what type of mute
state the config affects. Immutable after creation.
Corresponds to the JSON property type
8321 8322 8323 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8321 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the mute config was updated. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property updateTime
8328 8329 8330 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8328 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8335 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @description = args[:description] if args.key?(:description) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |