Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook

Returns a new instance of GoogleCloudSecuritycenterV2Notebook.



8467
8468
8469
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


8450
8451
8452
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8450

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


8455
8456
8457
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8455

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


8460
8461
8462
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8460

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


8465
8466
8467
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8465

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8472
8473
8474
8475
8476
8477
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8472

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end