Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
-
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
-
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
-
#name ⇒ String
Kubernetes object name.
-
#ns ⇒ String
Kubernetes object namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
constructor
A new instance of GoogleCloudSecuritycenterV2Object.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
Returns a new instance of GoogleCloudSecuritycenterV2Object.
9228 9229 9230 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
Corresponds to the JSON property containers
9203 9204 9205 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9203 def containers @containers end |
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
Corresponds to the JSON property group
9208 9209 9210 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9208 def group @group end |
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
Corresponds to the JSON property kind
9213 9214 9215 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9213 def kind @kind end |
#name ⇒ String
Kubernetes object name. For details see https://kubernetes.io/docs/concepts/
overview/working-with-objects/names/.
Corresponds to the JSON property name
9219 9220 9221 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9219 def name @name end |
#ns ⇒ String
Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid
collision with C++ namespace keyword. For details see https://kubernetes.io/
docs/tasks/administer-cluster/namespaces/.
Corresponds to the JSON property ns
9226 9227 9228 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9226 def ns @ns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9233 9234 9235 9236 9237 9238 9239 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9233 def update!(**args) @containers = args[:containers] if args.key?(:containers) @group = args[:group] if args.key?(:group) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) end |