Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object

Returns a new instance of GoogleCloudSecuritycenterV2Object.



8990
8991
8992
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8990

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



8965
8966
8967
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8965

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


8970
8971
8972
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8970

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


8975
8976
8977
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8975

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


8981
8982
8983
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8981

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


8988
8989
8990
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8988

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8995
8996
8997
8998
8999
9000
9001
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8995

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end