Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object

Returns a new instance of GoogleCloudSecuritycenterV2Object.



8548
8549
8550
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



8523
8524
8525
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8523

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


8528
8529
8530
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8528

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


8533
8534
8535
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8533

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


8539
8540
8541
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8539

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


8546
8547
8548
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8546

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8553
8554
8555
8556
8557
8558
8559
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8553

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end