Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2PortRange
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2PortRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.
Instance Attribute Summary collapse
-
#max ⇒ Fixnum
Maximum port value.
-
#min ⇒ Fixnum
Minimum port value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange
constructor
A new instance of GoogleCloudSecuritycenterV2PortRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange
Returns a new instance of GoogleCloudSecuritycenterV2PortRange.
8733 8734 8735 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max ⇒ Fixnum
Maximum port value.
Corresponds to the JSON property max
8726 8727 8728 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8726 def max @max end |
#min ⇒ Fixnum
Minimum port value.
Corresponds to the JSON property min
8731 8732 8733 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8731 def min @min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8738 8739 8740 8741 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8738 def update!(**args) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) end |