Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an operating system process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process

Returns a new instance of GoogleCloudSecuritycenterV2Process.



9532
9533
9534
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Process arguments as JSON encoded strings. Corresponds to the JSON property args

Returns:

  • (Array<String>)


9474
9475
9476
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9474

def args
  @args
end

#arguments_truncatedBoolean Also known as: arguments_truncated?

True if args is incomplete. Corresponds to the JSON property argumentsTruncated

Returns:

  • (Boolean)


9479
9480
9481
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9479

def arguments_truncated
  @arguments_truncated
end

#binaryGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property binary



9486
9487
9488
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9486

def binary
  @binary
end

#env_variablesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2EnvironmentVariable>

Process environment variables. Corresponds to the JSON property envVariables



9491
9492
9493
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9491

def env_variables
  @env_variables
end

#env_variables_truncatedBoolean Also known as: env_variables_truncated?

True if env_variables is incomplete. Corresponds to the JSON property envVariablesTruncated

Returns:

  • (Boolean)


9496
9497
9498
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9496

def env_variables_truncated
  @env_variables_truncated
end

#librariesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>

File information for libraries loaded by the process. Corresponds to the JSON property libraries



9502
9503
9504
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9502

def libraries
  @libraries
end

#nameString

The process name, as displayed in utilities like top and ps. This name can be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME). Corresponds to the JSON property name

Returns:

  • (String)


9508
9509
9510
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9508

def name
  @name
end

#parent_pidFixnum

The parent process ID. Corresponds to the JSON property parentPid

Returns:

  • (Fixnum)


9513
9514
9515
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9513

def parent_pid
  @parent_pid
end

#pidFixnum

The process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


9518
9519
9520
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9518

def pid
  @pid
end

#scriptGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property script



9524
9525
9526
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9524

def script
  @script
end

#user_idFixnum

The ID of the user that executed the process. E.g. If this is the root user this will always be 0. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


9530
9531
9532
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9530

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9537
9538
9539
9540
9541
9542
9543
9544
9545
9546
9547
9548
9549
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9537

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated)
  @binary = args[:binary] if args.key?(:binary)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated)
  @libraries = args[:libraries] if args.key?(:libraries)
  @name = args[:name] if args.key?(:name)
  @parent_pid = args[:parent_pid] if args.key?(:parent_pid)
  @pid = args[:pid] if args.key?(:pid)
  @script = args[:script] if args.key?(:script)
  @user_id = args[:user_id] if args.key?(:user_id)
end