Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an operating system process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process

Returns a new instance of GoogleCloudSecuritycenterV2Process.



9251
9252
9253
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Process arguments as JSON encoded strings. Corresponds to the JSON property args

Returns:

  • (Array<String>)


9193
9194
9195
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9193

def args
  @args
end

#arguments_truncatedBoolean Also known as: arguments_truncated?

True if args is incomplete. Corresponds to the JSON property argumentsTruncated

Returns:

  • (Boolean)


9198
9199
9200
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9198

def arguments_truncated
  @arguments_truncated
end

#binaryGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property binary



9205
9206
9207
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9205

def binary
  @binary
end

#env_variablesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2EnvironmentVariable>

Process environment variables. Corresponds to the JSON property envVariables



9210
9211
9212
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9210

def env_variables
  @env_variables
end

#env_variables_truncatedBoolean Also known as: env_variables_truncated?

True if env_variables is incomplete. Corresponds to the JSON property envVariablesTruncated

Returns:

  • (Boolean)


9215
9216
9217
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9215

def env_variables_truncated
  @env_variables_truncated
end

#librariesArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>

File information for libraries loaded by the process. Corresponds to the JSON property libraries



9221
9222
9223
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9221

def libraries
  @libraries
end

#nameString

The process name, as displayed in utilities like top and ps. This name can be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME). Corresponds to the JSON property name

Returns:

  • (String)


9227
9228
9229
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9227

def name
  @name
end

#parent_pidFixnum

The parent process ID. Corresponds to the JSON property parentPid

Returns:

  • (Fixnum)


9232
9233
9234
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9232

def parent_pid
  @parent_pid
end

#pidFixnum

The process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


9237
9238
9239
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9237

def pid
  @pid
end

#scriptGoogle::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property script



9243
9244
9245
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9243

def script
  @script
end

#user_idFixnum

The ID of the user that executed the process. E.g. If this is the root user this will always be 0. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


9249
9250
9251
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9249

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
9267
9268
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9256

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated)
  @binary = args[:binary] if args.key?(:binary)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated)
  @libraries = args[:libraries] if args.key?(:libraries)
  @name = args[:name] if args.key?(:name)
  @parent_pid = args[:parent_pid] if args.key?(:parent_pid)
  @pid = args[:pid] if args.key?(:pid)
  @script = args[:script] if args.key?(:script)
  @user_id = args[:user_id] if args.key?(:user_id)
end