Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
constructor
A new instance of GoogleCloudSecuritycenterV2Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
Returns a new instance of GoogleCloudSecuritycenterV2Process.
8809 8810 8811 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8809 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
8751 8752 8753 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8751 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
8756 8757 8758 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8756 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
8763 8764 8765 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8763 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
8768 8769 8770 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8768 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
8773 8774 8775 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8773 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
8779 8780 8781 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8779 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
8785 8786 8787 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8785 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
8790 8791 8792 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8790 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
8795 8796 8797 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8795 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
8801 8802 8803 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8801 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
8807 8808 8809 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8807 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8814 8815 8816 8817 8818 8819 8820 8821 8822 8823 8824 8825 8826 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8814 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |