Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
-
#display_name ⇒ String
The human readable name of the resource.
-
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The service or resource provider associated with the resource.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
constructor
A new instance of GoogleCloudSecuritycenterV2Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
Returns a new instance of GoogleCloudSecuritycenterV2Resource.
9740 9741 9742 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
9655 9656 9657 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9655 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
9660 9661 9662 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9660 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
9665 9666 9667 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9665 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
9670 9671 9672 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9670 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
9676 9677 9678 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9676 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
9682 9683 9684 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9682 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
Corresponds to the JSON property cloudProvider
9687 9688 9689 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9687 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
9692 9693 9694 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9692 def display_name @display_name end |
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource. Only applicable if the
finding's cloud provider is Google Cloud.
Corresponds to the JSON property gcpMetadata
9698 9699 9700 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9698 def @gcp_metadata end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
9703 9704 9705 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9703 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
9709 9710 9711 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9709 def name @name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
9715 9716 9717 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9715 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
9728 9729 9730 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9728 def resource_path_string @resource_path_string end |
#service ⇒ String
The service or resource provider associated with the resource.
Corresponds to the JSON property service
9733 9734 9735 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9733 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
9738 9739 9740 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9738 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9745 9746 9747 9748 9749 9750 9751 9752 9753 9754 9755 9756 9757 9758 9759 9760 9761 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9745 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |