Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
-
#display_name ⇒ String
The human readable name of the resource.
-
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The service or resource provider associated with the resource.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
constructor
A new instance of GoogleCloudSecuritycenterV2Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
Returns a new instance of GoogleCloudSecuritycenterV2Resource.
9459 9460 9461 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
9374 9375 9376 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9374 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
9379 9380 9381 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9379 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
9384 9385 9386 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9384 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
9389 9390 9391 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9389 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
9395 9396 9397 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9395 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
9401 9402 9403 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9401 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
Corresponds to the JSON property cloudProvider
9406 9407 9408 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9406 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
9411 9412 9413 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9411 def display_name @display_name end |
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource. Only applicable if the
finding's cloud provider is Google Cloud.
Corresponds to the JSON property gcpMetadata
9417 9418 9419 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9417 def @gcp_metadata end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
9422 9423 9424 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9422 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
9428 9429 9430 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9428 def name @name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
9434 9435 9436 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9434 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
9447 9448 9449 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9447 def resource_path_string @resource_path_string end |
#service ⇒ String
The service or resource provider associated with the resource.
Corresponds to the JSON property service
9452 9453 9454 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9452 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
9457 9458 9459 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9457 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9464 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |