Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
-
#display_name ⇒ String
The human readable name of the resource.
-
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The service or resource provider associated with the resource.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
constructor
A new instance of GoogleCloudSecuritycenterV2Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
Returns a new instance of GoogleCloudSecuritycenterV2Resource.
9002 9003 9004 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
8932 8933 8934 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8932 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
8938 8939 8940 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8938 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
8944 8945 8946 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8944 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
Corresponds to the JSON property cloudProvider
8949 8950 8951 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8949 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
8954 8955 8956 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8954 def display_name @display_name end |
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1beta2::GcpMetadata
Google Cloud metadata associated with the resource. Only applicable if the
finding's cloud provider is Google Cloud.
Corresponds to the JSON property gcpMetadata
8960 8961 8962 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8960 def @gcp_metadata end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
8965 8966 8967 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8965 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
8971 8972 8973 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8971 def name @name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
8977 8978 8979 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8977 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
8990 8991 8992 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8990 def resource_path_string @resource_path_string end |
#service ⇒ String
The service or resource provider associated with the resource.
Corresponds to the JSON property service
8995 8996 8997 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 8995 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
9000 9001 9002 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9000 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9007 9008 9009 9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9007 def update!(**args) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |