Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
9078 9079 9080 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
9056 9057 9058 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9056 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
9061 9062 9063 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9061 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
9066 9067 9068 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9066 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
9071 9072 9073 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9071 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
9076 9077 9078 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9076 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9083 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |