Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode

Returns a new instance of GoogleCloudSecuritycenterV2ResourcePathNode.



9931
9932
9933
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


9919
9920
9921
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9919

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


9924
9925
9926
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9924

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


9929
9930
9931
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9929

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9936
9937
9938
9939
9940
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9936

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end