Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode

Returns a new instance of GoogleCloudSecuritycenterV2ResourcePathNode.



9650
9651
9652
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


9638
9639
9640
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9638

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


9643
9644
9645
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9643

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


9648
9649
9650
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9648

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9655
9656
9657
9658
9659
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9655

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end