Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourcePathNode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A node within the resource path. Each node represents a resource within the resource hierarchy.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the resource this node represents.
-
#id ⇒ String
The ID of the resource this node represents.
-
#node_type ⇒ String
The type of resource this node represents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode
constructor
A new instance of GoogleCloudSecuritycenterV2ResourcePathNode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode
Returns a new instance of GoogleCloudSecuritycenterV2ResourcePathNode.
9190 9191 9192 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the resource this node represents.
Corresponds to the JSON property displayName
9178 9179 9180 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9178 def display_name @display_name end |
#id ⇒ String
The ID of the resource this node represents.
Corresponds to the JSON property id
9183 9184 9185 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9183 def id @id end |
#node_type ⇒ String
The type of resource this node represents.
Corresponds to the JSON property nodeType
9188 9189 9190 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9188 def node_type @node_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9195 9196 9197 9198 9199 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9195 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @node_type = args[:node_type] if args.key?(:node_type) end |