Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceValueConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceValueConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
Cloud provider this configuration applies to Corresponds to the JSON property
cloudProvider. -
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the resource value configuration.
-
#name ⇒ String
Identifier.
-
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with
AND. -
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type.
-
#resource_value ⇒ String
Resource value level this expression represents Only required when there is no Sensitive Data Protection mapping in the request Corresponds to the JSON property
resourceValue. -
#scope ⇒ String
Project or folder to scope this configuration to.
-
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration.
-
#tag_values ⇒ Array<String>
Tag values combined with
ANDto check against. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceValueConfig
constructor
A new instance of GoogleCloudSecuritycenterV2ResourceValueConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceValueConfig
Returns a new instance of GoogleCloudSecuritycenterV2ResourceValueConfig.
10017 10018 10019 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
Cloud provider this configuration applies to
Corresponds to the JSON property cloudProvider
9951 9952 9953 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9951 def cloud_provider @cloud_provider end |
#create_time ⇒ String
Output only. Timestamp this resource value configuration was created.
Corresponds to the JSON property createTime
9956 9957 9958 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9956 def create_time @create_time end |
#description ⇒ String
Description of the resource value configuration.
Corresponds to the JSON property description
9961 9962 9963 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9961 def description @description end |
#name ⇒ String
Identifier. Name for the resource value configuration
Corresponds to the JSON property name
9966 9967 9968 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9966 def name @name end |
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with AND. For example, "
resource_labels_selector": "key": "value", "env": "prod" will match
resources with labels "key": "value" AND "env": "prod" https://cloud.google.
com/resource-manager/docs/creating-managing-labels
Corresponds to the JSON property resourceLabelsSelector
9974 9975 9976 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9974 def resource_labels_selector @resource_labels_selector end |
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type. resource_type
will be checked with AND of other resources. For example, "storage.
googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only
to "storage.googleapis.com/Bucket" resources.
Corresponds to the JSON property resourceType
9982 9983 9984 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9982 def resource_type @resource_type end |
#resource_value ⇒ String
Resource value level this expression represents Only required when there is no
Sensitive Data Protection mapping in the request
Corresponds to the JSON property resourceValue
9988 9989 9990 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9988 def resource_value @resource_value end |
#scope ⇒ String
Project or folder to scope this configuration to. For example, "project/456"
would apply this configuration only to resources in "project/456" scope and
will be checked with AND of other resources.
Corresponds to the JSON property scope
9995 9996 9997 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9995 def scope @scope end |
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings If any of these
mappings have a resource value that is not unspecified, the resource_value
field will be ignored when reading this configuration.
Corresponds to the JSON property sensitiveDataProtectionMapping
10002 10003 10004 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10002 def sensitive_data_protection_mapping @sensitive_data_protection_mapping end |
#tag_values ⇒ Array<String>
Tag values combined with AND to check against. For Google Cloud resources,
they are tag value IDs in the form of "tagValues/123". Example: [ "tagValues/
123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/resource-
manager/docs/tags/tags-creating-and-managing
Corresponds to the JSON property tagValues
10010 10011 10012 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10010 def tag_values @tag_values end |
#update_time ⇒ String
Output only. Timestamp this resource value configuration was last updated.
Corresponds to the JSON property updateTime
10015 10016 10017 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10015 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10022 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector) @resource_type = args[:resource_type] if args.key?(:resource_type) @resource_value = args[:resource_value] if args.key?(:resource_value) @scope = args[:scope] if args.key?(:scope) @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping) @tag_values = args[:tag_values] if args.key?(:tag_values) @update_time = args[:update_time] if args.key?(:update_time) end |