Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceValueConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2ResourceValueConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
Cloud provider this configuration applies to Corresponds to the JSON property
cloudProvider. -
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the resource value configuration.
-
#name ⇒ String
Identifier.
-
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with
AND. -
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type.
-
#resource_value ⇒ String
Resource value level this expression represents Only required when there is no Sensitive Data Protection mapping in the request Corresponds to the JSON property
resourceValue. -
#scope ⇒ String
Project or folder to scope this configuration to.
-
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration.
-
#tag_values ⇒ Array<String>
Tag values combined with
ANDto check against. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceValueConfig
constructor
A new instance of GoogleCloudSecuritycenterV2ResourceValueConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceValueConfig
Returns a new instance of GoogleCloudSecuritycenterV2ResourceValueConfig.
9736 9737 9738 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
Cloud provider this configuration applies to
Corresponds to the JSON property cloudProvider
9670 9671 9672 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9670 def cloud_provider @cloud_provider end |
#create_time ⇒ String
Output only. Timestamp this resource value configuration was created.
Corresponds to the JSON property createTime
9675 9676 9677 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9675 def create_time @create_time end |
#description ⇒ String
Description of the resource value configuration.
Corresponds to the JSON property description
9680 9681 9682 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9680 def description @description end |
#name ⇒ String
Identifier. Name for the resource value configuration
Corresponds to the JSON property name
9685 9686 9687 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9685 def name @name end |
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with AND. For example, "
resource_labels_selector": "key": "value", "env": "prod" will match
resources with labels "key": "value" AND "env": "prod" https://cloud.google.
com/resource-manager/docs/creating-managing-labels
Corresponds to the JSON property resourceLabelsSelector
9693 9694 9695 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9693 def resource_labels_selector @resource_labels_selector end |
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type. resource_type
will be checked with AND of other resources. For example, "storage.
googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only
to "storage.googleapis.com/Bucket" resources.
Corresponds to the JSON property resourceType
9701 9702 9703 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9701 def resource_type @resource_type end |
#resource_value ⇒ String
Resource value level this expression represents Only required when there is no
Sensitive Data Protection mapping in the request
Corresponds to the JSON property resourceValue
9707 9708 9709 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9707 def resource_value @resource_value end |
#scope ⇒ String
Project or folder to scope this configuration to. For example, "project/456"
would apply this configuration only to resources in "project/456" scope and
will be checked with AND of other resources.
Corresponds to the JSON property scope
9714 9715 9716 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9714 def scope @scope end |
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings If any of these
mappings have a resource value that is not unspecified, the resource_value
field will be ignored when reading this configuration.
Corresponds to the JSON property sensitiveDataProtectionMapping
9721 9722 9723 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9721 def sensitive_data_protection_mapping @sensitive_data_protection_mapping end |
#tag_values ⇒ Array<String>
Tag values combined with AND to check against. For Google Cloud resources,
they are tag value IDs in the form of "tagValues/123". Example: [ "tagValues/
123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/resource-
manager/docs/tags/tags-creating-and-managing
Corresponds to the JSON property tagValues
9729 9730 9731 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9729 def tag_values @tag_values end |
#update_time ⇒ String
Output only. Timestamp this resource value configuration was last updated.
Corresponds to the JSON property updateTime
9734 9735 9736 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9734 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9741 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector) @resource_type = args[:resource_type] if args.key?(:resource_type) @resource_value = args[:resource_value] if args.key?(:resource_value) @scope = args[:scope] if args.key?(:scope) @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping) @tag_values = args[:tag_values] if args.key?(:tag_values) @update_time = args[:update_time] if args.key?(:update_time) end |