Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Returns a new instance of GoogleCloudSecuritycenterV2SecretEnvironmentVariable.



9375
9376
9377
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


9373
9374
9375
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9373

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9380
9381
9382
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9380

def update!(**args)
  @key = args[:key] if args.key?(:key)
end