Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SecurityPosture

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecurityPosture

Returns a new instance of GoogleCloudSecuritycenterV2SecurityPosture.



9602
9603
9604
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#changed_policyString

The name of the updated policy, for example, projects/project_id/policies/ constraint_name`. Corresponds to the JSON propertychangedPolicy`

Returns:

  • (String)


9562
9563
9564
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9562

def changed_policy
  @changed_policy
end

#nameString

Name of the posture, for example, CIS-Posture. Corresponds to the JSON property name

Returns:

  • (String)


9567
9568
9569
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9567

def name
  @name
end

#policyString

The ID of the updated policy, for example, compute-policy-1. Corresponds to the JSON property policy

Returns:

  • (String)


9572
9573
9574
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9572

def policy
  @policy
end

#policy_drift_detailsArray<Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2PolicyDriftDetails>

The details about a change in an updated policy that violates the deployed posture. Corresponds to the JSON property policyDriftDetails



9578
9579
9580
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9578

def policy_drift_details
  @policy_drift_details
end

#policy_setString

The name of the updated policy set, for example, cis-policyset. Corresponds to the JSON property policySet

Returns:

  • (String)


9583
9584
9585
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9583

def policy_set
  @policy_set
end

#posture_deploymentString

The name of the posture deployment, for example, organizations/org_id/ posturedeployments/posture_deployment_id`. Corresponds to the JSON propertypostureDeployment`

Returns:

  • (String)


9589
9590
9591
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9589

def posture_deployment
  @posture_deployment
end

#posture_deployment_resourceString

The project, folder, or organization on which the posture is deployed, for example, projects/project_number`. Corresponds to the JSON propertypostureDeploymentResource`

Returns:

  • (String)


9595
9596
9597
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9595

def posture_deployment_resource
  @posture_deployment_resource
end

#revision_idString

The version of the posture, for example, c7cfa2a8. Corresponds to the JSON property revisionId

Returns:

  • (String)


9600
9601
9602
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9600

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9607
9608
9609
9610
9611
9612
9613
9614
9615
9616
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9607

def update!(**args)
  @changed_policy = args[:changed_policy] if args.key?(:changed_policy)
  @name = args[:name] if args.key?(:name)
  @policy = args[:policy] if args.key?(:policy)
  @policy_drift_details = args[:policy_drift_details] if args.key?(:policy_drift_details)
  @policy_set = args[:policy_set] if args.key?(:policy_set)
  @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment)
  @posture_deployment_resource = args[:posture_deployment_resource] if args.key?(:posture_deployment_resource)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end