Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitivityScore

Returns a new instance of GoogleCloudSecuritycenterV2SensitivityScore.



10117
10118
10119
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


10115
10116
10117
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10115

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10122
10123
10124
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10122

def update!(**args)
  @score = args[:score] if args.key?(:score)
end