Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10533
10534
10535
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10506
10507
10508
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10506

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10511
10512
10513
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10511

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10516
10517
10518
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10516

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10521
10522
10523
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10521

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10526
10527
10528
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10526

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10531
10532
10533
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10531

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10538
10539
10540
10541
10542
10543
10544
10545
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10538

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end