Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10252
10253
10254
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10225
10226
10227
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10225

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10230
10231
10232
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10230

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10235
10236
10237
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10235

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10240
10241
10242
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10240

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10245
10246
10247
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10245

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10250
10251
10252
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10250

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10257
10258
10259
10260
10261
10262
10263
10264
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10257

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end