Class: Google::Apis::SecuritycenterV1beta2::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



9792
9793
9794
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


9765
9766
9767
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9765

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


9770
9771
9772
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9770

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


9775
9776
9777
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9775

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


9780
9781
9782
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9780

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9785
9786
9787
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9785

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


9790
9791
9792
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9790

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9797
9798
9799
9800
9801
9802
9803
9804
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 9797

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end