Class: Google::Apis::SecuritycenterV1beta2::IpRules
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::IpRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
IP rules associated with the finding.
Instance Attribute Summary collapse
-
#allowed ⇒ Google::Apis::SecuritycenterV1beta2::Allowed
Allowed IP rule.
-
#denied ⇒ Google::Apis::SecuritycenterV1beta2::Denied
Denied IP rule.
-
#destination_ip_ranges ⇒ Array<String>
If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges.
-
#direction ⇒ String
The direction that the rule is applicable to, one of ingress or egress.
-
#exposed_services ⇒ Array<String>
Name of the network protocol service, such as FTP, that is exposed by the open port.
-
#source_ip_ranges ⇒ Array<String>
If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpRules
constructor
A new instance of IpRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpRules
Returns a new instance of IpRules.
10891 10892 10893 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Google::Apis::SecuritycenterV1beta2::Allowed
Allowed IP rule.
Corresponds to the JSON property allowed
10858 10859 10860 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10858 def allowed @allowed end |
#denied ⇒ Google::Apis::SecuritycenterV1beta2::Denied
Denied IP rule.
Corresponds to the JSON property denied
10863 10864 10865 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10863 def denied @denied end |
#destination_ip_ranges ⇒ Array<String>
If destination IP ranges are specified, the firewall rule applies only to
traffic that has a destination IP address in these ranges. These ranges must
be expressed in CIDR format. Only supports IPv4.
Corresponds to the JSON property destinationIpRanges
10870 10871 10872 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10870 def destination_ip_ranges @destination_ip_ranges end |
#direction ⇒ String
The direction that the rule is applicable to, one of ingress or egress.
Corresponds to the JSON property direction
10875 10876 10877 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10875 def direction @direction end |
#exposed_services ⇒ Array<String>
Name of the network protocol service, such as FTP, that is exposed by the open
port. Follows the naming convention available at: https://www.iana.org/
assignments/service-names-port-numbers/service-names-port-numbers.xhtml.
Corresponds to the JSON property exposedServices
10882 10883 10884 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10882 def exposed_services @exposed_services end |
#source_ip_ranges ⇒ Array<String>
If source IP ranges are specified, the firewall rule applies only to traffic
that has a source IP address in these ranges. These ranges must be expressed
in CIDR format. Only supports IPv4.
Corresponds to the JSON property sourceIpRanges
10889 10890 10891 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10889 def source_ip_ranges @source_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10896 10897 10898 10899 10900 10901 10902 10903 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10896 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @denied = args[:denied] if args.key?(:denied) @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges) @direction = args[:direction] if args.key?(:direction) @exposed_services = args[:exposed_services] if args.key?(:exposed_services) @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges) end |