Class: Google::Apis::SecuritycenterV1beta2::IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRules

Returns a new instance of IpRules.



10150
10151
10152
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta2::Allowed

Allowed IP rule. Corresponds to the JSON property allowed



10117
10118
10119
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10117

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta2::Denied

Denied IP rule. Corresponds to the JSON property denied



10122
10123
10124
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10122

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


10129
10130
10131
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10129

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


10134
10135
10136
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10134

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


10141
10142
10143
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10141

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


10148
10149
10150
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10148

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10155
10156
10157
10158
10159
10160
10161
10162
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10155

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end