Class: Google::Apis::SecuritycenterV1beta2::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



10649
10650
10651
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


10632
10633
10634
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10632

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


10637
10638
10639
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10637

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


10642
10643
10644
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10642

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


10647
10648
10649
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10647

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10654
10655
10656
10657
10658
10659
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10654

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end