Class: Google::Apis::SecuritycenterV1beta2::Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
10189 10190 10191 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
10172 10173 10174 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10172 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
10177 10178 10179 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10177 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
10182 10183 10184 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10182 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
10187 10188 10189 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10187 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10194 10195 10196 10197 10198 10199 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10194 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |