Class: Google::Apis::SecuritycenterV1beta2::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
11351 11352 11353 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
11334 11335 11336 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11334 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
11339 11340 11341 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11339 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
11344 11345 11346 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11344 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
11349 11350 11351 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11349 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11356 11357 11358 11359 11360 11361 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11356 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |