Class: Google::Apis::SecuritycenterV1beta2::Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Notebook

Returns a new instance of Notebook.



11070
11071
11072
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


11053
11054
11055
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11053

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


11058
11059
11060
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11058

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


11063
11064
11065
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11063

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


11068
11069
11070
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11068

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11075
11076
11077
11078
11079
11080
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11075

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end