Class: Google::Apis::SecuritycenterV1beta2::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
10610 10611 10612 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
10593 10594 10595 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10593 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
10598 10599 10600 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10598 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
10603 10604 10605 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10603 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
10608 10609 10610 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10608 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10615 10616 10617 10618 10619 10620 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10615 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |