Class: Google::Apis::SecuritycenterV1beta2::Package
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Package
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Package is a generic definition of a package.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
The CPE URI where the vulnerability was detected.
-
#package_name ⇒ String
The name of the package where the vulnerability was detected.
-
#package_type ⇒ String
Type of package, for example, os, maven, or go.
-
#package_version ⇒ String
The version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Package
constructor
A new instance of Package.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Package
Returns a new instance of Package.
10714 10715 10716 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
The CPE URI where the vulnerability was detected.
Corresponds to the JSON property cpeUri
10697 10698 10699 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10697 def cpe_uri @cpe_uri end |
#package_name ⇒ String
The name of the package where the vulnerability was detected.
Corresponds to the JSON property packageName
10702 10703 10704 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10702 def package_name @package_name end |
#package_type ⇒ String
Type of package, for example, os, maven, or go.
Corresponds to the JSON property packageType
10707 10708 10709 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10707 def package_type @package_type end |
#package_version ⇒ String
The version of the package.
Corresponds to the JSON property packageVersion
10712 10713 10714 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10712 def package_version @package_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10719 10720 10721 10722 10723 10724 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10719 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @package_name = args[:package_name] if args.key?(:package_name) @package_type = args[:package_type] if args.key?(:package_type) @package_version = args[:package_version] if args.key?(:package_version) end |