Class: Google::Apis::SecuritycenterV1beta2::PortRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PortRange

Returns a new instance of PortRange.



10841
10842
10843
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxFixnum

Maximum port value. Corresponds to the JSON property max

Returns:

  • (Fixnum)


10834
10835
10836
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10834

def max
  @max
end

#minFixnum

Minimum port value. Corresponds to the JSON property min

Returns:

  • (Fixnum)


10839
10840
10841
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10839

def min
  @min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10846
10847
10848
10849
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10846

def update!(**args)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
end