Class: Google::Apis::SecuritycenterV1beta2::Process

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an operating system process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Process

Returns a new instance of Process.



11701
11702
11703
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Process arguments as JSON encoded strings. Corresponds to the JSON property args

Returns:

  • (Array<String>)


11643
11644
11645
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11643

def args
  @args
end

#arguments_truncatedBoolean Also known as: arguments_truncated?

True if args is incomplete. Corresponds to the JSON property argumentsTruncated

Returns:

  • (Boolean)


11648
11649
11650
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11648

def arguments_truncated
  @arguments_truncated
end

#binaryGoogle::Apis::SecuritycenterV1beta2::File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property binary



11655
11656
11657
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11655

def binary
  @binary
end

#env_variablesArray<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>

Process environment variables. Corresponds to the JSON property envVariables



11660
11661
11662
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11660

def env_variables
  @env_variables
end

#env_variables_truncatedBoolean Also known as: env_variables_truncated?

True if env_variables is incomplete. Corresponds to the JSON property envVariablesTruncated

Returns:

  • (Boolean)


11665
11666
11667
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11665

def env_variables_truncated
  @env_variables_truncated
end

#librariesArray<Google::Apis::SecuritycenterV1beta2::File>

File information for libraries loaded by the process. Corresponds to the JSON property libraries



11671
11672
11673
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11671

def libraries
  @libraries
end

#nameString

The process name, as displayed in utilities like top and ps. This name can be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME). Corresponds to the JSON property name

Returns:

  • (String)


11677
11678
11679
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11677

def name
  @name
end

#parent_pidFixnum

The parent process ID. Corresponds to the JSON property parentPid

Returns:

  • (Fixnum)


11682
11683
11684
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11682

def parent_pid
  @parent_pid
end

#pidFixnum

The process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


11687
11688
11689
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11687

def pid
  @pid
end

#scriptGoogle::Apis::SecuritycenterV1beta2::File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property script



11693
11694
11695
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11693

def script
  @script
end

#user_idFixnum

The ID of the user that executed the process. E.g. If this is the root user this will always be 0. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


11699
11700
11701
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11699

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11706

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated)
  @binary = args[:binary] if args.key?(:binary)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated)
  @libraries = args[:libraries] if args.key?(:libraries)
  @name = args[:name] if args.key?(:name)
  @parent_pid = args[:parent_pid] if args.key?(:parent_pid)
  @pid = args[:pid] if args.key?(:pid)
  @script = args[:script] if args.key?(:script)
  @user_id = args[:user_id] if args.key?(:user_id)
end