Class: Google::Apis::SecuritycenterV1beta2::Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Process
constructor
A new instance of Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Process
Returns a new instance of Process.
11377 11378 11379 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
11319 11320 11321 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11319 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
11324 11325 11326 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11324 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
11331 11332 11333 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11331 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
11336 11337 11338 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11336 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
11341 11342 11343 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11341 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta2::File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
11347 11348 11349 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11347 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
11353 11354 11355 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11353 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
11358 11359 11360 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11358 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
11363 11364 11365 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11363 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta2::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
11369 11370 11371 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11369 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
11375 11376 11377 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11375 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11382 11383 11384 11385 11386 11387 11388 11389 11390 11391 11392 11393 11394 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11382 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |