Class: Google::Apis::SecuritycenterV1beta2::Process

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents an operating system process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Process

Returns a new instance of Process.



10917
10918
10919
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Process arguments as JSON encoded strings. Corresponds to the JSON property args

Returns:

  • (Array<String>)


10859
10860
10861
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10859

def args
  @args
end

#arguments_truncatedBoolean Also known as: arguments_truncated?

True if args is incomplete. Corresponds to the JSON property argumentsTruncated

Returns:

  • (Boolean)


10864
10865
10866
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10864

def arguments_truncated
  @arguments_truncated
end

#binaryGoogle::Apis::SecuritycenterV1beta2::File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property binary



10871
10872
10873
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10871

def binary
  @binary
end

#env_variablesArray<Google::Apis::SecuritycenterV1beta2::EnvironmentVariable>

Process environment variables. Corresponds to the JSON property envVariables



10876
10877
10878
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10876

def env_variables
  @env_variables
end

#env_variables_truncatedBoolean Also known as: env_variables_truncated?

True if env_variables is incomplete. Corresponds to the JSON property envVariablesTruncated

Returns:

  • (Boolean)


10881
10882
10883
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10881

def env_variables_truncated
  @env_variables_truncated
end

#librariesArray<Google::Apis::SecuritycenterV1beta2::File>

File information for libraries loaded by the process. Corresponds to the JSON property libraries



10887
10888
10889
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10887

def libraries
  @libraries
end

#nameString

The process name, as displayed in utilities like top and ps. This name can be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME). Corresponds to the JSON property name

Returns:

  • (String)


10893
10894
10895
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10893

def name
  @name
end

#parent_pidFixnum

The parent process ID. Corresponds to the JSON property parentPid

Returns:

  • (Fixnum)


10898
10899
10900
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10898

def parent_pid
  @parent_pid
end

#pidFixnum

The process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


10903
10904
10905
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10903

def pid
  @pid
end

#scriptGoogle::Apis::SecuritycenterV1beta2::File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property script



10909
10910
10911
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10909

def script
  @script
end

#user_idFixnum

The ID of the user that executed the process. E.g. If this is the root user this will always be 0. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


10915
10916
10917
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10915

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 10922

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated)
  @binary = args[:binary] if args.key?(:binary)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated)
  @libraries = args[:libraries] if args.key?(:libraries)
  @name = args[:name] if args.key?(:name)
  @parent_pid = args[:parent_pid] if args.key?(:parent_pid)
  @pid = args[:pid] if args.key?(:pid)
  @script = args[:script] if args.key?(:script)
  @user_id = args[:user_id] if args.key?(:user_id)
end