Class: Google::Apis::SecuritycenterV1beta2::RapidVulnerabilityDetectionSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for the Rapid Vulnerability Detection service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RapidVulnerabilityDetectionSettings

Returns a new instance of RapidVulnerabilityDetectionSettings.



11782
11783
11784
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modulesHash<String,Google::Apis::SecuritycenterV1beta2::Config>

The configurations including the state of enablement for the service's different modules. The absence of a module in the map implies its configuration is inherited from its parent's. Corresponds to the JSON property modules



11761
11762
11763
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11761

def modules
  @modules
end

#nameString

The resource name of the RapidVulnerabilityDetectionSettings. Formats: * organizations/organization/rapidVulnerabilityDetectionSettings * folders/ folder/rapidVulnerabilityDetectionSettings * projects/project/ rapidVulnerabilityDetectionSettings Corresponds to the JSON property name

Returns:

  • (String)


11769
11770
11771
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11769

def name
  @name
end

#service_enablement_stateString

The state of enablement for the service at its level of the resource hierarchy. A DISABLED state will override all module enablement_states to DISABLED. Corresponds to the JSON property serviceEnablementState

Returns:

  • (String)


11775
11776
11777
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11775

def service_enablement_state
  @service_enablement_state
end

#update_timeString

Output only. The time the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11780
11781
11782
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11780

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11787
11788
11789
11790
11791
11792
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11787

def update!(**args)
  @modules = args[:modules] if args.key?(:modules)
  @name = args[:name] if args.key?(:name)
  @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state)
  @update_time = args[:update_time] if args.key?(:update_time)
end