Class: Google::Apis::SecuritycenterV1beta2::Requests
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::Requests
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information about the requests relevant to the finding.
Instance Attribute Summary collapse
-
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
-
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
-
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic.
-
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Requests
constructor
A new instance of Requests.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Requests
Returns a new instance of Requests.
12017 12018 12019 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
Corresponds to the JSON property longTermAllowed
11998 11999 12000 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11998 def long_term_allowed @long_term_allowed end |
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
Corresponds to the JSON property longTermDenied
12003 12004 12005 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12003 def long_term_denied @long_term_denied end |
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the
allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic
in the short term divided by allowed traffic in the long term.
Corresponds to the JSON property ratio
12010 12011 12012 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12010 def ratio @ratio end |
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Corresponds to the JSON property shortTermAllowed
12015 12016 12017 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12015 def short_term_allowed @short_term_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12022 12023 12024 12025 12026 12027 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12022 def update!(**args) @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed) @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied) @ratio = args[:ratio] if args.key?(:ratio) @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed) end |