Class: Google::Apis::SecuritycenterV1beta2::Requests

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the requests relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Requests

Returns a new instance of Requests.



11847
11848
11849
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#long_term_allowedFixnum

Allowed RPS (requests per second) over the long term. Corresponds to the JSON property longTermAllowed

Returns:

  • (Fixnum)


11828
11829
11830
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11828

def long_term_allowed
  @long_term_allowed
end

#long_term_deniedFixnum

Denied RPS (requests per second) over the long term. Corresponds to the JSON property longTermDenied

Returns:

  • (Fixnum)


11833
11834
11835
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11833

def long_term_denied
  @long_term_denied
end

#ratioFloat

For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic in the short term divided by allowed traffic in the long term. Corresponds to the JSON property ratio

Returns:

  • (Float)


11840
11841
11842
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11840

def ratio
  @ratio
end

#short_term_allowedFixnum

Allowed RPS (requests per second) in the short term. Corresponds to the JSON property shortTermAllowed

Returns:

  • (Fixnum)


11845
11846
11847
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11845

def short_term_allowed
  @short_term_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11852
11853
11854
11855
11856
11857
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11852

def update!(**args)
  @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed)
  @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied)
  @ratio = args[:ratio] if args.key?(:ratio)
  @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed)
end