Class: Google::Apis::SecuritycenterV1beta2::ResourcePath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents the path of resources leading up to the resource this finding is about.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePath

Returns a new instance of ResourcePath.



11547
11548
11549
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::SecuritycenterV1beta2::ResourcePathNode>

The list of nodes that make the up resource path, ordered from lowest level to highest level. Corresponds to the JSON property nodes



11545
11546
11547
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11545

def nodes
  @nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11552
11553
11554
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11552

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
end