Class: Google::Apis::SecuritycenterV1beta2::ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePathNode

Returns a new instance of ResourcePathNode.



11577
11578
11579
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


11565
11566
11567
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11565

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


11570
11571
11572
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11570

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


11575
11576
11577
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11575

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11582
11583
11584
11585
11586
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11582

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end