Class: Google::Apis::SecuritycenterV1beta2::ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePathNode

Returns a new instance of ResourcePathNode.



11117
11118
11119
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


11105
11106
11107
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11105

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


11110
11111
11112
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11110

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


11115
11116
11117
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11115

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11122
11123
11124
11125
11126
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11122

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end