Class: Google::Apis::SecuritycenterV1beta2::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



11668
11669
11670
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


11666
11667
11668
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11666

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11673
11674
11675
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11673

def update!(**args)
  @key = args[:key] if args.key?(:key)
end