Class: Google::Apis::SecuritycenterV1beta2::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



11208
11209
11210
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


11206
11207
11208
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11206

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11213
11214
11215
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11213

def update!(**args)
  @key = args[:key] if args.key?(:key)
end