Class: Google::Apis::SecuritycenterV1beta2::SecurityBulletin
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::SecurityBulletin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
SecurityBulletin are notifications of vulnerabilities of Google products.
Instance Attribute Summary collapse
-
#bulletin_id ⇒ String
ID of the bulletin corresponding to the vulnerability.
-
#submission_time ⇒ String
Submission time of this Security Bulletin.
-
#suggested_upgrade_version ⇒ String
This represents a version that the cluster receiving this notification should be upgraded to, based on its current version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityBulletin
constructor
A new instance of SecurityBulletin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityBulletin
Returns a new instance of SecurityBulletin.
12066 12067 12068 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulletin_id ⇒ String
ID of the bulletin corresponding to the vulnerability.
Corresponds to the JSON property bulletinId
12053 12054 12055 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12053 def bulletin_id @bulletin_id end |
#submission_time ⇒ String
Submission time of this Security Bulletin.
Corresponds to the JSON property submissionTime
12058 12059 12060 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12058 def submission_time @submission_time end |
#suggested_upgrade_version ⇒ String
This represents a version that the cluster receiving this notification should
be upgraded to, based on its current version. For example, 1.15.0
Corresponds to the JSON property suggestedUpgradeVersion
12064 12065 12066 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12064 def suggested_upgrade_version @suggested_upgrade_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12071 12072 12073 12074 12075 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12071 def update!(**args) @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id) @submission_time = args[:submission_time] if args.key?(:submission_time) @suggested_upgrade_version = args[:suggested_upgrade_version] if args.key?(:suggested_upgrade_version) end |