Class: Google::Apis::SecuritycenterV1beta2::SecurityCenterSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::SecurityCenterSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource capturing the settings for Security Center.
Instance Attribute Summary collapse
-
#crypto_key_name ⇒ String
The KMS key name used for CMEK encryption.
-
#log_sink_project ⇒ String
The resource name of the project to send logs to.
-
#name ⇒ String
The resource name of the SecurityCenterSettings.
-
#onboarding_time ⇒ String
Output only.
-
#org_service_account ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityCenterSettings
constructor
A new instance of SecurityCenterSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityCenterSettings
Returns a new instance of SecurityCenterSettings.
12286 12287 12288 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crypto_key_name ⇒ String
The KMS key name used for CMEK encryption. Format: projects/project/
locations/location/keyRings/key_ring/cryptoKeys/key_name
Corresponds to the JSON property cryptoKeyName
12256 12257 12258 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12256 def crypto_key_name @crypto_key_name end |
#log_sink_project ⇒ String
The resource name of the project to send logs to. This project must be part of
the organization this resource resides in. The format is projects/project_id
. An empty value disables logging. This value is only referenced by services
that support log sink. Please refer to the documentation for an updated list
of compatible services. This may only be specified for organization level
onboarding.
Corresponds to the JSON property logSinkProject
12266 12267 12268 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12266 def log_sink_project @log_sink_project end |
#name ⇒ String
The resource name of the SecurityCenterSettings. Format: organizations/
organization/securityCenterSettings Format: folders/folder/
securityCenterSettings Format: projects/project/securityCenterSettings
Corresponds to the JSON property name
12273 12274 12275 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12273 def name @name end |
#onboarding_time ⇒ String
Output only. Timestamp of when the customer organization was onboarded to SCC.
Corresponds to the JSON property onboardingTime
12278 12279 12280 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12278 def onboarding_time @onboarding_time end |
#org_service_account ⇒ String
Output only. The organization level service account to be used for security
center components.
Corresponds to the JSON property orgServiceAccount
12284 12285 12286 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12284 def org_service_account @org_service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12291 12292 12293 12294 12295 12296 12297 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12291 def update!(**args) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @log_sink_project = args[:log_sink_project] if args.key?(:log_sink_project) @name = args[:name] if args.key?(:name) @onboarding_time = args[:onboarding_time] if args.key?(:onboarding_time) @org_service_account = args[:org_service_account] if args.key?(:org_service_account) end |