Class: Google::Apis::SecuritycenterV1beta2::SecurityCenterSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::SecurityCenterSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource capturing the settings for Security Center.
Instance Attribute Summary collapse
-
#crypto_key_name ⇒ String
The KMS key name used for CMEK encryption.
-
#log_sink_project ⇒ String
The resource name of the project to send logs to.
-
#name ⇒ String
The resource name of the SecurityCenterSettings.
-
#onboarding_time ⇒ String
Output only.
-
#org_service_account ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityCenterSettings
constructor
A new instance of SecurityCenterSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityCenterSettings
Returns a new instance of SecurityCenterSettings.
12116 12117 12118 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crypto_key_name ⇒ String
The KMS key name used for CMEK encryption. Format: projects/project/
locations/location/keyRings/key_ring/cryptoKeys/key_name
Corresponds to the JSON property cryptoKeyName
12086 12087 12088 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12086 def crypto_key_name @crypto_key_name end |
#log_sink_project ⇒ String
The resource name of the project to send logs to. This project must be part of
the organization this resource resides in. The format is projects/project_id
. An empty value disables logging. This value is only referenced by services
that support log sink. Please refer to the documentation for an updated list
of compatible services. This may only be specified for organization level
onboarding.
Corresponds to the JSON property logSinkProject
12096 12097 12098 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12096 def log_sink_project @log_sink_project end |
#name ⇒ String
The resource name of the SecurityCenterSettings. Format: organizations/
organization/securityCenterSettings Format: folders/folder/
securityCenterSettings Format: projects/project/securityCenterSettings
Corresponds to the JSON property name
12103 12104 12105 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12103 def name @name end |
#onboarding_time ⇒ String
Output only. Timestamp of when the customer organization was onboarded to SCC.
Corresponds to the JSON property onboardingTime
12108 12109 12110 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12108 def onboarding_time @onboarding_time end |
#org_service_account ⇒ String
Output only. The organization level service account to be used for security
center components.
Corresponds to the JSON property orgServiceAccount
12114 12115 12116 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12114 def org_service_account @org_service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12121 12122 12123 12124 12125 12126 12127 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12121 def update!(**args) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @log_sink_project = args[:log_sink_project] if args.key?(:log_sink_project) @name = args[:name] if args.key?(:name) @onboarding_time = args[:onboarding_time] if args.key?(:onboarding_time) @org_service_account = args[:org_service_account] if args.key?(:org_service_account) end |