Class: Google::Apis::SecuritycenterV1beta2::SecurityCenterSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for Security Center.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityCenterSettings

Returns a new instance of SecurityCenterSettings.



11792
11793
11794
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crypto_key_nameString

The KMS key name used for CMEK encryption. Format: projects/project/ locations/location/keyRings/key_ring/cryptoKeys/key_name Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


11762
11763
11764
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11762

def crypto_key_name
  @crypto_key_name
end

#log_sink_projectString

The resource name of the project to send logs to. This project must be part of the organization this resource resides in. The format is projects/project_id . An empty value disables logging. This value is only referenced by services that support log sink. Please refer to the documentation for an updated list of compatible services. This may only be specified for organization level onboarding. Corresponds to the JSON property logSinkProject

Returns:

  • (String)


11772
11773
11774
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11772

def log_sink_project
  @log_sink_project
end

#nameString

The resource name of the SecurityCenterSettings. Format: organizations/ organization/securityCenterSettings Format: folders/folder/ securityCenterSettings Format: projects/project/securityCenterSettings Corresponds to the JSON property name

Returns:

  • (String)


11779
11780
11781
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11779

def name
  @name
end

#onboarding_timeString

Output only. Timestamp of when the customer organization was onboarded to SCC. Corresponds to the JSON property onboardingTime

Returns:

  • (String)


11784
11785
11786
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11784

def onboarding_time
  @onboarding_time
end

#org_service_accountString

Output only. The organization level service account to be used for security center components. Corresponds to the JSON property orgServiceAccount

Returns:

  • (String)


11790
11791
11792
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11790

def 
  @org_service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11797
11798
11799
11800
11801
11802
11803
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11797

def update!(**args)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @log_sink_project = args[:log_sink_project] if args.key?(:log_sink_project)
  @name = args[:name] if args.key?(:name)
  @onboarding_time = args[:onboarding_time] if args.key?(:onboarding_time)
  @org_service_account = args[:org_service_account] if args.key?(:org_service_account)
end