Class: Google::Apis::SecuritycenterV1beta2::SecurityHealthAnalyticsSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for the Security Health Analytics service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityHealthAnalyticsSettings

Returns a new instance of SecurityHealthAnalyticsSettings.



11381
11382
11383
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modulesHash<String,Google::Apis::SecuritycenterV1beta2::Config>

The configurations including the state of enablement for the service's different modules. The absence of a module in the map implies its configuration is inherited from its parent's configuration. Corresponds to the JSON property modules



11355
11356
11357
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11355

def modules
  @modules
end

#nameString

Identifier. The resource name of the SecurityHealthAnalyticsSettings. Formats:

  • organizations/organization/securityHealthAnalyticsSettings * folders/ folder/securityHealthAnalyticsSettings * projects/project/ securityHealthAnalyticsSettings Corresponds to the JSON property name

Returns:

  • (String)


11363
11364
11365
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11363

def name
  @name
end

#service_accountString

Output only. The service account used by Security Health Analytics detectors. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


11368
11369
11370
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11368

def 
  @service_account
end

#service_enablement_stateString

The state of enablement for the service at its level of the resource hierarchy. A DISABLED state will override all module enablement_states to DISABLED. Corresponds to the JSON property serviceEnablementState

Returns:

  • (String)


11374
11375
11376
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11374

def service_enablement_state
  @service_enablement_state
end

#update_timeString

Output only. The time the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11379
11380
11381
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11379

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11386
11387
11388
11389
11390
11391
11392
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11386

def update!(**args)
  @modules = args[:modules] if args.key?(:modules)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state)
  @update_time = args[:update_time] if args.key?(:update_time)
end