Class: Google::Apis::SecuritycenterV1beta2::SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the Google Cloud Armor security policy relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicy

Returns a new instance of SecurityPolicy.



11926
11927
11928
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the Google Cloud Armor security policy, for example, "my-security- policy". Corresponds to the JSON property name

Returns:

  • (String)


11911
11912
11913
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11911

def name
  @name
end

#previewBoolean Also known as: preview?

Whether or not the associated rule or policy is in preview mode. Corresponds to the JSON property preview

Returns:

  • (Boolean)


11916
11917
11918
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11916

def preview
  @preview
end

#typeString

The type of Google Cloud Armor security policy for example, 'backend security policy', 'edge security policy', 'network edge security policy', or 'always-on DDoS protection'. Corresponds to the JSON property type

Returns:

  • (String)


11924
11925
11926
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11924

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11931
11932
11933
11934
11935
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11931

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @preview = args[:preview] if args.key?(:preview)
  @type = args[:type] if args.key?(:type)
end