Class: Google::Apis::SecuritycenterV1beta2::SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the Google Cloud Armor security policy relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicy

Returns a new instance of SecurityPolicy.



11466
11467
11468
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the Google Cloud Armor security policy, for example, "my-security- policy". Corresponds to the JSON property name

Returns:

  • (String)


11451
11452
11453
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11451

def name
  @name
end

#previewBoolean Also known as: preview?

Whether or not the associated rule or policy is in preview mode. Corresponds to the JSON property preview

Returns:

  • (Boolean)


11456
11457
11458
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11456

def preview
  @preview
end

#typeString

The type of Google Cloud Armor security policy for example, 'backend security policy', 'edge security policy', 'network edge security policy', or 'always-on DDoS protection'. Corresponds to the JSON property type

Returns:

  • (String)


11464
11465
11466
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11464

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11471
11472
11473
11474
11475
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11471

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @preview = args[:preview] if args.key?(:preview)
  @type = args[:type] if args.key?(:type)
end