Class: Google::Apis::SecuritycenterV1beta2::SecurityPosture

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPosture

Returns a new instance of SecurityPosture.



11529
11530
11531
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#changed_policyString

The name of the updated policy, for example, projects/project_id/policies/ constraint_name`. Corresponds to the JSON propertychangedPolicy`

Returns:

  • (String)


11489
11490
11491
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11489

def changed_policy
  @changed_policy
end

#nameString

Name of the posture, for example, CIS-Posture. Corresponds to the JSON property name

Returns:

  • (String)


11494
11495
11496
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11494

def name
  @name
end

#policyString

The ID of the updated policy, for example, compute-policy-1. Corresponds to the JSON property policy

Returns:

  • (String)


11499
11500
11501
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11499

def policy
  @policy
end

#policy_drift_detailsArray<Google::Apis::SecuritycenterV1beta2::PolicyDriftDetails>

The details about a change in an updated policy that violates the deployed posture. Corresponds to the JSON property policyDriftDetails



11505
11506
11507
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11505

def policy_drift_details
  @policy_drift_details
end

#policy_setString

The name of the updated policyset, for example, cis-policyset. Corresponds to the JSON property policySet

Returns:

  • (String)


11510
11511
11512
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11510

def policy_set
  @policy_set
end

#posture_deploymentString

The name of the posture deployment, for example, organizations/org_id/ posturedeployments/posture_deployment_id`. Corresponds to the JSON propertypostureDeployment`

Returns:

  • (String)


11516
11517
11518
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11516

def posture_deployment
  @posture_deployment
end

#posture_deployment_resourceString

The project, folder, or organization on which the posture is deployed, for example, projects/project_number`. Corresponds to the JSON propertypostureDeploymentResource`

Returns:

  • (String)


11522
11523
11524
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11522

def posture_deployment_resource
  @posture_deployment_resource
end

#revision_idString

The version of the posture, for example, c7cfa2a8. Corresponds to the JSON property revisionId

Returns:

  • (String)


11527
11528
11529
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11527

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11534

def update!(**args)
  @changed_policy = args[:changed_policy] if args.key?(:changed_policy)
  @name = args[:name] if args.key?(:name)
  @policy = args[:policy] if args.key?(:policy)
  @policy_drift_details = args[:policy_drift_details] if args.key?(:policy_drift_details)
  @policy_set = args[:policy_set] if args.key?(:policy_set)
  @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment)
  @posture_deployment_resource = args[:posture_deployment_resource] if args.key?(:posture_deployment_resource)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end