Class: Google::Apis::SecuritycenterV1beta2::SensitivityScore
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::SensitivityScore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.
Instance Attribute Summary collapse
-
#score ⇒ String
The sensitivity score applied to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SensitivityScore
constructor
A new instance of SensitivityScore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SensitivityScore
Returns a new instance of SensitivityScore.
12016 12017 12018 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#score ⇒ String
The sensitivity score applied to the resource.
Corresponds to the JSON property score
12014 12015 12016 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12014 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12021 12022 12023 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12021 def update!(**args) @score = args[:score] if args.key?(:score) end |