Class: Google::Apis::SecuritycenterV1beta2::SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitivityScore

Returns a new instance of SensitivityScore.



11556
11557
11558
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


11554
11555
11556
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11554

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11561
11562
11563
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11561

def update!(**args)
  @score = args[:score] if args.key?(:score)
end