Class: Google::Apis::SecuritycenterV1beta2::TicketInfo
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::TicketInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Attribute Summary collapse
-
#assignee ⇒ String
The assignee of the ticket in the ticket system.
-
#description ⇒ String
The description of the ticket in the ticket system.
-
#id ⇒ String
The identifier of the ticket in the ticket system.
-
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
-
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
-
#uri ⇒ String
The link to the ticket in the ticket system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TicketInfo
constructor
A new instance of TicketInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TicketInfo
Returns a new instance of TicketInfo.
12677 12678 12679 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignee ⇒ String
The assignee of the ticket in the ticket system.
Corresponds to the JSON property assignee
12650 12651 12652 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12650 def assignee @assignee end |
#description ⇒ String
The description of the ticket in the ticket system.
Corresponds to the JSON property description
12655 12656 12657 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12655 def description @description end |
#id ⇒ String
The identifier of the ticket in the ticket system.
Corresponds to the JSON property id
12660 12661 12662 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12660 def id @id end |
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
Corresponds to the JSON property status
12665 12666 12667 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12665 def status @status end |
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
Corresponds to the JSON property updateTime
12670 12671 12672 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12670 def update_time @update_time end |
#uri ⇒ String
The link to the ticket in the ticket system.
Corresponds to the JSON property uri
12675 12676 12677 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12675 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12682 12683 12684 12685 12686 12687 12688 12689 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12682 def update!(**args) @assignee = args[:assignee] if args.key?(:assignee) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) end |