Class: Google::Apis::SecuritycenterV1beta2::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



12507
12508
12509
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


12480
12481
12482
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12480

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


12485
12486
12487
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12485

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


12490
12491
12492
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12490

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


12495
12496
12497
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12495

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


12500
12501
12502
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12500

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


12505
12506
12507
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12505

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12512
12513
12514
12515
12516
12517
12518
12519
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12512

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end