Class: Google::Apis::SecuritycenterV1beta2::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



12183
12184
12185
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


12156
12157
12158
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12156

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


12161
12162
12163
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12161

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


12166
12167
12168
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12166

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


12171
12172
12173
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12171

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


12176
12177
12178
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12176

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


12181
12182
12183
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12181

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12188
12189
12190
12191
12192
12193
12194
12195
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12188

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end