Class: Google::Apis::SecuritycenterV1beta2::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



11723
11724
11725
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


11696
11697
11698
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11696

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


11701
11702
11703
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11701

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


11706
11707
11708
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11706

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


11711
11712
11713
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11711

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


11716
11717
11718
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11716

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


11721
11722
11723
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11721

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11728
11729
11730
11731
11732
11733
11734
11735
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11728

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end