Class: Google::Apis::SecuritycenterV1beta2::VirtualMachineThreatDetectionSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb

Overview

Resource capturing the settings for the Virtual Machine Threat Detection service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VirtualMachineThreatDetectionSettings

Returns a new instance of VirtualMachineThreatDetectionSettings.



12615
12616
12617
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modulesHash<String,Google::Apis::SecuritycenterV1beta2::Config>

The configurations including the state of enablement for the service's different modules. The absence of a module in the map implies its configuration is inherited from its parent's configuration. Corresponds to the JSON property modules



12588
12589
12590
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12588

def modules
  @modules
end

#nameString

Identifier. The resource name of the VirtualMachineThreatDetectionSettings. Formats: * organizations/organization/virtualMachineThreatDetectionSettings * folders/folder/virtualMachineThreatDetectionSettings * projects/project/ virtualMachineThreatDetectionSettings Corresponds to the JSON property name

Returns:

  • (String)


12596
12597
12598
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12596

def name
  @name
end

#service_accountString

Output only. The service account used by Virtual Machine Threat Detection detectors. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


12602
12603
12604
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12602

def 
  @service_account
end

#service_enablement_stateString

The state of enablement for the service at its level of the resource hierarchy. A DISABLED state will override all module enablement_states to DISABLED. Corresponds to the JSON property serviceEnablementState

Returns:

  • (String)


12608
12609
12610
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12608

def service_enablement_state
  @service_enablement_state
end

#update_timeString

Output only. The time the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12613
12614
12615
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12613

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12620
12621
12622
12623
12624
12625
12626
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 12620

def update!(**args)
  @modules = args[:modules] if args.key?(:modules)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state)
  @update_time = args[:update_time] if args.key?(:update_time)
end