Class: Google::Apis::SecuritycenterV1beta2::VirtualMachineThreatDetectionSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta2::VirtualMachineThreatDetectionSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta2/classes.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb,
lib/google/apis/securitycenter_v1beta2/representations.rb
Overview
Resource capturing the settings for the Virtual Machine Threat Detection service.
Instance Attribute Summary collapse
-
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's different modules.
-
#name ⇒ String
Identifier.
-
#service_account ⇒ String
Output only.
-
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VirtualMachineThreatDetectionSettings
constructor
A new instance of VirtualMachineThreatDetectionSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VirtualMachineThreatDetectionSettings
Returns a new instance of VirtualMachineThreatDetectionSettings.
11831 11832 11833 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modules ⇒ Hash<String,Google::Apis::SecuritycenterV1beta2::Config>
The configurations including the state of enablement for the service's
different modules. The absence of a module in the map implies its
configuration is inherited from its parent's configuration.
Corresponds to the JSON property modules
11804 11805 11806 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11804 def modules @modules end |
#name ⇒ String
Identifier. The resource name of the VirtualMachineThreatDetectionSettings.
Formats: * organizations/organization/virtualMachineThreatDetectionSettings *
folders/folder/virtualMachineThreatDetectionSettings * projects/project/
virtualMachineThreatDetectionSettings
Corresponds to the JSON property name
11812 11813 11814 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11812 def name @name end |
#service_account ⇒ String
Output only. The service account used by Virtual Machine Threat Detection
detectors.
Corresponds to the JSON property serviceAccount
11818 11819 11820 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11818 def service_account @service_account end |
#service_enablement_state ⇒ String
The state of enablement for the service at its level of the resource hierarchy.
A DISABLED state will override all module enablement_states to DISABLED.
Corresponds to the JSON property serviceEnablementState
11824 11825 11826 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11824 def service_enablement_state @service_enablement_state end |
#update_time ⇒ String
Output only. The time the settings were last updated.
Corresponds to the JSON property updateTime
11829 11830 11831 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11829 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11836 11837 11838 11839 11840 11841 11842 |
# File 'lib/google/apis/securitycenter_v1beta2/classes.rb', line 11836 def update!(**args) @modules = args[:modules] if args.key?(:modules) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @service_enablement_state = args[:service_enablement_state] if args.key?(:service_enablement_state) @update_time = args[:update_time] if args.key?(:update_time) end |